unit CMQBPas;

// **************************************************************************
// **************************************************************************
// **************************************************************************
// MQSeries IBM library ported for Delphi by Dinko Miljak
// e-mail: dinmil@flashmail.com
// version 0.0.4 2001-05-07
// **************************************************************************
// **************************************************************************
// **************************************************************************

(**********************************************************************)
(*                                                                    *)
(*                  IBM MQSeries for Windows NT and Windows 2000      *)
(*                                                                    *)
(*  MODULE NAME:    CMQBC                                             *)
(*                                                                    *)
(*  DESCRIPTION:    Declarations for MQ Administration Interface      *)
(*                                                                    *)
(**********************************************************************)
(*  @START_COPYRIGHT@                                                 *)
(*  Licensed Materials - Property of IBM                              *)
(*                                                                    *)
(*  0784726, 5639-B43  MQSeries for Windows NT and Windows 2000       *)
(*                                                                    *)
(*  (C) Copyright IBM Corporation 1994, 2000.                         *)
(*                                                                    *)
(*  Status: Version 5 Release 2                                       *)
(*  @END_COPYRIGHT@                                                   *)
(**********************************************************************)
(*                                                                    *)
(*  FUNCTION:       This file declares the functions and named        *)
(*                  constants for the MQ administration interface     *)
(*                  (MQAI).                                           *)
(*                                                                    *)
(*  PROCESSOR:      C                                                 *)
(*                                                                    *)
(**********************************************************************)

interface

uses SysUtils, CMQPas;

const

  (*********************************************************************)
  (*  Values Related to Specific Functions                             *)
  (*********************************************************************)

  (* Create-Bag Options for mqCreateBag *)
  MQCBO_NONE                   = $00000000;
  MQCBO_USER_BAG               = $00000000;
  MQCBO_ADMIN_BAG              = $00000001;
  MQCBO_COMMAND_BAG            = $00000010;
  MQCBO_SYSTEM_BAG             = $00000020;
  MQCBO_LIST_FORM_ALLOWED      = $00000002;
  MQCBO_LIST_FORM_INHIBITED    = $00000000;
  MQCBO_REORDER_AS_REQUIRED    = $00000004;
  MQCBO_DO_NOT_REORDER         = $00000000;
  MQCBO_CHECK_SELECTORS        = $00000008;
  MQCBO_DO_NOT_CHECK_SELECTORS = $00000000;

  (* Buffer Length for mqAddString and mqSetString *)
  MQBL_NULL_TERMINATED = -1;

  (* Item Type for mqInquireItemInfo *)
  MQIT_INTEGER = 1;
  MQIT_STRING  = 2;
  MQIT_BAG     = 3;


 (*********************************************************************)
 (*  Values Related to Most Functions                                 *)
 (*********************************************************************)

 (* Integer Selectors for Object Attributes *)
 (*   See MQIA_*   values in CMQC   *)
 (*   See MQIACF_* values in CMQCFC *)
 (*   See MQIACH_* values in CMQCFC *)

 (* Character Selectors for Object Attributes *)
 (*   See MQCA_*   values in CMQC   *)
 (*   See MQCACF_* values in CMQCFC *)
 (*   See MQCACH_* values in CMQCFC *)

 (* Handle Selectors *)
  MQHA_FIRST      = 4001;
  MQHA_BAG_HANDLE = 4001;
  MQHA_LAST_USED  = 4001;
  MQHA_LAST       = 6000;

 (* Limits for Selectors for Object Attributes *)
  MQOA_FIRST = 1;
  MQOA_LAST  = 6000;

 (* Integer System Selectors *)
  MQIASY_FIRST             = -1;
  MQIASY_CODED_CHAR_SET_ID = -1;
  MQIASY_TYPE              = -2;
  MQIASY_COMMAND           = -3;
  MQIASY_MSG_SEQ_NUMBER    = -4;
  MQIASY_CONTROL           = -5;
  MQIASY_COMP_CODE         = -6;
  MQIASY_REASON            = -7;
  MQIASY_BAG_OPTIONS       = -8;
  MQIASY_LAST_USED         = -8;
  MQIASY_LAST              = -2000;

 (* Special Selector Values *)
  MQSEL_ANY_SELECTOR         = -30001;
  MQSEL_ANY_USER_SELECTOR    = -30002;
  MQSEL_ANY_SYSTEM_SELECTOR  = -30003;
  MQSEL_ALL_SELECTORS        = -30001;
  MQSEL_ALL_USER_SELECTORS   = -30002;
  MQSEL_ALL_SYSTEM_SELECTORS = -30003;

 (* Special Index Values *)
  MQIND_NONE = -1;
  MQIND_ALL  = -2;

 (* Bag Handles *)
  MQHB_UNUSABLE_HBAG = -1;
  MQHB_NONE          = -2;


 (*********************************************************************)
 (*  Simple Data Types                                                *)
 (*********************************************************************)

 type
   MQHBAG  = MQLONG;
   PMQHBAG = ^MQHBAG;


 (*********************************************************************)
 (*  Short Names for Functions                                        *)
 (*********************************************************************)

 (*
  MQADDIQ  mqAddInquiry
  MQADDIN  mqAddInteger
  MQADDST  mqAddString
  MQBG2BF  mqBagToBuffer
  MQBF2BG  mqBufferToBag
  MQCLRBG  mqClearBag
  MQCNTIT  mqCountItems
  MQCRTBG  mqCreateBag
  MQDELBG  mqDeleteBag
  MQDELIT  mqDeleteItem
  MQEXEC   mqExecute
  MQGETBG  mqGetBag
  MQINQBG  mqInquireBag
  MQINQIN  mqInquireInteger
  MQINQIT  mqInquireItemInfo
  MQINQST  mqInquireString
  MQPAD    mqPad
  MQPUTBG  mqPutBag
  MQSETIN  mqSetInteger
  MQSETST  mqSetString
  MQTRIM   mqTrim
  MQTRNBG  mqTruncateBag
 *)

 (*********************************************************************)
 (*  mqAddInquiry Function -- Add an Inquiry Item to Bag              *)
 (*********************************************************************)

 procedure mqAddInquiry (
   Bag         : MQHBAG;   (* Bag handle *)
   Selector    : MQLONG;   (* Attribute selector *)
   var CompCode: MQLONG;   (* Completion code *)
   var Reason  : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqAddInquiry';

 (*********************************************************************)
 (*  mqAddInteger Function -- Add Integer to Bag                      *)
 (*********************************************************************)

 procedure mqAddInteger (
   Bag         : MQHBAG;   (* Bag handle *)
   Selector    : MQLONG;   (* Item selector *)
   ItemValue   : MQLONG;   (* Item value *)
   var CompCode: MQLONG;   (* Completion code *)
   var Reason  : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqAddInteger';

 (*********************************************************************)
 (*  mqAddString Function -- Add String to Bag                        *)
 (*********************************************************************)

 procedure mqAddString (
   Bag         : MQHBAG;   (* Bag handle *)
   Selector    : MQLONG;   (* Item selector *)
   BufferLength: MQLONG;   (* Length of buffer *)
   var Buffer  : MQCHAR;   (* Buffer containing item value *)
   var CompCode: MQLONG;   (* Completion code *)
   var Reason  : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqAddString';

 (*********************************************************************)
 (*  mqBagToBuffer Function -- Convert Bag to PCF                     *)
 (*********************************************************************)

 procedure mqBagToBuffer (
   OptionsBag    : MQHBAG;   (* Handle of options bag *)
   DataBag       : MQHBAG;   (* Handle of data bag *)
   BufferLength  : MQLONG;   (* Length of buffer *)
   pBuffer       : Pointer;  (* Buffer to contain PCF *)
   var DataLength: MQLONG;   (* Length of PCF returned in buffer *)
   var CompCode  : MQLONG;   (* Completion code *)
   var Reason    : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqBagToBuffer';

 (*********************************************************************)
 (*  mqBufferToBag Function -- Convert PCF to Bag                     *)
 (*********************************************************************)

 procedure mqBufferToBag (
   OptionsBag  : MQHBAG;     (* Handle of options bag *)
   BufferLength: MQLONG;     (* Length of buffer *)
   Buffer      : Pointer;    (* Buffer containing PCF *)
   DataBag     : MQHBAG;     (* Handle of bag to contain data *)
   var CompCode: MQLONG;     (* Completion code *)
   var Reason  : MQLONG);    (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqBufferToBag';

 (*********************************************************************)
 (*  mqClearBag Function -- Delete All Items in Bag                   *)
 (*********************************************************************)

 procedure mqClearBag (
   Bag         : MQHBAG;     (* Bag handle *)
   var CompCode: MQLONG;     (* Completion code *)
   var Reason  : MQLONG);    (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqClearBag';

 (*********************************************************************)
 (*  mqCountItems Function -- Count Items in Bag                      *)
 (*********************************************************************)

 procedure mqCountItems (
   Bag          : MQHBAG;    (* Bag handle *)
   Selector     : MQLONG;    (* Item selector *)
   var ItemCount: MQLONG;    (* Number of items *)
   var CompCode : MQLONG;    (* Completion code *)
   var Reason   : MQLONG);   (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqCountItems';

 (*********************************************************************)
 (*  mqCreateBag Function -- Create Bag                               *)
 (*********************************************************************)

 procedure mqCreateBag (
   Options      : MQLONG;    (* Bag options *)
   var Bag      : MQHBAG;    (* Handle of bag created *)
   var CompCode : MQLONG;    (* Completion code *)
   var Reason   : MQLONG);   (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqCreateBag';

 (*********************************************************************)
 (*  mqDeleteBag Function -- Delete Bag                               *)
 (*********************************************************************)

 procedure mqDeleteBag (
   var Bag      : MQHBAG;    (* Bag Handle*)
   var CompCode : MQLONG;    (* Completion code *)
   var Reason   : MQLONG);   (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqDeleteBag';

 (*********************************************************************)
 (*  mqDeleteItem Function -- Delete Item in Bag                      *)
 (*********************************************************************)

 procedure mqDeleteItem (
   Bag          : MQHBAG;    (* Bag handle *)
   Selector     : MQLONG;    (* Item selector *)
   ItemIndex    : MQLONG;    (* Item index *)
   var CompCode : MQLONG;    (* Completion code *)
   var Reason   : MQLONG);   (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqDeleteItem';

 (*********************************************************************)
 (*  mqExecute Function -- Send Admin Command and Receive Reponse     *)
 (*********************************************************************)

 procedure mqExecute (
   Hconn        : MQHCONN;   (* Connection handle *)
   Command      : MQLONG;    (* Command identifier *)
   OptionsBag   : MQHBAG;    (* Handle of options bag *)
   AdminBag     : MQHBAG;    (* Handle of admin bag *)
   ResponseBag  : MQHBAG;    (* Handle of response bag *)
   AdminQ       : MQHOBJ;    (* Handle of admin queue *)
   ResponseQ    : MQHOBJ;    (* Handle of response queue *)
   var CompCode : MQLONG;    (* Completion code *)
   var Reason   : MQLONG);   (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqExecute';

 (*********************************************************************)
 (*  mqGetBag Function -- Receive PCF Message into Bag                *)
 (*********************************************************************)

 procedure mqGetBag (
   Hconn         : MQHCONN;  (* Connection handle *)
   Hobj          : MQHOBJ;   (* Queue handle *)
   var MsgDesc   : TMQMD;    (* Message descriptor *)
   var GetMsgOpts: TMQGMO;   (* Get-message options *)
   Bag           : MQHBAG;   (* Handle of bag to contain message *)
   var CompCode  : MQLONG;   (* Completion code *)
   var Reason    : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqGetBag';

 (*********************************************************************)
 (*  mqInquireBag Function -- Inquire Handle in Bag                   *)
 (*********************************************************************)

 procedure mqInquireBag (
   Bag           : MQHBAG;   (* Bag handle *)
   Selector      : MQLONG;   (* Item selector *)
   ItemIndex     : MQLONG;   (* Item index *)
   var ItemValue : MQHBAG;   (* Item value *)
   var CompCode  : MQLONG;   (* Completion code *)
   var Reason    : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqInquireBag';

 (*********************************************************************)
 (*  mqInquireInteger Function -- Inquire Integer in Bag              *)
 (*********************************************************************)

 procedure mqInquireInteger (
   Bag           : MQHBAG;   (* Bag handle *)
   Selector      : MQLONG;   (* Item selector *)
   ItemIndex     : MQLONG;   (* Item index *)
   var ItemValue : MQLONG;   (* Item value *)
   var CompCode  : MQLONG;   (* Completion code *)
   var Reason    : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqInquireInteger';

 (*********************************************************************)
 (*  mqInquireItemInfo Function -- Inquire Attributes of Item in Bag  *)
 (*********************************************************************)

 procedure mqInquireItemInfo (
   Bag            : MQHBAG;   (* Bag handle *)
   Selector       : MQLONG;   (* Item selector *)
   ItemIndex      : MQLONG;   (* Item index *)
   var OutSelector: MQLONG;   (* Selector of item *)
   var ItemType   : MQLONG;   (* Data type of item *)
   var CompCode   : MQLONG;   (* Completion code *)
   var Reason     : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqInquireItemInfo';

 (*********************************************************************)
 (*  mqInquireString Function -- Inquire String in Bag                *)
 (*********************************************************************)

 procedure mqInquireString (
   Bag               : MQHBAG;   (* Bag handle *)
   Selector          : MQLONG;   (* Item selector *)
   ItemIndex         : MQLONG;   (* Item index *)
   BufferLength      : MQLONG;   (* Length of buffer *)
   Buffer            : Pointer;  (* Buffer to contain string *)
   var StringLength  : MQLONG;   (* Length of string returned *)
   var CodedCharSetId: MQLONG;   (* Character-set identifier of string *)
   var CompCode      : MQLONG;   (* Completion code *)
   var Reason        : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqInquireString';

 (*********************************************************************)
 (*  mqPad Function -- Pad Null-terminated String with Blanks         *)
 (*********************************************************************)

 procedure mqPad (
   pString           : PChar;    (* Null-terminated string to be padded *)
   BufferLength      : MQLONG;   (* Length of buffer *)
   Buffer            : Pointer;  (* Buffer to contain padded string *)
   var CompCode      : MQLONG;   (* Completion code *)
   var Reason        : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqPad';

 (*********************************************************************)
 (*  mqPutBag Function -- Send Bag as PCF Message                     *)
 (*********************************************************************)

 procedure mqPutBag (
   Hconn             : MQHCONN;  (* Connection handle *)
   Hobj              : MQHOBJ;   (* Queue handle *)
   var MsgDesc       : TMQMD;    (* Message descriptor *)
   var PutMsgOpts    : TMQPMO;   (* Put-message options *)
   Bag               : MQHBAG;   (* Handle of bag containing message data *)
   var CompCode      : MQLONG;   (* Completion code *)
   var Reason        : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqPutBag';

 (*********************************************************************)
 (*  mqSetInteger Function -- Modify Integer in Bag                   *)
 (*********************************************************************)

 procedure mqSetInteger (
   Bag               : MQHBAG;   (* Bag handle *)
   Selector          : MQLONG;   (* Item selector *)
   ItemIndex         : MQLONG;   (* Item index *)
   ItemValue         : MQLONG;   (* Item value *)
   var CompCode      : MQLONG;   (* Completion code *)
   var Reason        : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqSetInteger';

 (*********************************************************************)
 (*  mqSetString Function -- Modify String in Bag                     *)
 (*********************************************************************)

 procedure mqSetString (
   Bag               : MQHBAG;   (* Bag handle *)
   Selector          : MQLONG;   (* Item selector *)
   ItemIndex         : MQLONG;   (* Item index *)
   BufferLength      : MQLONG;   (* Length of buffer *)
   Buffer            : Pointer;  (* Buffer containing item value *)
   var CompCode      : MQLONG;   (* Completion code *)
   var Reason        : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqSetString';

 (*********************************************************************)
 (*  mqTrim Function -- Replace Trailing Blanks with Null Character   *)
 (*********************************************************************)

 procedure mqTrim (
   BufferLength      : MQLONG;   (* Length of buffer *)
   Buffer            : PChar;    (* Buffer containing blank-padded string *)
   pString           : PChar;    (* String with blanks discarded *)
   var CompCode      : MQLONG;   (* Completion code *)
   var Reason        : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqTrim';

 (*********************************************************************)
 (*  mqTruncateBag Function -- Delete Trailing Items in Bag           *)
 (*********************************************************************)

 procedure mqTruncateBag (
   Bag               : MQHBAG;   (* Bag handle *)
   ItemCount         : MQLONG;   (* Number of items to remain in bag *)
   var CompCode      : MQLONG;   (* Completion code *)
   var Reason        : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'mqTruncateBag';

implementation

end.
