unit CMQCFPas;

// **************************************************************************
// **************************************************************************
// **************************************************************************
// MQSeries IBM library ported for Delphi by Dinko Miljak
// e-mail: dinmil@flashmail.com
// version 0.0.4 2001-05-07
// **************************************************************************
// **************************************************************************
// **************************************************************************

 (*********************************************************************)
 (*                                                                   *)
 (*                  IBM MQSeries for Windows NT and Windows 2000     *)
 (*                                                                   *)
 (*  HEADER NAME:    CMQCFC                                           *)
 (*                                                                   *)
 (*  DESCRIPTION:    Declarations for PCF and Events                  *)
 (*                                                                   *)
 (*********************************************************************)
 (*  @START_COPYRIGHT@                                                *)
 (*  Licensed Materials - Property of IBM                             *)
 (*                                                                   *)
 (*  0784726, 5639-B43                                                *)
 (*                                                                   *)
 (*  (C) Copyright IBM Corporation 1995, 2000.                        *)
 (*                                                                   *)
 (*  Status: Version 5 Release 2                                      *)
 (*  @END_COPYRIGHT@                                                  *)
 (*********************************************************************)
 (*                                                                   *)
 (*  FUNCTION:       This file declares the structures and named      *)
 (*                  constants for PCF and event messages.            *)
 (*                                                                   *)
 (*  PROCESSOR:      C                                                *)
 (*                                                                   *)
 (*********************************************************************)

interface

uses SysUtils, CMQPas;

const

 (*********************************************************************)
 (*  Values Related to MQCFH Structure                                *)
 (*********************************************************************)

 (* Structure Length *)
  MQCFH_STRUC_LENGTH = 36;

 (* Structure Version Number *)
  MQCFH_VERSION_1       = 1;
  MQCFH_CURRENT_VERSION = 1;

 (* Command Codes *)
  MQCMD_CHANGE_Q_MGR           = 1;
  MQCMD_INQUIRE_Q_MGR          = 2;
  MQCMD_CHANGE_PROCESS         = 3;
  MQCMD_COPY_PROCESS           = 4;
  MQCMD_CREATE_PROCESS         = 5;
  MQCMD_DELETE_PROCESS         = 6;
  MQCMD_INQUIRE_PROCESS        = 7;
  MQCMD_CHANGE_Q               = 8;
  MQCMD_CLEAR_Q                = 9;
  MQCMD_COPY_Q                 = 10;
  MQCMD_CREATE_Q               = 11;
  MQCMD_DELETE_Q               = 12;
  MQCMD_INQUIRE_Q              = 13;
  MQCMD_RESET_Q_STATS          = 17;
  MQCMD_INQUIRE_Q_NAMES        = 18;
  MQCMD_INQUIRE_PROCESS_NAMES  = 19;
  MQCMD_INQUIRE_CHANNEL_NAMES  = 20;
  MQCMD_CHANGE_CHANNEL         = 21;
  MQCMD_COPY_CHANNEL           = 22;
  MQCMD_CREATE_CHANNEL         = 23;
  MQCMD_DELETE_CHANNEL         = 24;
  MQCMD_INQUIRE_CHANNEL        = 25;
  MQCMD_PING_CHANNEL           = 26;
  MQCMD_RESET_CHANNEL          = 27;
  MQCMD_START_CHANNEL          = 28;
  MQCMD_STOP_CHANNEL           = 29;
  MQCMD_START_CHANNEL_INIT     = 30;
  MQCMD_START_CHANNEL_LISTENER = 31;
  MQCMD_CHANGE_NAMELIST        = 32;
  MQCMD_COPY_NAMELIST          = 33;
  MQCMD_CREATE_NAMELIST        = 34;
  MQCMD_DELETE_NAMELIST        = 35;
  MQCMD_INQUIRE_NAMELIST       = 36;
  MQCMD_INQUIRE_NAMELIST_NAMES = 37;
  MQCMD_ESCAPE                 = 38;
  MQCMD_RESOLVE_CHANNEL        = 39;
  MQCMD_PING_Q_MGR             = 40;
  MQCMD_INQUIRE_CHANNEL_STATUS = 42;
  MQCMD_Q_MGR_EVENT            = 44;
  MQCMD_PERFM_EVENT            = 45;
  MQCMD_CHANNEL_EVENT          = 46;
  MQCMD_DELETE_PUBLICATION     = 60;
  MQCMD_DEREGISTER_PUBLISHER   = 61;
  MQCMD_DEREGISTER_SUBSCRIBER  = 62;
  MQCMD_PUBLISH                = 63;
  MQCMD_REGISTER_PUBLISHER     = 64;
  MQCMD_REGISTER_SUBSCRIBER    = 65;
  MQCMD_REQUEST_UPDATE         = 66;
  MQCMD_BROKER_INTERNAL        = 67;
  MQCMD_INQUIRE_CLUSTER_Q_MGR  = 70;
  MQCMD_RESUME_Q_MGR_CLUSTER   = 71;
  MQCMD_SUSPEND_Q_MGR_CLUSTER  = 72;
  MQCMD_REFRESH_CLUSTER        = 73;
  MQCMD_RESET_CLUSTER          = 74;
  MQCMD_REFRESH_SECURITY       = 78;
  MQCMD_NONE                   = 0;

 (* Control Options *)
  MQCFC_LAST     = 1;
  MQCFC_NOT_LAST = 0;

 (* Reason Codes *)
  MQRCCF_CFH_TYPE_ERROR          = 3001;
  MQRCCF_CFH_LENGTH_ERROR        = 3002;
  MQRCCF_CFH_VERSION_ERROR       = 3003;
  MQRCCF_CFH_MSG_SEQ_NUMBER_ERR  = 3004;
  MQRCCF_CFH_CONTROL_ERROR       = 3005;
  MQRCCF_CFH_PARM_COUNT_ERROR    = 3006;
  MQRCCF_CFH_COMMAND_ERROR       = 3007;
  MQRCCF_COMMAND_FAILED          = 3008;
  MQRCCF_CFIN_LENGTH_ERROR       = 3009;
  MQRCCF_CFST_LENGTH_ERROR       = 3010;
  MQRCCF_CFST_STRING_LENGTH_ERR  = 3011;
  MQRCCF_FORCE_VALUE_ERROR       = 3012;
  MQRCCF_STRUCTURE_TYPE_ERROR    = 3013;
  MQRCCF_CFIN_PARM_ID_ERROR      = 3014;
  MQRCCF_CFST_PARM_ID_ERROR      = 3015;
  MQRCCF_MSG_LENGTH_ERROR        = 3016;
  MQRCCF_CFIN_DUPLICATE_PARM     = 3017;
  MQRCCF_CFST_DUPLICATE_PARM     = 3018;
  MQRCCF_PARM_COUNT_TOO_SMALL    = 3019;
  MQRCCF_PARM_COUNT_TOO_BIG      = 3020;
  MQRCCF_Q_ALREADY_IN_CELL       = 3021;
  MQRCCF_Q_TYPE_ERROR            = 3022;
  MQRCCF_MD_FORMAT_ERROR         = 3023;
  MQRCCF_CFSL_LENGTH_ERROR       = 3024;
  MQRCCF_REPLACE_VALUE_ERROR     = 3025;
  MQRCCF_CFIL_DUPLICATE_VALUE    = 3026;
  MQRCCF_CFIL_COUNT_ERROR        = 3027;
  MQRCCF_CFIL_LENGTH_ERROR       = 3028;
  MQRCCF_QUIESCE_VALUE_ERROR     = 3029;
  MQRCCF_MSG_SEQ_NUMBER_ERROR    = 3030;
  MQRCCF_PING_DATA_COUNT_ERROR   = 3031;
  MQRCCF_PING_DATA_COMPARE_ERROR = 3032;
  MQRCCF_CFSL_PARM_ID_ERROR      = 3033;
  MQRCCF_CHANNEL_TYPE_ERROR      = 3034;
  MQRCCF_PARM_SEQUENCE_ERROR     = 3035;
  MQRCCF_XMIT_PROTOCOL_TYPE_ERR  = 3036;
  MQRCCF_BATCH_SIZE_ERROR        = 3037;
  MQRCCF_DISC_INT_ERROR          = 3038;
  MQRCCF_SHORT_RETRY_ERROR       = 3039;
  MQRCCF_SHORT_TIMER_ERROR       = 3040;
  MQRCCF_LONG_RETRY_ERROR        = 3041;
  MQRCCF_LONG_TIMER_ERROR        = 3042;
  MQRCCF_SEQ_NUMBER_WRAP_ERROR   = 3043;
  MQRCCF_MAX_MSG_LENGTH_ERROR    = 3044;
  MQRCCF_PUT_AUTH_ERROR          = 3045;
  MQRCCF_PURGE_VALUE_ERROR       = 3046;
  MQRCCF_CFIL_PARM_ID_ERROR      = 3047;
  MQRCCF_MSG_TRUNCATED           = 3048;
  MQRCCF_CCSID_ERROR             = 3049;
  MQRCCF_ENCODING_ERROR          = 3050;
  MQRCCF_DATA_CONV_VALUE_ERROR   = 3052;
  MQRCCF_INDOUBT_VALUE_ERROR     = 3053;
  MQRCCF_ESCAPE_TYPE_ERROR       = 3054;
  MQRCCF_CHANNEL_TABLE_ERROR     = 3062;
  MQRCCF_MCA_TYPE_ERROR          = 3063;
  MQRCCF_CHL_INST_TYPE_ERROR     = 3064;
  MQRCCF_CHL_STATUS_NOT_FOUND    = 3065;
  MQRCCF_CFSL_DUPLICATE_PARM     = 3066;
  MQRCCF_CFSL_TOTAL_LENGTH_ERROR = 3067;
  MQRCCF_CFSL_COUNT_ERROR        = 3068;
  MQRCCF_CFSL_STRING_LENGTH_ERR  = 3069;
  MQRCCF_BROKER_DELETED          = 3070;
  MQRCCF_STREAM_ERROR            = 3071;
  MQRCCF_TOPIC_ERROR             = 3072;
  MQRCCF_NOT_REGISTERED          = 3073;
  MQRCCF_Q_MGR_NAME_ERROR        = 3074;
  MQRCCF_INCORRECT_STREAM        = 3075;
  MQRCCF_Q_NAME_ERROR            = 3076;
  MQRCCF_NO_RETAINED_MSG         = 3077;
  MQRCCF_DUPLICATE_IDENTITY      = 3078;
  MQRCCF_INCORRECT_Q             = 3079;
  MQRCCF_CORREL_ID_ERROR         = 3080;
  MQRCCF_NOT_AUTHORIZED          = 3081;
  MQRCCF_UNKNOWN_STREAM          = 3082;
  MQRCCF_REG_OPTIONS_ERROR       = 3083;
  MQRCCF_PUB_OPTIONS_ERROR       = 3084;
  MQRCCF_UNKNOWN_BROKER          = 3085;
  MQRCCF_Q_MGR_CCSID_ERROR       = 3086;
  MQRCCF_DEL_OPTIONS_ERROR       = 3087;
  MQRCCF_CLUSTER_NAME_CONFLICT   = 3088;
  MQRCCF_REPOS_NAME_CONFLICT     = 3089;
  MQRCCF_CLUSTER_Q_USAGE_ERROR   = 3090;
  MQRCCF_ACTION_VALUE_ERROR      = 3091;
  MQRCCF_COMMS_LIBRARY_ERROR     = 3092;
  MQRCCF_NETBIOS_NAME_ERROR      = 3093;
  MQRCCF_BROKER_COMMAND_FAILED   = 3094;
  MQRCCF_FILTER_ERROR            = 3150;
  MQRCCF_WRONG_USER              = 3151;
  MQRCCF_OBJECT_ALREADY_EXISTS   = 4001;
  MQRCCF_OBJECT_WRONG_TYPE       = 4002;
  MQRCCF_LIKE_OBJECT_WRONG_TYPE  = 4003;
  MQRCCF_OBJECT_OPEN             = 4004;
  MQRCCF_ATTR_VALUE_ERROR        = 4005;
  MQRCCF_UNKNOWN_Q_MGR           = 4006;
  MQRCCF_Q_WRONG_TYPE            = 4007;
  MQRCCF_OBJECT_NAME_ERROR       = 4008;
  MQRCCF_ALLOCATE_FAILED         = 4009;
  MQRCCF_HOST_NOT_AVAILABLE      = 4010;
  MQRCCF_CONFIGURATION_ERROR     = 4011;
  MQRCCF_CONNECTION_REFUSED      = 4012;
  MQRCCF_ENTRY_ERROR             = 4013;
  MQRCCF_SEND_FAILED             = 4014;
  MQRCCF_RECEIVED_DATA_ERROR     = 4015;
  MQRCCF_RECEIVE_FAILED          = 4016;
  MQRCCF_CONNECTION_CLOSED       = 4017;
  MQRCCF_NO_STORAGE              = 4018;
  MQRCCF_NO_COMMS_MANAGER        = 4019;
  MQRCCF_LISTENER_NOT_STARTED    = 4020;
  MQRCCF_BIND_FAILED             = 4024;
  MQRCCF_CHANNEL_INDOUBT         = 4025;
  MQRCCF_MQCONN_FAILED           = 4026;
  MQRCCF_MQOPEN_FAILED           = 4027;
  MQRCCF_MQGET_FAILED            = 4028;
  MQRCCF_MQPUT_FAILED            = 4029;
  MQRCCF_PING_ERROR              = 4030;
  MQRCCF_CHANNEL_IN_USE          = 4031;
  MQRCCF_CHANNEL_NOT_FOUND       = 4032;
  MQRCCF_UNKNOWN_REMOTE_CHANNEL  = 4033;
  MQRCCF_REMOTE_QM_UNAVAILABLE   = 4034;
  MQRCCF_REMOTE_QM_TERMINATING   = 4035;
  MQRCCF_MQINQ_FAILED            = 4036;
  MQRCCF_NOT_XMIT_Q              = 4037;
  MQRCCF_CHANNEL_DISABLED        = 4038;
  MQRCCF_USER_EXIT_NOT_AVAILABLE = 4039;
  MQRCCF_COMMIT_FAILED           = 4040;
  MQRCCF_CHANNEL_ALREADY_EXISTS  = 4042;
  MQRCCF_DATA_TOO_LARGE          = 4043;
  MQRCCF_CHANNEL_NAME_ERROR      = 4044;
  MQRCCF_XMIT_Q_NAME_ERROR       = 4045;
  MQRCCF_MCA_NAME_ERROR          = 4047;
  MQRCCF_SEND_EXIT_NAME_ERROR    = 4048;
  MQRCCF_SEC_EXIT_NAME_ERROR     = 4049;
  MQRCCF_MSG_EXIT_NAME_ERROR     = 4050;
  MQRCCF_RCV_EXIT_NAME_ERROR     = 4051;
  MQRCCF_XMIT_Q_NAME_WRONG_TYPE  = 4052;
  MQRCCF_MCA_NAME_WRONG_TYPE     = 4053;
  MQRCCF_DISC_INT_WRONG_TYPE     = 4054;
  MQRCCF_SHORT_RETRY_WRONG_TYPE  = 4055;
  MQRCCF_SHORT_TIMER_WRONG_TYPE  = 4056;
  MQRCCF_LONG_RETRY_WRONG_TYPE   = 4057;
  MQRCCF_LONG_TIMER_WRONG_TYPE   = 4058;
  MQRCCF_PUT_AUTH_WRONG_TYPE     = 4059;
  MQRCCF_MISSING_CONN_NAME       = 4061;
  MQRCCF_CONN_NAME_ERROR         = 4062;
  MQRCCF_MQSET_FAILED            = 4063;
  MQRCCF_CHANNEL_NOT_ACTIVE      = 4064;
  MQRCCF_TERMINATED_BY_SEC_EXIT  = 4065;
  MQRCCF_DYNAMIC_Q_SCOPE_ERROR   = 4067;
  MQRCCF_CELL_DIR_NOT_AVAILABLE  = 4068;
  MQRCCF_MR_COUNT_ERROR          = 4069;
  MQRCCF_MR_COUNT_WRONG_TYPE     = 4070;
  MQRCCF_MR_EXIT_NAME_ERROR      = 4071;
  MQRCCF_MR_EXIT_NAME_WRONG_TYPE = 4072;
  MQRCCF_MR_INTERVAL_ERROR       = 4073;
  MQRCCF_MR_INTERVAL_WRONG_TYPE  = 4074;
  MQRCCF_NPM_SPEED_ERROR         = 4075;
  MQRCCF_NPM_SPEED_WRONG_TYPE    = 4076;
  MQRCCF_HB_INTERVAL_ERROR       = 4077;
  MQRCCF_HB_INTERVAL_WRONG_TYPE  = 4078;
  MQRCCF_CHAD_ERROR              = 4079;
  MQRCCF_CHAD_WRONG_TYPE         = 4080;
  MQRCCF_CHAD_EVENT_ERROR        = 4081;
  MQRCCF_CHAD_EVENT_WRONG_TYPE   = 4082;
  MQRCCF_CHAD_EXIT_ERROR         = 4083;
  MQRCCF_CHAD_EXIT_WRONG_TYPE    = 4084;
  MQRCCF_SUPPRESSED_BY_EXIT      = 4085;
  MQRCCF_BATCH_INT_ERROR         = 4086;
  MQRCCF_BATCH_INT_WRONG_TYPE    = 4087;
  MQRCCF_NET_PRIORITY_ERROR      = 4088;
  MQRCCF_NET_PRIORITY_WRONG_TYPE = 4089;
  MQRCCF_CHANNEL_CLOSED          = 4090;

 (*********************************************************************)
 (*  Values Related to MQCFIL Structure                               *)
 (*********************************************************************)

 (* Structure Length (Fixed Part) *)
  MQCFIL_STRUC_LENGTH_FIXED = 16;


 (*********************************************************************)
 (*  Values Related to MQCFIN Structure                               *)
 (*********************************************************************)

 (* Structure Length *)
  MQCFIN_STRUC_LENGTH = 16;


 (*********************************************************************)
 (*  Values Related to MQCFSL Structure                               *)
 (*********************************************************************)

 (* Structure Length (Fixed Part) *)
  MQCFSL_STRUC_LENGTH_FIXED = 24;


 (*********************************************************************)
 (*  Values Related to MQCFST Structure                               *)
 (*********************************************************************)

 (* Structure Length (Fixed Part) *)
  MQCFST_STRUC_LENGTH_FIXED = 20;


 (*********************************************************************)
 (*  Values Related to All Structures                                 *)
 (*********************************************************************)

 (* Structure Type *)
  MQCFT_COMMAND      = 1;
  MQCFT_RESPONSE     = 2;
  MQCFT_INTEGER      = 3;
  MQCFT_STRING       = 4;
  MQCFT_INTEGER_LIST = 5;
  MQCFT_STRING_LIST  = 6;
  MQCFT_EVENT        = 7;
  MQCFT_USER         = 8;


 (*********************************************************************)
 (*  Values Related to Integer Parameter Structures                   *)
 (*********************************************************************)

 (* Integer Parameter Types *)
  MQIACF_FIRST                 = 1001;
  MQIACF_Q_MGR_ATTRS           = 1001;
  MQIACF_Q_ATTRS               = 1002;
  MQIACF_PROCESS_ATTRS         = 1003;
  MQIACF_NAMELIST_ATTRS        = 1004;
  MQIACF_FORCE                 = 1005;
  MQIACF_REPLACE               = 1006;
  MQIACF_PURGE                 = 1007;
  MQIACF_QUIESCE               = 1008;
  MQIACF_ALL                   = 1009;
  MQIACF_PARAMETER_ID          = 1012;
  MQIACF_ERROR_ID              = 1013;
  MQIACF_ERROR_IDENTIFIER      = 1013;
  MQIACF_SELECTOR              = 1014;
  MQIACF_CHANNEL_ATTRS         = 1015;
  MQIACF_ESCAPE_TYPE           = 1017;
  MQIACF_ERROR_OFFSET          = 1018;
  MQIACF_REASON_QUALIFIER      = 1020;
  MQIACF_COMMAND               = 1021;
  MQIACF_OPEN_OPTIONS          = 1022;
  MQIACF_AUX_ERROR_DATA_INT_1  = 1070;
  MQIACF_AUX_ERROR_DATA_INT_2  = 1071;
  MQIACF_CONV_REASON_CODE      = 1072;
  MQIACF_BRIDGE_TYPE           = 1073;
  MQIACF_INQUIRY               = 1074;
  MQIACF_WAIT_INTERVAL         = 1075;
  MQIACF_OPTIONS               = 1076;
  MQIACF_BROKER_OPTIONS        = 1077;
  MQIACF_SEQUENCE_NUMBER       = 1079;
  MQIACF_INTEGER_DATA          = 1080;
  MQIACF_REGISTRATION_OPTIONS  = 1081;
  MQIACF_PUBLICATION_OPTIONS   = 1082;
  MQIACF_CLUSTER_INFO          = 1083;
  MQIACF_Q_MGR_DEFINITION_TYPE = 1084;
  MQIACF_Q_MGR_TYPE            = 1085;
  MQIACF_ACTION                = 1086;
  MQIACF_SUSPEND               = 1087;
  MQIACF_BROKER_COUNT          = 1088;
  MQIACF_APPL_COUNT            = 1089;
  MQIACF_ANONYMOUS_COUNT       = 1090;
  MQIACF_REG_REG_OPTIONS       = 1091;
  MQIACF_DELETE_OPTIONS        = 1092;
  MQIACF_CLUSTER_Q_MGR_ATTRS   = 1093;
  MQIACF_LAST_USED             = 1093;

  MQIACH_FIRST                   = 1501;
  MQIACH_XMIT_PROTOCOL_TYPE      = 1501;
  MQIACH_BATCH_SIZE              = 1502;
  MQIACH_DISC_INTERVAL           = 1503;
  MQIACH_SHORT_TIMER             = 1504;
  MQIACH_SHORT_RETRY             = 1505;
  MQIACH_LONG_TIMER              = 1506;
  MQIACH_LONG_RETRY              = 1507;
  MQIACH_PUT_AUTHORITY           = 1508;
  MQIACH_SEQUENCE_NUMBER_WRAP    = 1509;
  MQIACH_MAX_MSG_LENGTH          = 1510;
  MQIACH_CHANNEL_TYPE            = 1511;
  MQIACH_DATA_COUNT              = 1512;
  MQIACH_MSG_SEQUENCE_NUMBER     = 1514;
  MQIACH_DATA_CONVERSION         = 1515;
  MQIACH_IN_DOUBT                = 1516;
  MQIACH_MCA_TYPE                = 1517;
  MQIACH_CHANNEL_INSTANCE_TYPE   = 1523;
  MQIACH_CHANNEL_INSTANCE_ATTRS  = 1524;
  MQIACH_CHANNEL_ERROR_DATA      = 1525;
  MQIACH_CHANNEL_TABLE           = 1526;
  MQIACH_CHANNEL_STATUS          = 1527;
  MQIACH_INDOUBT_STATUS          = 1528;
  MQIACH_LAST_SEQ_NUMBER         = 1529;
  MQIACH_LAST_SEQUENCE_NUMBER    = 1529;
  MQIACH_CURRENT_MSGS            = 1531;
  MQIACH_CURRENT_SEQ_NUMBER      = 1532;
  MQIACH_CURRENT_SEQUENCE_NUMBER = 1532;
  MQIACH_MSGS                    = 1534;
  MQIACH_BYTES_SENT              = 1535;
  MQIACH_BYTES_RCVD              = 1536;
  MQIACH_BYTES_RECEIVED          = 1536;
  MQIACH_BATCHES                 = 1537;
  MQIACH_BUFFERS_SENT            = 1538;
  MQIACH_BUFFERS_RCVD            = 1539;
  MQIACH_BUFFERS_RECEIVED        = 1539;
  MQIACH_LONG_RETRIES_LEFT       = 1540;
  MQIACH_SHORT_RETRIES_LEFT      = 1541;
  MQIACH_MCA_STATUS              = 1542;
  MQIACH_STOP_REQUESTED          = 1543;
  MQIACH_MR_COUNT                = 1544;
  MQIACH_MR_INTERVAL             = 1545;
  MQIACH_NPM_SPEED               = 1562;
  MQIACH_HB_INTERVAL             = 1563;
  MQIACH_BATCH_INTERVAL          = 1564;
  MQIACH_NETWORK_PRIORITY        = 1565;
  MQIACH_LAST_USED               = 1565;


 (*********************************************************************)
 (*  Values Related to Character Parameter Structures                 *)
 (*********************************************************************)

 (* Character Parameter Types *)
  MQCACF_FIRST                   = 3001;
  MQCACF_FROM_Q_NAME             = 3001;
  MQCACF_TO_Q_NAME               = 3002;
  MQCACF_FROM_PROCESS_NAME       = 3003;
  MQCACF_TO_PROCESS_NAME         = 3004;
  MQCACF_FROM_NAMELIST_NAME      = 3005;
  MQCACF_TO_NAMELIST_NAME        = 3006;
  MQCACF_FROM_CHANNEL_NAME       = 3007;
  MQCACF_TO_CHANNEL_NAME         = 3008;
  MQCACF_Q_NAMES                 = 3011;
  MQCACF_PROCESS_NAMES           = 3012;
  MQCACF_NAMELIST_NAMES          = 3013;
  MQCACF_ESCAPE_TEXT             = 3014;
  MQCACF_LOCAL_Q_NAMES           = 3015;
  MQCACF_MODEL_Q_NAMES           = 3016;
  MQCACF_ALIAS_Q_NAMES           = 3017;
  MQCACF_REMOTE_Q_NAMES          = 3018;
  MQCACF_SENDER_CHANNEL_NAMES    = 3019;
  MQCACF_SERVER_CHANNEL_NAMES    = 3020;
  MQCACF_REQUESTER_CHANNEL_NAMES = 3021;
  MQCACF_RECEIVER_CHANNEL_NAMES  = 3022;
  MQCACF_OBJECT_Q_MGR_NAME       = 3023;
  MQCACF_APPL_NAME               = 3024;
  MQCACF_USER_IDENTIFIER         = 3025;
  MQCACF_AUX_ERROR_DATA_STR_1    = 3026;
  MQCACF_AUX_ERROR_DATA_STR_2    = 3027;
  MQCACF_AUX_ERROR_DATA_STR_3    = 3028;
  MQCACF_BRIDGE_NAME             = 3029;
  MQCACF_STREAM_NAME             = 3030;
  MQCACF_TOPIC                   = 3031;
  MQCACF_PARENT_Q_MGR_NAME       = 3032;
  MQCACF_PUBLISH_TIMESTAMP       = 3034;
  MQCACF_STRING_DATA             = 3035;
  MQCACF_SUPPORTED_STREAM_NAME   = 3036;
  MQCACF_REG_TOPIC               = 3037;
  MQCACF_REG_TIME                = 3038;
  MQCACF_REG_USER_ID             = 3039;
  MQCACF_CHILD_Q_MGR_NAME        = 3040;
  MQCACF_REG_STREAM_NAME         = 3041;
  MQCACF_REG_Q_MGR_NAME          = 3042;
  MQCACF_REG_Q_NAME              = 3043;
  MQCACF_REG_CORREL_ID           = 3044;
  MQCACF_LAST_USED               = 3044;

  MQCACH_FIRST               = 3501;
  MQCACH_CHANNEL_NAME        = 3501;
  MQCACH_DESC                = 3502;
  MQCACH_MODE_NAME           = 3503;
  MQCACH_TP_NAME             = 3504;
  MQCACH_XMIT_Q_NAME         = 3505;
  MQCACH_CONNECTION_NAME     = 3506;
  MQCACH_MCA_NAME            = 3507;
  MQCACH_SEC_EXIT_NAME       = 3508;
  MQCACH_MSG_EXIT_NAME       = 3509;
  MQCACH_SEND_EXIT_NAME      = 3510;
  MQCACH_RCV_EXIT_NAME       = 3511;
  MQCACH_CHANNEL_NAMES       = 3512;
  MQCACH_SEC_EXIT_USER_DATA  = 3513;
  MQCACH_MSG_EXIT_USER_DATA  = 3514;
  MQCACH_SEND_EXIT_USER_DATA = 3515;
  MQCACH_RCV_EXIT_USER_DATA  = 3516;
  MQCACH_USER_ID             = 3517;
  MQCACH_PASSWORD            = 3518;
  MQCACH_LAST_MSG_TIME       = 3524;
  MQCACH_LAST_MSG_DATE       = 3525;
  MQCACH_MCA_USER_ID         = 3527;
  MQCACH_CHANNEL_START_TIME  = 3528;
  MQCACH_CHANNEL_START_DATE  = 3529;
  MQCACH_MCA_JOB_NAME        = 3530;
  MQCACH_LAST_LUWID          = 3531;
  MQCACH_CURRENT_LUWID       = 3532;
  MQCACH_FORMAT_NAME         = 3533;
  MQCACH_MR_EXIT_NAME        = 3534;
  MQCACH_MR_EXIT_USER_DATA   = 3535;
  MQCACH_LAST_USED           = 3535;


 (*********************************************************************)
 (*  Parameter Values                                                 *)
 (*********************************************************************)

 (* Action Option *)
  MQACT_FORCE_REMOVE = 1;

 (* Bridge Type *)
  MQBT_OTMA = 1;

 (* Indoubt Status *)
  MQCHIDS_NOT_INDOUBT = 0;
  MQCHIDS_INDOUBT     = 1;

 (* Channel Status *)
  MQCHS_INACTIVE     = 0;
  MQCHS_BINDING      = 1;
  MQCHS_STARTING     = 2;
  MQCHS_RUNNING      = 3;
  MQCHS_STOPPING     = 4;
  MQCHS_RETRYING     = 5;
  MQCHS_STOPPED      = 6;
  MQCHS_REQUESTING   = 7;
  MQCHS_PAUSED       = 8;
  MQCHS_INITIALIZING = 13;

 (* Channel Stop Option *)
  MQCHSR_STOP_NOT_REQUESTED = 0;
  MQCHSR_STOP_REQUESTED     = 1;

 (* Channel Table Type *)
  MQCHTAB_Q_MGR    = 1;
  MQCHTAB_CLNTCONN = 2;

 (* Escape Type *)
  MQET_MQSC = 1;

 (* Event Recording *)
  MQEVR_DISABLED = 0;
  MQEVR_ENABLED  = 1;

 (* Force Control *)
  MQFC_YES = 1;
  MQFC_NO  = 0;

 (* Indoubt Option *)
  MQIDO_COMMIT  = 1;
  MQIDO_BACKOUT = 2;

 (* Message Channel Agent Status *)
  MQMCAS_STOPPED = 0;
  MQMCAS_RUNNING = 3;

 (* Purge Option *)
  MQPO_YES = 1;
  MQPO_NO  = 0;

 (* Queue Manager Definition Type *)
  MQQMDT_EXPLICIT_CLUSTER_SENDER = 1;
  MQQMDT_AUTO_CLUSTER_SENDER     = 2;
  MQQMDT_AUTO_EXP_CLUSTER_SENDER = 4;
  MQQMDT_CLUSTER_RECEIVER        = 3;

 (* Queue Manager Type *)
  MQQMT_NORMAL     = 0;
  MQQMT_REPOSITORY = 1;

 (* Quiesce Option *)
  MQQO_YES = 1;
  MQQO_NO  = 0;

 (* Queue Service-Interval Events *)
  MQQSIE_NONE = 0;
  MQQSIE_HIGH = 1;
  MQQSIE_OK   = 2;

 (* Replace Option *)
  MQRP_YES = 1;
  MQRP_NO  = 0;

 (* Reason Qualifiers *)
  MQRQ_CONN_NOT_AUTHORIZED      = 1;
  MQRQ_OPEN_NOT_AUTHORIZED      = 2;
  MQRQ_CLOSE_NOT_AUTHORIZED     = 3;
  MQRQ_CMD_NOT_AUTHORIZED       = 4;
  MQRQ_Q_MGR_STOPPING           = 5;
  MQRQ_Q_MGR_QUIESCING          = 6;
  MQRQ_CHANNEL_STOPPED_OK       = 7;
  MQRQ_CHANNEL_STOPPED_ERROR    = 8;
  MQRQ_CHANNEL_STOPPED_RETRY    = 9;
  MQRQ_CHANNEL_STOPPED_DISABLED = 10;
  MQRQ_BRIDGE_STOPPED_OK        = 11;
  MQRQ_BRIDGE_STOPPED_ERROR     = 12;

 (* Queue Definition Scope *)
  MQSCO_Q_MGR = 1;
  MQSCO_CELL  = 2;

 (* Suspend Status *)
  MQSUS_YES = 1;
  MQSUS_NO  = 0;


 (*********************************************************************)
 (*  Values Related to Publish/Subscribe                              *)
 (*********************************************************************)

 (* Delete Options *)
  MQDELO_NONE  = $00000000;
  MQDELO_LOCAL = $00000004;

 (* Publication Options *)
  MQPUBO_NONE                    = $00000000;
  MQPUBO_CORREL_ID_AS_IDENTITY   = $00000001;
  MQPUBO_RETAIN_PUBLICATION      = $00000002;
  MQPUBO_OTHER_SUBSCRIBERS_ONLY  = $00000004;
  MQPUBO_NO_REGISTRATION         = $00000008;
  MQPUBO_IS_RETAINED_PUBLICATION = $00000010;

 (* Registration Options *)
  MQREGO_NONE                    = $00000000;
  MQREGO_CORREL_ID_AS_IDENTITY   = $00000001;
  MQREGO_ANONYMOUS               = $00000002;
  MQREGO_LOCAL                   = $00000004;
  MQREGO_DIRECT_REQUESTS         = $00000008;
  MQREGO_NEW_PUBLICATIONS_ONLY   = $00000010;
  MQREGO_PUBLISH_ON_REQUEST_ONLY = $00000020;
  MQREGO_DEREGISTER_ALL          = $00000040;
  MQREGO_INCLUDE_STREAM_NAME     = $00000080;
  MQREGO_INFORM_IF_RETAINED      = $00000100;

 (* User Attribute Selectors *)
  MQUA_FIRST = 65536;
  MQUA_LAST  = 999999999;


 (*********************************************************************)
 (*  MQCFH Structure -- PCF Header                                    *)
 (*********************************************************************)

Type

 TMQCFH = record
   TType         : MQLONG;   (* Structure type *)
   StrucLength   : MQLONG;   (* Structure length *)
   Version       : MQLONG;   (* Structure version number *)
   Command       : MQLONG;   (* Command identifier *)
   MsgSeqNumber  : MQLONG;   (* Message sequence number *)
   Control       : MQLONG;   (* Control options *)
   CompCode      : MQLONG;   (* Completion code *)
   Reason        : MQLONG;   (* Reason code qualifying completion code *)
   ParameterCount: MQLONG;   (* Count of parameter structures *)
 end;
 PMQCFH = ^TMQCFH;

 (*
  MQCFH_DEFAULT MQCFT_COMMAND,\
                       MQCFH_STRUC_LENGTH,\
                       MQCFH_VERSION_1,\
                       MQCMD_NONE,\
                       1L,\
                       MQCFC_LAST,\
                       MQCC_OK,\
                       MQRC_NONE,\
                       0L
  *)

 (*********************************************************************)
 (*  MQCFIL Structure -- PCF Integer-List Parameter                   *)
 (*********************************************************************)

 TMQCFIL = record
   TType      : MQLONG;                 (* Structure type *)
   StrucLength: MQLONG;                 (* Structure length *)
   Parameter  : MQLONG;                 (* Parameter identifier *)
   Count      : MQLONG;                 (* Count of parameter values *)
   Values     : array[0..0] of MQLONG;  (* Parameter values -- first element *)
 end;
 PMQCFIL = ^TMQCFIL;

 (*
  MQCFIL_DEFAULT MQCFT_INTEGER_LIST,\
                        MQCFIL_STRUC_LENGTH_FIXED,\
                        0L,\
                        0L,\
                        {0L}
  *)

 (*********************************************************************)
 (*  MQCFIN Structure -- PCF Integer Parameter                        *)
 (*********************************************************************)

 TMQCFIN = record
   TType      : MQLONG;    (* Structure type *)
   StrucLength: MQLONG;    (* Structure length *)
   Parameter  : MQLONG;    (* Parameter identifier *)
   Value      : MQLONG;    (* Parameter value *)
 end;
 PMQCFIN = ^TMQCFIN;

 (*
  MQCFIN_DEFAULT MQCFT_INTEGER,\
                        MQCFIN_STRUC_LENGTH,\
                        0L,\
                        0L
 *)

 (*********************************************************************)
 (*  MQCFSL Structure -- PCF String-List Parameter                    *)
 (*********************************************************************)

 TMQCFSL = record
   TType         : MQLONG;                (* Structure type *)
   StrucLength   : MQLONG;                (* Structure length *)
   Parameter     : MQLONG;                (* Parameter identifier *)
   CodedCharSetId: MQLONG;                (* Coded character set identifier *)
   Count         : MQLONG;                (* Count of parameter values *)
   StringLength  : MQLONG;                (* Length of one string *)
   Strings       : array[0..0] of MQCHAR; (* String values -- first character *)
 end;
 PMQCFSL = ^TMQCFSL;

 (*
  MQCFSL_DEFAULT MQCFT_STRING_LIST,\
                        MQCFSL_STRUC_LENGTH_FIXED,\
                        0L,\
                        MQCCSI_DEFAULT,\
                        0L,\
                        0L,\
                        {""}
  *)


 (*********************************************************************)
 (*  MQCFST Structure -- PCF String Parameter                         *)
 (*********************************************************************)

 TMQCFST = record
   TType         : MQLONG;                (* Structure type *)
   StrucLength   : MQLONG;                (* Structure length *)
   Parameter     : MQLONG;                (* Parameter identifier *)
   CodedCharSetId: MQLONG;                (* Coded character set identifier *)
   StringLength  : MQLONG;                (* Length of string *)
   Strings       : array[0..0] of MQCHAR; (* String value -- first character *)
 end;
 PMQCFST = ^TMQCFST;

 (*
  MQCFST_DEFAULT MQCFT_STRING,\
                        MQCFST_STRUC_LENGTH_FIXED,\
                        0L,\
                        MQCCSI_DEFAULT,\
                        0L,\
                        {""}
 *)

const
  MQCFH_DEFAULT: TMQCFH = (
    TType         :  MQCFT_COMMAND;
    StrucLength   :  MQCFH_STRUC_LENGTH;
    Version       :  MQCFH_VERSION_1;
    Command       :  MQCMD_NONE;
    MsgSeqNumber  :  1;
    Control       :  MQCFC_LAST;
    CompCode      :  MQCC_OK;
    Reason        :  MQRC_NONE;
    ParameterCount:  0
  );

  MQCFIL_DEFAULT: TMQCFIL = (
    TType      : MQCFT_INTEGER_LIST;
    StrucLength: MQCFIL_STRUC_LENGTH_FIXED;
    Parameter  : 0;
    Count      : 0;
    Values     : (0);
  );

  MQCFIN_DEFAULT: TMQCFIN = (
    TType      : MQCFT_INTEGER;
    StrucLength: MQCFIN_STRUC_LENGTH;
    Parameter  : 0;
    Value      : 0;
  );

  MQCFSL_DEFAULT: TMQCFSL = (
    TType         : MQCFT_STRING_LIST;
    StrucLength   : MQCFSL_STRUC_LENGTH_FIXED;
    Parameter     : 0;
    CodedCharSetId: MQCCSI_DEFAULT;
    Count         : 0;
    StringLength  : 0;
    Strings       : (#0)
  );

  MQCFST_DEFAULT: TMQCFST = (
    TType         : MQCFT_STRING;
    StrucLength   : MQCFST_STRUC_LENGTH_FIXED;
    Parameter     : 0;
    CodedCharSetId: MQCCSI_DEFAULT;
    StringLength  : 0;
    Strings       : (#0);
  );

implementation

end.
