unit CMQPas;

// **************************************************************************
// **************************************************************************
// **************************************************************************
// MQSeries IBM library ported for Delphi by Dinko Miljak
// e-mail: dinmil@flashmail.com
// version 0.0.4 2001-05-07
// **************************************************************************
// **************************************************************************
// **************************************************************************


{$A-}  // alignment settings - aviod problems between different languages


  (*********************************************************************)
  (*                                                                   *)
  (*                  IBM MQSeries for Windows NT and Windows 2000     *)
  (*                                                                   *)
  (*  HEADER NAME:    CMQC                                             *)
  (*                                                                   *)
  (*  DESCRIPTION:    Declarations for Main MQI                        *)
  (*                                                                   *)
  (*********************************************************************)
  (*  @START_COPYRIGHT@                                                *)
  (*  Licensed Materials - Property of IBM                             *)
  (*                                                                   *)
  (*  0784726, 5639-B43                                                *)
  (*                                                                   *)
  (*  (C) Copyright IBM Corporation 1993, 2000.                        *)
  (*                                                                   *)
  (*  Status: Version 5 Release 2                                      *)
  (*  @END_COPYRIGHT@                                                  *)
  (*********************************************************************)
  (*                                                                   *)
  (*  FUNCTION:       This file declares the functions, structures,    *)
  (*                  and named constants for the main MQI.            *)
  (*                                                                   *)
  (*  PROCESSOR:      C                                                *)
  (*                                                                   *)
  (*********************************************************************)

interface

uses SysUtils;

const

  (*********************************************************************)
  (*  Values Related to MQBO Structure                                 *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQBO_STRUC_ID = 'BO  ';

  (* Structure Version Number *)
  MQBO_VERSION_1       = 1;
  MQBO_CURRENT_VERSION = 1;

  (* Begin Options *)
  MQBO_NONE = 0;

  (*********************************************************************)
  (*  Values Related to MQCIH Structure                                *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQCIH_STRUC_ID = 'CIH ';

  (* Structure Version Number *)
  MQCIH_VERSION_1       = 1;
  MQCIH_VERSION_2       = 2;
  MQCIH_CURRENT_VERSION = 2;

  (* Structure Length *)
  MQCIH_LENGTH_1       = 164;
  MQCIH_LENGTH_2       = 180;
  MQCIH_CURRENT_LENGTH = 180;

  (* Flags *)
  MQCIH_NONE =0;

  (* Return Code *)
  MQCRC_OK                    = 0;
  MQCRC_CICS_EXEC_ERROR       = 1;
  MQCRC_MQ_API_ERROR          = 2;
  MQCRC_BRIDGE_ERROR          = 3;
  MQCRC_BRIDGE_ABEND          = 4;
  MQCRC_APPLICATION_ABEND     = 5;
  MQCRC_SECURITY_ERROR        = 6;
  MQCRC_PROGRAM_NOT_AVAILABLE = 7;
  MQCRC_BRIDGE_TIMEOUT        = 8;
  MQCRC_TRANSID_NOT_AVAILABLE = 9;

  (* Unit of Work Control *)
  MQCUOWC_ONLY     = $00000111;
  MQCUOWC_CONTINUE = $00010000;
  MQCUOWC_FIRST    = $00000011;
  MQCUOWC_MIDDLE   = $00000010;
  MQCUOWC_LAST     = $00000110;
  MQCUOWC_COMMIT   = $00000100;
  MQCUOWC_BACKOUT  = $00001100;

  (* Get Wait Interval *)
  MQCGWI_DEFAULT = -2;

  (* Link Type *)
  MQCLT_PROGRAM     = 1;
  MQCLT_TRANSACTION = 2;

  (* Output Data Length *)
  MQCODL_AS_INPUT = -1;

  (* ADS Descriptor *)
  MQCADSD_NONE      = $00000000;
  MQCADSD_SEND      = $00000001;
  MQCADSD_RECV      = $00000010;
  MQCADSD_MSGFORMAT = $00000100;

  (* Conversational Task *)
  MQCCT_YES = $00000001;
  MQCCT_NO  = $00000000;

  (* Task End Status *)
  MQCTES_NOSYNC  = $00000000;
  MQCTES_COMMIT  = $00000100;
  MQCTES_BACKOUT = $00001100;
  MQCTES_ENDTASK = $00010000;

  (* Facility *)
  MQCFAC_NONE = #0#0#0#0#0#0#0#0;

  (* Function *)
  MQCFUNC_MQCONN = 'CONN';
  MQCFUNC_MQGET  = 'GET ';
  MQCFUNC_MQINQ  = 'INQ ';
  MQCFUNC_MQOPEN = 'OPEN';
  MQCFUNC_MQPUT  = 'PUT ';
  MQCFUNC_MQPUT1 = 'PUT1';
  MQCFUNC_NONE   = '    ';

  (* Start Code *)
  MQCSC_START     = 'S   ';
  MQCSC_STARTDATA = 'SD  ';
  MQCSC_TERMINPUT = 'TD  ';
  MQCSC_NONE      = '    ';

  (*********************************************************************)
  (*  Values Related to MQCNO Structure                                *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQCNO_STRUC_ID = 'CNO ';

  (* Structure Version Number *)
  MQCNO_VERSION_1       = 1;
  MQCNO_VERSION_2       = 2;
  MQCNO_CURRENT_VERSION = 2;

  (* Connect Options *)
  MQCNO_STANDARD_BINDING = $00000000;
  MQCNO_FASTPATH_BINDING = $00000001;
  MQCNO_NONE             = $00000000;


  (*********************************************************************)
  (*  Values Related to MQDH Structure                                 *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQDH_STRUC_ID = 'DH  ';

  (* Structure Version Number *)
  MQDH_VERSION_1       = 1;
  MQDH_CURRENT_VERSION = 1;

  (* General Flags *)
  MQDHF_NEW_MSG_IDS = 1;
  MQDHF_NONE        = 0;

  (* Put Message Record Flags *)
  (* See values for "Put Message Record Fields" under MQPMO *)


  (*********************************************************************)
  (*  Values Related to MQDLH Structure                                *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQDLH_STRUC_ID = 'DLH ';

  (* Structure Version Number *)
  MQDLH_VERSION_1       = 1;
  MQDLH_CURRENT_VERSION = 1;


  (*********************************************************************)
  (*  Values Related to MQGMO Structure                                *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQGMO_STRUC_ID = 'GMO ';

  (* Structure Version Number *)
  MQGMO_VERSION_1       = 1;
  MQGMO_VERSION_2       = 2;
  MQGMO_VERSION_3       = 3;
  MQGMO_CURRENT_VERSION = 3;

  (* Get-Message Options *)
  MQGMO_WAIT                    = $00000001;
  MQGMO_NO_WAIT                 = $00000000;
  MQGMO_SYNCPOINT               = $00000002;
  MQGMO_SYNCPOINT_IF_PERSISTENT = $00001000;
  MQGMO_NO_SYNCPOINT            = $00000004;
  MQGMO_MARK_SKIP_BACKOUT       = $00000080;
  MQGMO_BROWSE_FIRST            = $00000010;
  MQGMO_BROWSE_NEXT             = $00000020;
  MQGMO_BROWSE_MSG_UNDER_CURSOR = $00000800;
  MQGMO_MSG_UNDER_CURSOR        = $00000100;
  MQGMO_LOCK                    = $00000200;
  MQGMO_UNLOCK                  = $00000400;
  MQGMO_ACCEPT_TRUNCATED_MSG    = $00000040;
  MQGMO_SET_SIGNAL              = $00000008;
  MQGMO_FAIL_IF_QUIESCING       = $00002000;
  MQGMO_CONVERT                 = $00004000;
  MQGMO_LOGICAL_ORDER           = $00008000;
  MQGMO_COMPLETE_MSG            = $00010000;
  MQGMO_ALL_MSGS_AVAILABLE      = $00020000;
  MQGMO_ALL_SEGMENTS_AVAILABLE  = $00040000;
  MQGMO_NONE                    = $00000000;

  (* Wait Interval *)
  MQWI_UNLIMITED = -1;

  (* Signal Values *)
  MQEC_MSG_ARRIVED           = 2;
  MQEC_WAIT_INTERVAL_EXPIRED = 3;
  MQEC_WAIT_CANCELED         = 4;
  MQEC_Q_MGR_QUIESCING       = 5;
  MQEC_CONNECTION_QUIESCING  = 6;

  (* Match Options *)
  MQMO_MATCH_MSG_ID         = $00000001;
  MQMO_MATCH_CORREL_ID      = $00000002;
  MQMO_MATCH_GROUP_ID       = $00000004;
  MQMO_MATCH_MSG_SEQ_NUMBER = $00000008;
  MQMO_MATCH_OFFSET         = $00000010;
  MQMO_MATCH_MSG_TOKEN      = $00000020;
  MQMO_NONE                 = $00000000;

  (* Group Status *)
  MQGS_NOT_IN_GROUP      = ' ';
  MQGS_MSG_IN_GROUP      = 'G';
  MQGS_LAST_MSG_IN_GROUP = 'L';

  (* Segment Status *)
  MQSS_NOT_A_SEGMENT = ' ';
  MQSS_SEGMENT       = 'S';
  MQSS_LAST_SEGMENT  = 'L';

  (* Segmentation *)
  MQSEG_INHIBITED = ' ';
  MQSEG_ALLOWED   = 'A';

  (* Message Token *)
  MQMTOK_NONE = #0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0;

  (* Returned Length *)
  MQRL_UNDEFINED = -1;


  (*********************************************************************)
  (*  Values Related to MQIIH Structure                                *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQIIH_STRUC_ID = 'IIH ';

  (* Structure Version Number *)
  MQIIH_VERSION_1       = 1;
  MQIIH_CURRENT_VERSION = 1;

  (* Structure Length *)
  MQIIH_LENGTH_1 = 84;

  (* Flags *)
  MQIIH_NONE = 0;

  (* Authenticator *)
  MQIAUT_NONE = '        ';

  (* Transaction Instance Identifier *)
  MQITII_NONE = #0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0;

  (* Transaction State *)
  MQITS_IN_CONVERSATION     = 'C';
  MQITS_NOT_IN_CONVERSATION = ' ';
  MQITS_ARCHITECTED         = 'A';

  (* Commit Mode *)
  MQICM_COMMIT_THEN_SEND = '0';
  MQICM_SEND_THEN_COMMIT = '1';

  (* Security Scope *)
  MQISS_CHECK = 'C';
  MQISS_FULL  = 'F';


  (*********************************************************************)
  (*  Values Related to MQMD Structure                                 *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQMD_STRUC_ID = 'MD  ';

  (* Structure Version Number *)
  MQMD_VERSION_1       = 1;
  MQMD_VERSION_2       = 2;
  MQMD_CURRENT_VERSION = 2;

  (* Report Options *)
  MQRO_EXCEPTION                 = $01000000;
  MQRO_EXCEPTION_WITH_DATA       = $03000000;
  MQRO_EXCEPTION_WITH_FULL_DATA  = $07000000;
  MQRO_EXPIRATION                = $00200000;
  MQRO_EXPIRATION_WITH_DATA      = $00600000;
  MQRO_EXPIRATION_WITH_FULL_DATA = $00e00000;
  MQRO_COA                       = $00000100;
  MQRO_COA_WITH_DATA             = $00000300;
  MQRO_COA_WITH_FULL_DATA        = $00000700;
  MQRO_COD                       = $00000800;
  MQRO_COD_WITH_DATA             = $00001800;
  MQRO_COD_WITH_FULL_DATA        = $00003800;
  MQRO_PAN                       = $00000001;
  MQRO_NAN                       = $00000002;
  MQRO_NEW_MSG_ID                = $00000000;
  MQRO_PASS_MSG_ID               = $00000080;
  MQRO_COPY_MSG_ID_TO_CORREL_ID  = $00000000;
  MQRO_PASS_CORREL_ID            = $00000040;
  MQRO_DEAD_LETTER_Q             = $00000000;
  MQRO_DISCARD_MSG               = $08000000;
  MQRO_NONE                      = $00000000;

  (* Report Options Masks *)
  MQRO_REJECT_UNSUP_MASK         = $101c0000;
  MQRO_ACCEPT_UNSUP_MASK         = $efe000ff;
  MQRO_ACCEPT_UNSUP_IF_XMIT_MASK = $0003ff00;

  (* Message Types *)
  MQMT_SYSTEM_FIRST        = 1;
  MQMT_REQUEST             = 1;
  MQMT_REPLY               = 2;
  MQMT_DATAGRAM            = 8;
  MQMT_REPORT              = 4;
  MQMT_MQE_FIELDS_FROM_MQE = 112;
  MQMT_MQE_FIELDS          = 113;
  MQMT_SYSTEM_LAST         = 65535;
  MQMT_APPL_FIRST          = 65536;
  MQMT_APPL_LAST           = 999999999;

  (* Expiry *)
  MQEI_UNLIMITED = -1;

  (* Feedback Values *)
  MQFB_NONE                  = 0;
  MQFB_SYSTEM_FIRST          = 1;
  MQFB_QUIT                  = 256;
  MQFB_EXPIRATION            = 258;
  MQFB_COA                   = 259;
  MQFB_COD                   = 260;
  MQFB_CHANNEL_COMPLETED     = 262;
  MQFB_CHANNEL_FAIL_RETRY    = 263;
  MQFB_CHANNEL_FAIL          = 264;
  MQFB_APPL_CANNOT_BE_STARTED= 265;
  MQFB_TM_ERROR              = 266;
  MQFB_APPL_TYPE_ERROR       = 267;
  MQFB_STOPPED_BY_MSG_EXIT   = 268;
  MQFB_XMIT_Q_MSG_ERROR      = 271;
  MQFB_PAN                   = 275;
  MQFB_NAN                   = 276;
  MQFB_STOPPED_BY_CHAD_EXIT  = 277;
  MQFB_STOPPED_BY_PUBSUB_EXIT= 279;
  MQFB_NOT_A_REPOSITORY_MSG  = 280;
  MQFB_BIND_OPEN_CLUSRCVR_DEL= 281;
  MQFB_DATA_LENGTH_ZERO      = 291;
  MQFB_DATA_LENGTH_NEGATIVE  = 292;
  MQFB_DATA_LENGTH_TOO_BIG   = 293;
  MQFB_BUFFER_OVERFLOW       = 294;
  MQFB_LENGTH_OFF_BY_ONE     = 295;
  MQFB_IIH_ERROR             = 296;
  MQFB_NOT_AUTHORIZED_FOR_IMS= 298;
  MQFB_IMS_ERROR             = 300;
  MQFB_IMS_FIRST             = 301;
  MQFB_IMS_LAST              = 399;
  MQFB_CICS_INTERNAL_ERROR   = 401;
  MQFB_CICS_NOT_AUTHORIZED   = 402;
  MQFB_CICS_BRIDGE_FAILURE   = 403;
  MQFB_CICS_CORREL_ID_ERROR  = 404;
  MQFB_CICS_CCSID_ERROR      = 405;
  MQFB_CICS_ENCODING_ERROR   = 406;
  MQFB_CICS_CIH_ERROR        = 407;
  MQFB_CICS_UOW_ERROR        = 408;
  MQFB_CICS_COMMAREA_ERROR   = 409;
  MQFB_CICS_APPL_NOT_STARTED = 410;
  MQFB_CICS_APPL_ABENDED     = 411;
  MQFB_CICS_DLQ_ERROR        = 412;
  MQFB_CICS_UOW_BACKED_OUT   = 413;
  MQFB_SYSTEM_LAST           = 65535;
  MQFB_APPL_FIRST            = 65536;
  MQFB_APPL_LAST             = 999999999;

  (* Encoding *)
  MQENC_NATIVE = $00000222;

  (* Encoding Masks *)
  MQENC_INTEGER_MASK  = $0000000f;
  MQENC_DECIMAL_MASK  = $000000f0;
  MQENC_FLOAT_MASK    = $00000f00;
  MQENC_RESERVED_MASK = $fffff000;

  (* Encodings for Binary Integers *)
  MQENC_INTEGER_UNDEFINED = $00000000;
  MQENC_INTEGER_NORMAL    = $00000001;
  MQENC_INTEGER_REVERSED  = $00000002;

  (* Encodings for Packed-Decimal Integers *)
  MQENC_DECIMAL_UNDEFINED = $00000000;
  MQENC_DECIMAL_NORMAL    = $00000010;
  MQENC_DECIMAL_REVERSED  = $00000020;

  (* Encodings for Floating-Point Numbers *)
  MQENC_FLOAT_UNDEFINED     = $00000000;
  MQENC_FLOAT_IEEE_NORMAL   = $00000100;
  MQENC_FLOAT_IEEE_REVERSED = $00000200;
  MQENC_FLOAT_S390          = $00000300;

  (* Coded Character-Set Identifiers *)
  MQCCSI_UNDEFINED = 0;
  MQCCSI_DEFAULT   = 0;
  MQCCSI_Q_MGR     = 0;
  MQCCSI_INHERIT   = -2;
  MQCCSI_EMBEDDED  = -1;

  (* Formats *)
  MQFMT_NONE               = '        ';
  MQFMT_ADMIN              = 'MQADMIN ';
  MQFMT_CHANNEL_COMPLETED  = 'MQCHCOM ';
  MQFMT_CICS               = 'MQCICS  ';
  MQFMT_COMMAND_1          = 'MQCMD1  ';
  MQFMT_COMMAND_2          = 'MQCMD2  ';
  MQFMT_DEAD_LETTER_HEADER = 'MQDEAD  ';
  MQFMT_DIST_HEADER        = 'MQHDIST ';
  MQFMT_EVENT              = 'MQEVENT ';
  MQFMT_IMS                = 'MQIMS   ';
  MQFMT_IMS_VAR_STRING     = 'MQIMSVS ';
  MQFMT_MD_EXTENSION       = 'MQHMDE  ';
  MQFMT_PCF                = 'MQPCF   ';
  MQFMT_REF_MSG_HEADER     = 'MQHREF  ';
  MQFMT_RF_HEADER          = 'MQHRF   ';
  MQFMT_RF_HEADER_2        = 'MQHRF2  ';
  MQFMT_STRING             = 'MQSTR   ';
  MQFMT_TRIGGER            = 'MQTRIG  ';
  MQFMT_WORK_INFO_HEADER   = 'MQHWIH  ';
  MQFMT_XMIT_Q_HEADER      = 'MQXMIT  ';

  (* Priority *)
  MQPRI_PRIORITY_AS_Q_DEF = -1;

  (* Persistence Values *)
  MQPER_NOT_PERSISTENT       = 0;
  MQPER_PERSISTENT           = 1;
  MQPER_PERSISTENCE_AS_Q_DEF = 2;

  (* Message Identifier *)
  MQMI_NONE = #0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0;

  (* Correlation Identifier *)
  MQCI_NONE   = #0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0;
  MQCI_NEW_SESSION = '#41#$4d#51#21#$4e#45#57#$5f#53#45#53#53#49#$4f#$4e#$5f#43#$4f#52#52#45#$4c#49#44';

  (* Accounting Token *)
  MQACT_NONE = #0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0;

  (* Accounting Token Type *)
  MQACTT_UNKNOWN             = '$#00';
  MQACTT_CICS_LUOW_ID        = '$#01';
  MQACTT_OS2_DEFAULT         = '$#04';
  MQACTT_DOS_DEFAULT         = '$#05';
  MQACTT_UNIX_NUMERIC_ID     = '$#06';
  MQACTT_OS400_ACCOUNT_TOKEN = '$#08';
  MQACTT_WINDOWS_DEFAULT     = '$#09';
  MQACTT_NT_SECURITY_ID      = '$#0b';
  MQACTT_USER                = '$#19';

  (* Put Application Types *)
  MQAT_UNKNOWN    = -1;
  MQAT_NO_CONTEXT = 0;
  MQAT_CICS       = 1;
  MQAT_MVS        = 2;
  MQAT_OS390      = 2;
  MQAT_IMS        = 3;
  MQAT_OS2        = 4;
  MQAT_DOS        = 5;
  MQAT_AIX        = 6;
  MQAT_UNIX       = 6;
  MQAT_QMGR       = 7;
  MQAT_OS400      = 8;
  MQAT_WINDOWS    = 9;
  MQAT_CICS_VSE   = 10;
  MQAT_WINDOWS_NT = 11;
  MQAT_VMS        = 12;
  MQAT_GUARDIAN   = 13;
  MQAT_NSK        = 13;
  MQAT_VOS        = 14;
  MQAT_IMS_BRIDGE = 19;
  MQAT_XCF        = 20;
  MQAT_CICS_BRIDGE= 21;
  MQAT_NOTES_AGENT= 22;
  MQAT_BROKER     = 26;
  MQAT_JAVA       = 28;
  MQAT_DQM        = 29;
  MQAT_DEFAULT    = 11;
  MQAT_USER_FIRST = 65536;
  MQAT_USER_LAST  = 999999999;

  (* Group Identifier *)
  MQGI_NONE = #0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0;

  (* Message Flags *)
  MQMF_SEGMENTATION_INHIBITED = $00000000;
  MQMF_SEGMENTATION_ALLOWED   = $00000001;
  MQMF_MSG_IN_GROUP           = $00000008;
  MQMF_LAST_MSG_IN_GROUP      = $00000010;
  MQMF_SEGMENT                = $00000002;
  MQMF_LAST_SEGMENT           = $00000004;
  MQMF_NONE                   = $00000000;

  (* Message Flags Masks *)
  MQMF_REJECT_UNSUP_MASK         = $00000fff;
  MQMF_ACCEPT_UNSUP_MASK         = $fff00000;
  MQMF_ACCEPT_UNSUP_IF_XMIT_MASK = $000ff000;

  (* Original Length *)
  MQOL_UNDEFINED = -1;


  (*********************************************************************)
  (*  Values Related to MQMDE Structure                                *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQMDE_STRUC_ID = 'MDE ';

  (* Structure Version Number *)
  MQMDE_VERSION_2       = 2;
  MQMDE_CURRENT_VERSION = 2;

  (* Structure Length *)
  MQMDE_LENGTH_2 = 72;

  (* General Flags *)
  MQMDEF_NONE = $00000000;


  (*********************************************************************)
  (*  Values Related to MQOD Structure                                 *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQOD_STRUC_ID = 'OD  ';

  (* Structure Version Number *)
  MQOD_VERSION_1       = 1;
  MQOD_VERSION_2       = 2;
  MQOD_VERSION_3       = 3;
  MQOD_CURRENT_VERSION = 3;

  (* Structure Length *)
  MQOD_CURRENT_LENGTH = 336;

  (* Object Types *)
  MQOT_Q          = 1;
  MQOT_NAMELIST   = 2;
  MQOT_PROCESS    = 3;
  MQOT_Q_MGR      = 5;
  MQOT_CHANNEL    = 6;
  MQOT_RESERVED_1 = 7;

  (* Extended Object Types *)
  MQOT_ALL               = 1001;
  MQOT_ALIAS_Q           = 1002;
  MQOT_MODEL_Q           = 1003;
  MQOT_LOCAL_Q           = 1004;
  MQOT_REMOTE_Q          = 1005;
  MQOT_SENDER_CHANNEL    = 1007;
  MQOT_SERVER_CHANNEL    = 1008;
  MQOT_REQUESTER_CHANNEL = 1009;
  MQOT_RECEIVER_CHANNEL  = 1010;
  MQOT_CURRENT_CHANNEL   = 1011;
  MQOT_SAVED_CHANNEL     = 1012;
  MQOT_SVRCONN_CHANNEL   = 1013;
  MQOT_CLNTCONN_CHANNEL  = 1014;

  (* Security Identifier *)
  MQSID_NONE = #0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0;

  (* Security Identifier Type *)
  MQSIDT_NONE           = '#$00';
  MQSIDT_NT_SECURITY_ID = '#$01';


  (*********************************************************************)
  (*  Values Related to MQPMO Structure                                *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQPMO_STRUC_ID = 'PMO ';

  (* Structure Version Number *)
  MQPMO_VERSION_1       = 1;
  MQPMO_VERSION_2       = 2;
  MQPMO_CURRENT_VERSION = 2;

  (* Structure Length *)
  MQPMO_CURRENT_LENGTH = 152;

  (* Put-Message Options *)
  MQPMO_SYNCPOINT                = $00000002;
  MQPMO_NO_SYNCPOINT             = $00000004;
  MQPMO_NEW_MSG_ID               = $00000040;
  MQPMO_NEW_CORREL_ID            = $00000080;
  MQPMO_LOGICAL_ORDER            = $00008000;
  MQPMO_NO_CONTEXT               = $00004000;
  MQPMO_DEFAULT_CONTEXT          = $00000020;
  MQPMO_PASS_IDENTITY_CONTEXT    = $00000100;
  MQPMO_PASS_ALL_CONTEXT         = $00000200;
  MQPMO_SET_IDENTITY_CONTEXT     = $00000400;
  MQPMO_SET_ALL_CONTEXT          = $00000800;
  MQPMO_ALTERNATE_USER_AUTHORITY = $00001000;
  MQPMO_FAIL_IF_QUIESCING        = $00002000;
  MQPMO_NONE                     = $00000000;

  (* Put Message Record Fields *)
  MQPMRF_MSG_ID           = 1;
  MQPMRF_CORREL_ID        = 2;
  MQPMRF_GROUP_ID         = 4;
  MQPMRF_FEEDBACK         = 8;
  MQPMRF_ACCOUNTING_TOKEN = 16;
  MQPMRF_NONE             = 0;

  (*********************************************************************)
  (*  Values Related to MQRFH Structure                                *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQRFH_STRUC_ID = 'RFH ';

  (* Structure Version Number *)
  MQRFH_VERSION_1 = 1;
  MQRFH_VERSION_2 = 2;

  (* Structure Length *)
  MQRFH_STRUC_LENGTH_FIXED   = 32;
  MQRFH_STRUC_LENGTH_FIXED_2 = 36;

  (* Flags *)
  MQRFH_NONE = $00000000;

  (* Names for Name/Value String *)
  MQNVS_APPL_TYPE = 'OPT_APP_GRP ';
  MQNVS_MSG_TYPE  = 'OPT_MSG_TYPE ';



  (*********************************************************************)
  (*  Values Related to MQRMH Structure                                *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQRMH_STRUC_ID = 'RMH ';

  (* Structure Version Number *)
  MQRMH_VERSION_1       = 1;
  MQRMH_CURRENT_VERSION = 1;

  (* Flags *)
  MQRMHF_LAST     = $00000001;
  MQRMHF_NOT_LAST = $00000000;

  (* Object Instance Identifier *)
  MQOII_NONE = #0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0;


  (*********************************************************************)
  (*  Values Related to MQTM Structure                                 *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQTM_STRUC_ID = 'TM  ';

  (* Structure Version Number *)
  MQTM_VERSION_1       = 1;
  MQTM_CURRENT_VERSION = 1;


  (*********************************************************************)
  (*  Values Related to MQTMC2 Structure                               *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQTMC_STRUC_ID = 'TMC ';

  (* Structure Version Number *)
  MQTMC_VERSION_1       = '   1';
  MQTMC_VERSION_2       = '   2';
  MQTMC_CURRENT_VERSION = '   2';


  (*********************************************************************)
  (*  Values Related to MQWIH Structure                                *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQWIH_STRUC_ID = 'WIH ';

  (* Structure Version Number *)
  MQWIH_VERSION_1       = 1;
  MQWIH_CURRENT_VERSION = 1;

  (* Structure Length *)
  MQWIH_LENGTH_1       = 120;
  MQWIH_CURRENT_LENGTH = 120;

  (* Flags *)
  MQWIH_NONE = 0;


  (*********************************************************************)
  (*  Values Related to MQXQH Structure                                *)
  (*********************************************************************)

  (* Structure Identifier *)
  MQXQH_STRUC_ID = 'XQH ';

  (* Structure Version Number *)
  MQXQH_VERSION_1       = 1;
  MQXQH_CURRENT_VERSION = 1;


  (*********************************************************************)
  (*  Values Related to MQCLOSE Function                               *)
  (*********************************************************************)

  (* Object Handle *)
  MQHO_UNUSABLE_HOBJ = -1;
  MQHO_NONE          = 0;

  (* Close Options *)
  MQCO_NONE         = 0;
  MQCO_DELETE       = 1;
  MQCO_DELETE_PURGE = 2;


  (*********************************************************************)
  (*  Values Related to MQINQ Function                                 *)
  (*********************************************************************)

  (* Character-Attribute Selectors *)
  MQCA_ALTERATION_DATE       = 2027;
  MQCA_ALTERATION_TIME       = 2028;
  MQCA_APPL_ID               = 2001;
  MQCA_BACKOUT_REQ_Q_NAME    = 2019;
  MQCA_BASE_Q_NAME           = 2002;
  MQCA_CF_STRUC_NAME         = 2039;
  MQCA_CHANNEL_AUTO_DEF_EXIT = 2026;
  MQCA_CLUSTER_DATE          = 2037;
  MQCA_CLUSTER_NAME          = 2029;
  MQCA_CLUSTER_NAMELIST      = 2030;
  MQCA_CLUSTER_Q_MGR_NAME    = 2031;
  MQCA_CLUSTER_TIME          = 2038;
  MQCA_CLUSTER_WORKLOAD_DATA = 2034;
  MQCA_CLUSTER_WORKLOAD_EXIT = 2033;
  MQCA_COMMAND_INPUT_Q_NAME  = 2003;
  MQCA_CREATION_DATE         = 2004;
  MQCA_CREATION_TIME         = 2005;
  MQCA_DEAD_LETTER_Q_NAME    = 2006;
  MQCA_DEF_XMIT_Q_NAME       = 2025;
  MQCA_ENV_DATA              = 2007;
  MQCA_FIRST                 = 2001;
  MQCA_IGQ_USER_ID           = 2041;
  MQCA_INITIATION_Q_NAME     = 2008;
  MQCA_LAST                  = 4000;
  MQCA_LAST_USED             = 2041;
  MQCA_NAMELIST_DESC         = 2009;
  MQCA_NAMELIST_NAME         = 2010;
  MQCA_NAMES                 = 2020;
  MQCA_PROCESS_DESC          = 2011;
  MQCA_PROCESS_NAME          = 2012;
  MQCA_Q_DESC                = 2013;
  MQCA_Q_MGR_DESC            = 2014;
  MQCA_Q_MGR_IDENTIFIER      = 2032;
  MQCA_Q_MGR_NAME            = 2015;
  MQCA_Q_NAME                = 2016;
  MQCA_QSG_NAME              = 2040;
  MQCA_REMOTE_Q_MGR_NAME     = 2017;
  MQCA_REMOTE_Q_NAME         = 2018;
  MQCA_REPOSITORY_NAME       = 2035;
  MQCA_REPOSITORY_NAMELIST   = 2036;
  MQCA_STORAGE_CLASS         = 2022;
  MQCA_TRIGGER_DATA          = 2023;
  MQCA_USER_DATA             = 2021;
  MQCA_USER_LIST             = 4000;
  MQCA_XMIT_Q_NAME           = 2024;

  (* Integer-Attribute Selectors *)
  MQIA_APPL_TYPE                = 1;
  MQIA_ARCHIVE                  = 60;
  MQIA_AUTHORITY_EVENT          = 47;
  MQIA_BACKOUT_THRESHOLD        = 22;
  MQIA_CHANNEL_AUTO_DEF         = 55;
  MQIA_CHANNEL_AUTO_DEF_EVENT   = 56;
  MQIA_CLUSTER_Q_TYPE           = 59;
  MQIA_CLUSTER_WORKLOAD_LENGTH  = 58;
  MQIA_CODED_CHAR_SET_ID        = 2;
  MQIA_COMMAND_LEVEL            = 31;
  MQIA_CURRENT_Q_DEPTH          = 3;
  MQIA_DEF_BIND                 = 61;
  MQIA_DEF_INPUT_OPEN_OPTION    = 4;
  MQIA_DEF_PERSISTENCE          = 5;
  MQIA_DEF_PRIORITY             = 6;
  MQIA_DEFINITION_TYPE          = 7;
  MQIA_DIST_LISTS               = 34;
  MQIA_FIRST                    = 1;
  MQIA_HARDEN_GET_BACKOUT       = 8;
  MQIA_HIGH_Q_DEPTH             = 36;
  MQIA_IGQ_PUT_AUTHORITY        = 65;
  MQIA_INDEX_TYPE               = 57;
  MQIA_INHIBIT_EVENT            = 48;
  MQIA_INHIBIT_GET              = 9;
  MQIA_INHIBIT_PUT              = 10;
  MQIA_INTRA_GROUP_QUEUING      = 64;
  MQIA_LAST                     = 2000;
  MQIA_LAST_USED                = 65;
  MQIA_LOCAL_EVENT              = 49;
  MQIA_MAX_HANDLES              = 11;
  MQIA_MAX_MSG_LENGTH           = 13;
  MQIA_MAX_PRIORITY             = 14;
  MQIA_MAX_Q_DEPTH              = 15;
  MQIA_MAX_UNCOMMITTED_MSGS     = 33;
  MQIA_MSG_DELIVERY_SEQUENCE    = 16;
  MQIA_MSG_DEQ_COUNT            = 38;
  MQIA_MSG_ENQ_COUNT            = 37;
  MQIA_NAME_COUNT               = 19;
  MQIA_OPEN_INPUT_COUNT         = 17;
  MQIA_OPEN_OUTPUT_COUNT        = 18;
  MQIA_PERFORMANCE_EVENT        = 53;
  MQIA_PLATFORM                 = 32;
  MQIA_Q_DEPTH_HIGH_EVENT       = 43;
  MQIA_Q_DEPTH_HIGH_LIMIT       = 40;
  MQIA_Q_DEPTH_LOW_EVENT        = 44;
  MQIA_Q_DEPTH_LOW_LIMIT        = 41;
  MQIA_Q_DEPTH_MAX_EVENT        = 42;
  MQIA_Q_SERVICE_INTERVAL       = 54;
  MQIA_Q_SERVICE_INTERVAL_EVENT = 46;
  MQIA_Q_TYPE                   = 20;
  MQIA_QSG_DISP                 = 63;
  MQIA_REMOTE_EVENT             = 50;
  MQIA_RETENTION_INTERVAL       = 21;
  MQIA_SCOPE                    = 45;
  MQIA_SHAREABILITY             = 23;
  MQIA_START_STOP_EVENT         = 52;
  MQIA_SYNCPOINT                = 30;
  MQIA_TIME_SINCE_RESET         = 35;
  MQIA_TRIGGER_CONTROL          = 24;
  MQIA_TRIGGER_DEPTH            = 29;
  MQIA_TRIGGER_INTERVAL         = 25;
  MQIA_TRIGGER_MSG_PRIORITY     = 26;
  MQIA_TRIGGER_TYPE             = 28;
  MQIA_USAGE                    = 12;
  MQIA_USER_LIST                = 2000;

  (* Integer Attribute Value Denoting "Not Applicable" *)
  MQIAV_NOT_APPLICABLE = -1;
  MQIAV_UNDEFINED      = -2;


  (*********************************************************************)
  (*  Values Related to MQOPEN Function                                *)
  (*********************************************************************)

  (* Open Options *)
  MQOO_INPUT_AS_Q_DEF           = $00000001;
  MQOO_INPUT_SHARED             = $00000002;
  MQOO_INPUT_EXCLUSIVE          = $00000004;
  MQOO_BROWSE                   = $00000008;
  MQOO_OUTPUT                   = $00000010;
  MQOO_INQUIRE                  = $00000020;
  MQOO_SET                      = $00000040;
  MQOO_BIND_ON_OPEN             = $00004000;
  MQOO_BIND_NOT_FIXED           = $00008000;
  MQOO_BIND_AS_Q_DEF            = $00000000;
  MQOO_SAVE_ALL_CONTEXT         = $00000080;
  MQOO_PASS_IDENTITY_CONTEXT    = $00000100;
  MQOO_PASS_ALL_CONTEXT         = $00000200;
  MQOO_SET_IDENTITY_CONTEXT     = $00000400;
  MQOO_SET_ALL_CONTEXT          = $00000800;
  MQOO_ALTERNATE_USER_AUTHORITY = $00001000;
  MQOO_FAIL_IF_QUIESCING        = $00002000;
  MQOO_RESOLVE_NAMES            = $00010000;


  (*********************************************************************)
  (*  Values Related to All Functions                                  *)
  (*********************************************************************)
  (* Connection Handle *)
  MQHC_DEF_HCONN      = 0;
  MQHC_UNUSABLE_HCONN = -1;

  (* String Lengths *)
  MQ_ABEND_CODE_LENGTH         = 4;
  MQ_ACCOUNTING_TOKEN_LENGTH   = 32;
  MQ_APPL_IDENTITY_DATA_LENGTH = 32;
  MQ_APPL_NAME_LENGTH          = 28;
  MQ_APPL_ORIGIN_DATA_LENGTH   = 4;
  MQ_ATTENTION_ID_LENGTH       = 4;
  MQ_AUTHENTICATOR_LENGTH      = 8;
  MQ_BRIDGE_NAME_LENGTH        = 24;
  MQ_CANCEL_CODE_LENGTH        = 4;
  MQ_CF_STRUC_NAME_LENGTH      = 12;
  MQ_CHANNEL_DATE_LENGTH       = 12;
  MQ_CHANNEL_DESC_LENGTH       = 64;
  MQ_CHANNEL_NAME_LENGTH       = 20;
  MQ_CHANNEL_TIME_LENGTH       = 8;
  MQ_CLUSTER_NAME_LENGTH       = 48;
  MQ_CONN_NAME_LENGTH          = 264;
  MQ_CONN_TAG_LENGTH           = 128;
  MQ_CORREL_ID_LENGTH          = 24;
  MQ_CREATION_DATE_LENGTH      = 12;
  MQ_CREATION_TIME_LENGTH      = 8;
  MQ_DATE_LENGTH               = 12;
  MQ_EXIT_DATA_LENGTH          = 32;
  MQ_EXIT_NAME_LENGTH          = 128;
  MQ_EXIT_USER_AREA_LENGTH     = 16;
  MQ_FACILITY_LENGTH           = 8;
  MQ_FACILITY_LIKE_LENGTH      = 4;
  MQ_FORMAT_LENGTH             = 8;
  MQ_FUNCTION_LENGTH           = 4;
  MQ_GROUP_ID_LENGTH           = 24;
  MQ_LTERM_OVERRIDE_LENGTH     = 8;
  MQ_LUWID_LENGTH              = 16;
  MQ_MAX_EXIT_NAME_LENGTH      = 128;
  MQ_MAX_MCA_USER_ID_LENGTH    = 64;
  MQ_MCA_JOB_NAME_LENGTH       = 28;
  MQ_MCA_NAME_LENGTH           = 20;
  MQ_MCA_USER_ID_LENGTH        = 64;
  MQ_MFS_MAP_NAME_LENGTH       = 8;
  MQ_MODE_NAME_LENGTH          = 8;
  MQ_MSG_HEADER_LENGTH         = 4000;
  MQ_MSG_ID_LENGTH             = 24;
  MQ_MSG_TOKEN_LENGTH          = 16;
  MQ_NAMELIST_DESC_LENGTH      = 64;
  MQ_NAMELIST_NAME_LENGTH      = 48;
  MQ_OBJECT_INSTANCE_ID_LENGTH = 24;
  MQ_OBJECT_NAME_LENGTH        = 48;
  MQ_PASSWORD_LENGTH           = 12;
  MQ_PROCESS_APPL_ID_LENGTH    = 256;
  MQ_PROCESS_DESC_LENGTH       = 64;
  MQ_PROCESS_ENV_DATA_LENGTH   = 128;
  MQ_PROCESS_NAME_LENGTH       = 48;
  MQ_PROCESS_USER_DATA_LENGTH  = 128;
  MQ_PUT_APPL_NAME_LENGTH      = 28;
  MQ_PUT_DATE_LENGTH           = 8;
  MQ_PUT_TIME_LENGTH           = 8;
  MQ_Q_DESC_LENGTH             = 64;
  MQ_Q_MGR_DESC_LENGTH         = 64;
  MQ_Q_MGR_IDENTIFIER_LENGTH   = 48;
  MQ_Q_MGR_NAME_LENGTH         = 48;
  MQ_Q_NAME_LENGTH             = 48;
  MQ_QSG_NAME_LENGTH           = 4;
  MQ_REMOTE_SYS_ID_LENGTH      = 4;
  MQ_SECURITY_ID_LENGTH        = 40;
  MQ_SERVICE_NAME_LENGTH       = 32;
  MQ_SERVICE_STEP_LENGTH       = 8;
  MQ_SHORT_CONN_NAME_LENGTH    = 20;
  MQ_START_CODE_LENGTH         = 4;
  MQ_STORAGE_CLASS_LENGTH      = 8;
  MQ_TIME_LENGTH               = 8;
  MQ_TOTAL_EXIT_DATA_LENGTH    = 999;
  MQ_TOTAL_EXIT_NAME_LENGTH    = 999;
  MQ_TP_NAME_LENGTH            = 64;
  MQ_TRAN_INSTANCE_ID_LENGTH   = 16;
  MQ_TRANSACTION_ID_LENGTH     = 4;
  MQ_TRIGGER_DATA_LENGTH       = 64;
  MQ_USER_ID_LENGTH            = 12;

  (* Completion Codes *)
  MQCC_OK      = 0;
  MQCC_WARNING = 1;
  MQCC_FAILED  = 2;
  MQCC_UNKNOWN = -1;

  (* Reason Codes *)
  MQRC_NONE                      = 0;
  MQRC_ALIAS_BASE_Q_TYPE_ERROR   = 2001;
  MQRC_ALREADY_CONNECTED         = 2002;
  MQRC_BACKED_OUT                = 2003;
  MQRC_BUFFER_ERROR              = 2004;
  MQRC_BUFFER_LENGTH_ERROR       = 2005;
  MQRC_CHAR_ATTR_LENGTH_ERROR    = 2006;
  MQRC_CHAR_ATTRS_ERROR          = 2007;
  MQRC_CHAR_ATTRS_TOO_SHORT      = 2008;
  MQRC_CONNECTION_BROKEN         = 2009;
  MQRC_DATA_LENGTH_ERROR         = 2010;
  MQRC_DYNAMIC_Q_NAME_ERROR      = 2011;
  MQRC_ENVIRONMENT_ERROR         = 2012;
  MQRC_EXPIRY_ERROR              = 2013;
  MQRC_FEEDBACK_ERROR            = 2014;
  MQRC_GET_INHIBITED             = 2016;
  MQRC_HANDLE_NOT_AVAILABLE      = 2017;
  MQRC_HCONN_ERROR               = 2018;
  MQRC_HOBJ_ERROR                = 2019;
  MQRC_INHIBIT_VALUE_ERROR       = 2020;
  MQRC_INT_ATTR_COUNT_ERROR      = 2021;
  MQRC_INT_ATTR_COUNT_TOO_SMALL  = 2022;
  MQRC_INT_ATTRS_ARRAY_ERROR     = 2023;
  MQRC_SYNCPOINT_LIMIT_REACHED   = 2024;
  MQRC_MAX_CONNS_LIMIT_REACHED   = 2025;
  MQRC_MD_ERROR                  = 2026;
  MQRC_MISSING_REPLY_TO_Q        = 2027;
  MQRC_MSG_TYPE_ERROR            = 2029;
  MQRC_MSG_TOO_BIG_FOR_Q         = 2030;
  MQRC_MSG_TOO_BIG_FOR_Q_MGR     = 2031;
  MQRC_NO_MSG_AVAILABLE          = 2033;
  MQRC_NO_MSG_UNDER_CURSOR       = 2034;
  MQRC_NOT_AUTHORIZED            = 2035;
  MQRC_NOT_OPEN_FOR_BROWSE       = 2036;
  MQRC_NOT_OPEN_FOR_INPUT        = 2037;
  MQRC_NOT_OPEN_FOR_INQUIRE      = 2038;
  MQRC_NOT_OPEN_FOR_OUTPUT       = 2039;
  MQRC_NOT_OPEN_FOR_SET          = 2040;
  MQRC_OBJECT_CHANGED            = 2041;
  MQRC_OBJECT_IN_USE             = 2042;
  MQRC_OBJECT_TYPE_ERROR         = 2043;
  MQRC_OD_ERROR                  = 2044;
  MQRC_OPTION_NOT_VALID_FOR_TYPE = 2045;
  MQRC_OPTIONS_ERROR             = 2046;
  MQRC_PERSISTENCE_ERROR         = 2047;
  MQRC_PERSISTENT_NOT_ALLOWED    = 2048;
  MQRC_PRIORITY_EXCEEDS_MAXIMUM  = 2049;
  MQRC_PRIORITY_ERROR            = 2050;
  MQRC_PUT_INHIBITED             = 2051;
  MQRC_Q_DELETED                 = 2052;
  MQRC_Q_FULL                    = 2053;
  MQRC_Q_NOT_EMPTY               = 2055;
  MQRC_Q_SPACE_NOT_AVAILABLE     = 2056;
  MQRC_Q_TYPE_ERROR              = 2057;
  MQRC_Q_MGR_NAME_ERROR          = 2058;
  MQRC_Q_MGR_NOT_AVAILABLE       = 2059;
  MQRC_REPORT_OPTIONS_ERROR      = 2061;
  MQRC_SECOND_MARK_NOT_ALLOWED   = 2062;
  MQRC_SECURITY_ERROR            = 2063;
  MQRC_SELECTOR_COUNT_ERROR      = 2065;
  MQRC_SELECTOR_LIMIT_EXCEEDED   = 2066;
  MQRC_SELECTOR_ERROR            = 2067;
  MQRC_SELECTOR_NOT_FOR_TYPE     = 2068;
  MQRC_SIGNAL_OUTSTANDING        = 2069;
  MQRC_SIGNAL_REQUEST_ACCEPTED   = 2070;
  MQRC_STORAGE_NOT_AVAILABLE     = 2071;
  MQRC_SYNCPOINT_NOT_AVAILABLE   = 2072;
  MQRC_TRIGGER_CONTROL_ERROR     = 2075;
  MQRC_TRIGGER_DEPTH_ERROR       = 2076;
  MQRC_TRIGGER_MSG_PRIORITY_ERR  = 2077;
  MQRC_TRIGGER_TYPE_ERROR        = 2078;
  MQRC_TRUNCATED_MSG_ACCEPTED    = 2079;
  MQRC_TRUNCATED_MSG_FAILED      = 2080;
  MQRC_UNKNOWN_ALIAS_BASE_Q      = 2082;
  MQRC_UNKNOWN_OBJECT_NAME       = 2085;
  MQRC_UNKNOWN_OBJECT_Q_MGR      = 2086;
  MQRC_UNKNOWN_REMOTE_Q_MGR      = 2087;
  MQRC_WAIT_INTERVAL_ERROR       = 2090;
  MQRC_XMIT_Q_TYPE_ERROR         = 2091;
  MQRC_XMIT_Q_USAGE_ERROR        = 2092;
  MQRC_NOT_OPEN_FOR_PASS_ALL     = 2093;
  MQRC_NOT_OPEN_FOR_PASS_IDENT   = 2094;
  MQRC_NOT_OPEN_FOR_SET_ALL      = 2095;
  MQRC_NOT_OPEN_FOR_SET_IDENT    = 2096;
  MQRC_CONTEXT_HANDLE_ERROR      = 2097;
  MQRC_CONTEXT_NOT_AVAILABLE     = 2098;
  MQRC_SIGNAL1_ERROR             = 2099;
  MQRC_OBJECT_ALREADY_EXISTS     = 2100;
  MQRC_OBJECT_DAMAGED            = 2101;
  MQRC_RESOURCE_PROBLEM          = 2102;
  MQRC_ANOTHER_Q_MGR_CONNECTED   = 2103;
  MQRC_UNKNOWN_REPORT_OPTION     = 2104;
  MQRC_STORAGE_CLASS_ERROR       = 2105;
  MQRC_COD_NOT_VALID_FOR_XCF_Q   = 2106;
  MQRC_XWAIT_CANCELED            = 2107;
  MQRC_XWAIT_ERROR               = 2108;
  MQRC_SUPPRESSED_BY_EXIT        = 2109;
  MQRC_FORMAT_ERROR              = 2110;
  MQRC_SOURCE_CCSID_ERROR        = 2111;
  MQRC_SOURCE_INTEGER_ENC_ERROR  = 2112;
  MQRC_SOURCE_DECIMAL_ENC_ERROR  = 2113;
  MQRC_SOURCE_FLOAT_ENC_ERROR    = 2114;
  MQRC_TARGET_CCSID_ERROR        = 2115;
  MQRC_TARGET_INTEGER_ENC_ERROR  = 2116;
  MQRC_TARGET_DECIMAL_ENC_ERROR  = 2117;
  MQRC_TARGET_FLOAT_ENC_ERROR    = 2118;
  MQRC_NOT_CONVERTED             = 2119;
  MQRC_CONVERTED_MSG_TOO_BIG     = 2120;
  MQRC_TRUNCATED                 = 2120; // This could be IBM error
  MQRC_NO_EXTERNAL_PARTICIPANTS  = 2121;
  MQRC_PARTICIPANT_NOT_AVAILABLE = 2122;
  MQRC_OUTCOME_MIXED             = 2123;
  MQRC_OUTCOME_PENDING           = 2124;
  MQRC_BRIDGE_STARTED            = 2125;
  MQRC_BRIDGE_STOPPED            = 2126;
  MQRC_ADAPTER_STORAGE_SHORTAGE  = 2127;
  MQRC_UOW_IN_PROGRESS           = 2128;
  MQRC_ADAPTER_CONN_LOAD_ERROR   = 2129;
  MQRC_ADAPTER_SERV_LOAD_ERROR   = 2130;
  MQRC_ADAPTER_DEFS_ERROR        = 2131;
  MQRC_ADAPTER_DEFS_LOAD_ERROR   = 2132;
  MQRC_ADAPTER_CONV_LOAD_ERROR   = 2133;
  MQRC_BO_ERROR                  = 2134;
  MQRC_DH_ERROR                  = 2135;
  MQRC_MULTIPLE_REASONS          = 2136;
  MQRC_OPEN_FAILED               = 2137;
  MQRC_ADAPTER_DISC_LOAD_ERROR   = 2138;
  MQRC_CNO_ERROR                 = 2139;
  MQRC_CICS_WAIT_FAILED          = 2140;
  MQRC_DLH_ERROR                 = 2141;
  MQRC_HEADER_ERROR              = 2142;
  MQRC_SOURCE_LENGTH_ERROR       = 2143;
  MQRC_TARGET_LENGTH_ERROR       = 2144;
  MQRC_SOURCE_BUFFER_ERROR       = 2145;
  MQRC_TARGET_BUFFER_ERROR       = 2146;
  MQRC_IIH_ERROR                 = 2148;
  MQRC_PCF_ERROR                 = 2149;
  MQRC_DBCS_ERROR                = 2150;
  MQRC_OBJECT_NAME_ERROR         = 2152;
  MQRC_OBJECT_Q_MGR_NAME_ERROR   = 2153;
  MQRC_RECS_PRESENT_ERROR        = 2154;
  MQRC_OBJECT_RECORDS_ERROR      = 2155;
  MQRC_RESPONSE_RECORDS_ERROR    = 2156;
  MQRC_ASID_MISMATCH             = 2157;
  MQRC_PMO_RECORD_FLAGS_ERROR    = 2158;
  MQRC_PUT_MSG_RECORDS_ERROR     = 2159;
  MQRC_CONN_ID_IN_USE            = 2160;
  MQRC_Q_MGR_QUIESCING           = 2161;
  MQRC_Q_MGR_STOPPING            = 2162;
  MQRC_DUPLICATE_RECOV_COORD     = 2163;
  MQRC_PMO_ERROR                 = 2173;
  MQRC_API_EXIT_NOT_FOUND        = 2182;
  MQRC_API_EXIT_LOAD_ERROR       = 2183;
  MQRC_REMOTE_Q_NAME_ERROR       = 2184;
  MQRC_INCONSISTENT_PERSISTENCE  = 2185;
  MQRC_GMO_ERROR                 = 2186;
  MQRC_CICS_BRIDGE_RESTRICTION   = 2187;
  MQRC_STOPPED_BY_CLUSTER_EXIT   = 2188;
  MQRC_CLUSTER_RESOLUTION_ERROR  = 2189;
  MQRC_CONVERTED_STRING_TOO_BIG  = 2190;
  MQRC_TMC_ERROR                 = 2191;
  MQRC_PAGESET_FULL              = 2192;
  MQRC_STORAGE_MEDIUM_FULL       = 2192; // This could be IBM error
  MQRC_PAGESET_ERROR             = 2193;
  MQRC_NAME_NOT_VALID_FOR_TYPE   = 2194;
  MQRC_UNEXPECTED_ERROR          = 2195;
  MQRC_UNKNOWN_XMIT_Q            = 2196;
  MQRC_UNKNOWN_DEF_XMIT_Q        = 2197;
  MQRC_DEF_XMIT_Q_TYPE_ERROR     = 2198;
  MQRC_DEF_XMIT_Q_USAGE_ERROR    = 2199;
  MQRC_NAME_IN_USE               = 2201;
  MQRC_CONNECTION_QUIESCING      = 2202;
  MQRC_CONNECTION_STOPPING       = 2203;
  MQRC_ADAPTER_NOT_AVAILABLE     = 2204;
  MQRC_MSG_ID_ERROR              = 2206;
  MQRC_CORREL_ID_ERROR           = 2207;
  MQRC_FILE_SYSTEM_ERROR         = 2208;
  MQRC_NO_MSG_LOCKED             = 2209;
  MQRC_FILE_NOT_AUDITED          = 2216;
  MQRC_CONNECTION_NOT_AUTHORIZED = 2217;
  MQRC_MSG_TOO_BIG_FOR_CHANNEL   = 2218;
  MQRC_CALL_IN_PROGRESS          = 2219;
  MQRC_RMH_ERROR                 = 2220;
  MQRC_Q_MGR_ACTIVE              = 2222;
  MQRC_Q_MGR_NOT_ACTIVE          = 2223;
  MQRC_Q_DEPTH_HIGH              = 2224;
  MQRC_Q_DEPTH_LOW               = 2225;
  MQRC_Q_SERVICE_INTERVAL_HIGH   = 2226;
  MQRC_Q_SERVICE_INTERVAL_OK     = 2227;
  MQRC_UNIT_OF_WORK_NOT_STARTED  = 2232;
  MQRC_CHANNEL_AUTO_DEF_OK       = 2233;
  MQRC_CHANNEL_AUTO_DEF_ERROR    = 2234;
  MQRC_CFH_ERROR                 = 2235;
  MQRC_CFIL_ERROR                = 2236;
  MQRC_CFIN_ERROR                = 2237;
  MQRC_CFSL_ERROR                = 2238;
  MQRC_CFST_ERROR                = 2239;
  MQRC_INCOMPLETE_GROUP          = 2241;
  MQRC_INCOMPLETE_MSG            = 2242;
  MQRC_INCONSISTENT_CCSIDS       = 2243;
  MQRC_INCONSISTENT_ENCODINGS    = 2244;
  MQRC_INCONSISTENT_UOW          = 2245;
  MQRC_INVALID_MSG_UNDER_CURSOR  = 2246;
  MQRC_MATCH_OPTIONS_ERROR       = 2247;
  MQRC_MDE_ERROR                 = 2248;
  MQRC_MSG_FLAGS_ERROR           = 2249;
  MQRC_MSG_SEQ_NUMBER_ERROR      = 2250;
  MQRC_OFFSET_ERROR              = 2251;
  MQRC_ORIGINAL_LENGTH_ERROR     = 2252;
  MQRC_SEGMENT_LENGTH_ZERO       = 2253;
  MQRC_UOW_NOT_AVAILABLE         = 2255;
  MQRC_WRONG_GMO_VERSION         = 2256;
  MQRC_WRONG_MD_VERSION          = 2257;
  MQRC_GROUP_ID_ERROR            = 2258;
  MQRC_INCONSISTENT_BROWSE       = 2259;
  MQRC_XQH_ERROR                 = 2260;
  MQRC_SRC_ENV_ERROR             = 2261;
  MQRC_SRC_NAME_ERROR            = 2262;
  MQRC_DEST_ENV_ERROR            = 2263;
  MQRC_DEST_NAME_ERROR           = 2264;
  MQRC_TM_ERROR                  = 2265;
  MQRC_CLUSTER_EXIT_ERROR        = 2266;
  MQRC_CLUSTER_EXIT_LOAD_ERROR   = 2267;
  MQRC_CLUSTER_PUT_INHIBITED     = 2268;
  MQRC_CLUSTER_RESOURCE_ERROR    = 2269;
  MQRC_NO_DESTINATIONS_AVAILABLE = 2270;
  MQRC_CONN_TAG_IN_USE           = 2271;
  MQRC_PARTIALLY_CONVERTED       = 2272;
  MQRC_CONNECTION_ERROR          = 2273;
  MQRC_OPTION_ENVIRONMENT_ERROR  = 2274;
  MQRC_CD_ERROR                  = 2277;
  MQRC_CLIENT_CONN_ERROR         = 2278;
  MQRC_CHANNEL_STOPPED_BY_USER   = 2279;
  MQRC_HCONFIG_ERROR             = 2280;
  MQRC_FUNCTION_ERROR            = 2281;
  MQRC_CHANNEL_STARTED           = 2282;
  MQRC_CHANNEL_STOPPED           = 2283;
  MQRC_CHANNEL_CONV_ERROR        = 2284;
  MQRC_SERVICE_NOT_AVAILABLE     = 2285;
  MQRC_INITIALIZATION_FAILED     = 2286;
  MQRC_TERMINATION_FAILED        = 2287;
  MQRC_UNKNOWN_Q_NAME            = 2288;
  MQRC_SERVICE_ERROR             = 2289;
  MQRC_Q_ALREADY_EXISTS          = 2290;
  MQRC_USER_ID_NOT_AVAILABLE     = 2291;
  MQRC_UNKNOWN_ENTITY            = 2292;
  MQRC_UNKNOWN_AUTH_ENTITY       = 2293;
  MQRC_UNKNOWN_REF_OBJECT        = 2294;
  MQRC_CHANNEL_ACTIVATED         = 2295;
  MQRC_CHANNEL_NOT_ACTIVATED     = 2296;
  MQRC_UOW_CANCELED              = 2297;
  MQRC_FUNCTION_NOT_SUPPORTED    = 2298;
  MQRC_SELECTOR_TYPE_ERROR       = 2299;
  MQRC_COMMAND_TYPE_ERROR        = 2300;
  MQRC_MULTIPLE_INSTANCE_ERROR   = 2301;
  MQRC_SYSTEM_ITEM_NOT_ALTERABLE = 2302;
  MQRC_BAG_CONVERSION_ERROR      = 2303;
  MQRC_SELECTOR_OUT_OF_RANGE     = 2304;
  MQRC_SELECTOR_NOT_UNIQUE       = 2305;
  MQRC_INDEX_NOT_PRESENT         = 2306;
  MQRC_STRING_ERROR              = 2307;
  MQRC_ENCODING_NOT_SUPPORTED    = 2308;
  MQRC_SELECTOR_NOT_PRESENT      = 2309;
  MQRC_OUT_SELECTOR_ERROR        = 2310;
  MQRC_STRING_TRUNCATED          = 2311;
  MQRC_SELECTOR_WRONG_TYPE       = 2312;
  MQRC_INCONSISTENT_ITEM_TYPE    = 2313;
  MQRC_INDEX_ERROR               = 2314;
  MQRC_SYSTEM_BAG_NOT_ALTERABLE  = 2315;
  MQRC_ITEM_COUNT_ERROR          = 2316;
  MQRC_FORMAT_NOT_SUPPORTED      = 2317;
  MQRC_SELECTOR_NOT_SUPPORTED    = 2318;
  MQRC_ITEM_VALUE_ERROR          = 2319;
  MQRC_HBAG_ERROR                = 2320;
  MQRC_PARAMETER_MISSING         = 2321;
  MQRC_CMD_SERVER_NOT_AVAILABLE  = 2322;
  MQRC_STRING_LENGTH_ERROR       = 2323;
  MQRC_INQUIRY_COMMAND_ERROR     = 2324;
  MQRC_NESTED_BAG_NOT_SUPPORTED  = 2325;
  MQRC_BAG_WRONG_TYPE            = 2326;
  MQRC_ITEM_TYPE_ERROR           = 2327;
  MQRC_SYSTEM_BAG_NOT_DELETABLE  = 2328;
  MQRC_SYSTEM_ITEM_NOT_DELETABLE = 2329;
  MQRC_CODED_CHAR_SET_ID_ERROR   = 2330;
  MQRC_MSG_TOKEN_ERROR           = 2331;
  MQRC_MISSING_WIH               = 2332;
  MQRC_WIH_ERROR                 = 2333;
  MQRC_RFH_ERROR                 = 2334;
  MQRC_RFH_STRING_ERROR          = 2335;
  MQRC_RFH_COMMAND_ERROR         = 2336;
  MQRC_RFH_PARM_ERROR            = 2337;
  MQRC_RFH_DUPLICATE_PARM        = 2338;
  MQRC_RFH_PARM_MISSING          = 2339;
  MQRC_CHAR_CONVERSION_ERROR     = 2340;
  MQRC_UCS2_CONVERSION_ERROR     = 2341;
  MQRC_DB2_NOT_AVAILABLE         = 2342;
  MQRC_OBJECT_NOT_UNIQUE         = 2343;
  MQRC_CONN_TAG_NOT_RELEASED     = 2344;
  MQRC_CF_NOT_AVAILABLE          = 2345;
  MQRC_CF_STRUC_IN_USE           = 2346;
  MQRC_CF_STRUC_LIST_HDR_IN_USE  = 2347;
  MQRC_CF_STRUC_AUTH_FAILED      = 2348;
  MQRC_CF_STRUC_ERROR            = 2349;
  MQRC_CONN_TAG_NOT_USABLE       = 2350;
  MQRC_GLOBAL_UOW_CONFLICT       = 2351;
  MQRC_LOCAL_UOW_CONFLICT        = 2352;
  MQRC_HANDLE_IN_USE_FOR_UOW     = 2353;
  MQRC_UOW_ENLISTMENT_ERROR      = 2354;
  MQRC_UOW_MIX_NOT_SUPPORTED     = 2355;
  MQRC_WXP_ERROR                 = 2356;
  MQRC_CURRENT_RECORD_ERROR      = 2357;
  MQRC_NEXT_OFFSET_ERROR         = 2358;
  MQRC_NO_RECORD_AVAILABLE       = 2359;
  MQRC_OBJECT_LEVEL_INCOMPATIBLE = 2360;
  MQRC_NEXT_RECORD_ERROR         = 2361;

  MQRC_APPL_FIRST                = 900;
  MQRC_APPL_LAST                 = 999;


  (*********************************************************************)
  (*  Values Related to Queue Attributes                               *)
  (*********************************************************************)

  (* Queue Types *)
  MQQT_LOCAL     = 1;
  MQQT_MODEL     = 2;
  MQQT_ALIAS     = 3;
  MQQT_REMOTE    = 6;
  MQQT_CLUSTER   = 7;

  (* Cluster Queue Types *)
  MQCQT_LOCAL_Q     = 1;
  MQCQT_ALIAS_Q     = 2;
  MQCQT_REMOTE_Q    = 3;
  MQCQT_Q_MGR_ALIAS = 4;

  (* Extended Queue Types *)
  MQQT_ALL = 1001;

  (* Queue Definition Types *)
  MQQDT_PREDEFINED        = 1;
  MQQDT_PERMANENT_DYNAMIC = 2;
  MQQDT_TEMPORARY_DYNAMIC = 3;
  MQQDT_SHARED_DYNAMIC    = 4;

  (* Inhibit Get *)
  MQQA_GET_INHIBITED = 1;
  MQQA_GET_ALLOWED   = 0;

  (* Inhibit Put *)
  MQQA_PUT_INHIBITED = 1;
  MQQA_PUT_ALLOWED   = 0;

  (* Queue Shareability *)
  MQQA_SHAREABLE     = 1;
  MQQA_NOT_SHAREABLE = 0;

  (* Back-Out Hardening *)
  MQQA_BACKOUT_HARDENED     = 1;
  MQQA_BACKOUT_NOT_HARDENED = 0;

  (* Message Delivery Sequence *)
  MQMDS_PRIORITY = 0;
  MQMDS_FIFO     = 1;

  (* Trigger Control *)
  MQTC_OFF = 0;
  MQTC_ON  = 1;

  (* Trigger Types *)
  MQTT_NONE  = 0;
  MQTT_FIRST = 1;
  MQTT_EVERY = 2;
  MQTT_DEPTH = 3;

  (* Queue Usage *)
  MQUS_NORMAL       = 0;
  MQUS_TRANSMISSION = 1;

  (* Distribution Lists *)
  MQDL_SUPPORTED     = 1;
  MQDL_NOT_SUPPORTED = 0;

  (* Index Type *)
  MQIT_NONE      = 0;
  MQIT_MSG_ID    = 1;
  MQIT_CORREL_ID = 2;
  MQIT_MSG_TOKEN = 4;

  (* Default Bind *)
  MQBND_BIND_ON_OPEN   = 0;
  MQBND_BIND_NOT_FIXED = 1;

  (* Queue Sharing Group Disposition *)
  MQQSGD_Q_MGR  = 0;
  MQQSGD_COPY   = 1;
  MQQSGD_SHARED = 2;

  (*********************************************************************)
  (*  Values Related to Namelist Attributes                            *)
  (*********************************************************************)

  (* Name Count *)
  MQNC_MAX_NAMELIST_NAME_COUNT = 256;


  (*********************************************************************)
  (*  Values Related to Process-Definition Attributes                  *)
  (*********************************************************************)

  (* Application Types *)
  (* See values for "Put Application Types" under MQMD *)


  (*********************************************************************)
  (*  Values Related to Queue-Manager Attributes                       *)
  (*********************************************************************)

  (* Command Level *)
  MQCMDL_LEVEL_1   = 100;
  MQCMDL_LEVEL_101 = 101;
  MQCMDL_LEVEL_110 = 110;
  MQCMDL_LEVEL_114 = 114;
  MQCMDL_LEVEL_120 = 120;
  MQCMDL_LEVEL_200 = 200;
  MQCMDL_LEVEL_201 = 201;
  MQCMDL_LEVEL_210 = 210;
  MQCMDL_LEVEL_220 = 220;
  MQCMDL_LEVEL_221 = 221;
  MQCMDL_LEVEL_320 = 320;
  MQCMDL_LEVEL_420 = 420;
  MQCMDL_LEVEL_500 = 500;
  MQCMDL_LEVEL_510 = 510;
  MQCMDL_LEVEL_520 = 520;

  (* Platform *)
  MQPL_MVS        = 1;
  MQPL_OS390      = 1;
  MQPL_OS2        = 2;
  MQPL_AIX        = 3;
  MQPL_UNIX       = 3;
  MQPL_OS400      = 4;
  MQPL_WINDOWS    = 5;
  MQPL_WINDOWS_NT = 11;
  MQPL_VMS        = 12;
  MQPL_NSK        = 13;

  (* Syncpoint Availability *)
  MQSP_AVAILABLE     = 1;
  MQSP_NOT_AVAILABLE = 0;

  (* Channel Auto Definition *)
  MQCHAD_DISABLED = 0;
  MQCHAD_ENABLED  = 1;

  (* Intra-Group Queuing *)
  MQIGQ_DISABLED = 0;
  MQIGQ_ENABLED  = 1;

  (* Intra-Group Queuing Put Authority *)
  MQIGQPA_DEFAULT          = 1;
  MQIGQPA_CONTEXT          = 2;
  MQIGQPA_ONLY_IGQ         = 3;
  MQIGQPA_ALTERNATE_OR_IGQ = 4;

  (* Distribution Lists *)
  (* See values for "Distribution Lists" under Queue Attributes *)


type

  (*********************************************************************)
  (*  Simple Data Types                                                *)
  (*********************************************************************)

  (* Function Entry-Point and Pointer Attributes *)
//  MQENTRY   __cdecl
  MQPOINTER = Pointer;

  (* Byte Datatypes *)
  MQBYTE = byte;
  PMQBYTE = ^MQBYTE;
  MQBYTE8 = array [0..7] of MQBYTE;
  PMQBYTE8 = ^MQBYTE8;
  MQBYTE16 = array [0..15] of MQBYTE;
  PMQBYTE16 = ^MQBYTE16;
  MQBYTE24 = array [0..23] of MQBYTE;
  PMQBYTE24 = ^MQBYTE24;
  MQBYTE32 = array [0..31] of MQBYTE;
  PMQBYTE32 = ^MQBYTE32;
  MQBYTE40 = array [0..39] of MQBYTE;
  PMQBYTE40 = ^MQBYTE40;
  MQBYTE128 = array [0..127] of MQBYTE;
  PMQBYTE128 = ^MQBYTE128;

  (* Character Datatypes *)
  MQCHAR = char;
  PMQCHAR = ^MQCHAR;
  MQCHAR4 = array[0..3] of MQCHAR;
  PMQCHAR4 = ^MQCHAR4;
  MQCHAR8 = array[0..7] of MQCHAR;
  PMQCHAR8 = ^MQCHAR8;
  MQCHAR12 = array[0..11] of MQCHAR;
  PMQCHAR12 = ^MQCHAR12;
  MQCHAR20 = array[0..19] of MQCHAR;
  PMQCHAR20 = ^MQCHAR20;
  MQCHAR28 = array[0..27] of MQCHAR;
  PMQCHAR28 = ^MQCHAR28;
  MQCHAR32 = array[0..31] of MQCHAR;
  PMQCHAR32 = ^MQCHAR32;
  MQCHAR48 = array[0..47] of MQCHAR;
  PMQCHAR48 = ^MQCHAR48;
  MQCHAR64 = array[0..63] of MQCHAR;
  PMQCHAR64 = ^MQCHAR64;
  MQCHAR128 = array[0..127] of MQCHAR;
  PMQCHAR128 = ^MQCHAR128;
  MQCHAR256 = array[0..255] of MQCHAR;
  PMQCHAR256 = ^MQCHAR256;

  (* Other Datatypes *)
  MQLONG = Longint;
  PMQLONG = ^MQLONG;
  MQHCONN = MQLONG;
  PMQHCONN = ^MQHCONN;
  MQHOBJ = MQLONG ;
  PMQHOBJ = ^MQHOBJ;
  MQPTR = ^Pointer;
  PMQPTR = ^MQPTR;
  PMQVOID = ^Pointer;
  PPMQVOID = ^Pointer ;


  (*********************************************************************)
  (*  MQBO Structure -- Begin Options                                  *)
  (*********************************************************************)


  TMQBO = record
    StrucId: MQCHAR4;  (* Structure identifier *)
    Version: MQLONG;   (* Structure version number *)
    Options: MQLONG;   (* Options that control the action of MQBEGIN *)
  end;
  PMQBO = ^TMQBO;

  (*********************************************************************)
  (*  MQCIH Structure -- CICS Information Header                       *)
  (*********************************************************************)


  TMQCIH = record
    StrucId : MQCHAR4;             (* Structure identifier *)
    Version : MQLONG;              (* Structure version number *)
    StrucLength : MQLONG;          (* Length of MQCIH structure *)
    Encoding : MQLONG;             (* Reserved *)
    CodedCharSetId : MQLONG;       (* Reserved *)
    Format : MQCHAR8;              (* MQ format name of data that follows
                                      MQCIH *)
    Flags : MQLONG;                (* Flags *)
    ReturnCode : MQLONG;           (* Return code from bridge *)
    CompCode : MQLONG;             (* MQ completion code or CICS
                                      EIBRESP *)
    Reason : MQLONG;               (* MQ reason or feedback code, or CICS
                                      EIBRESP2 *)
    UOWControl : MQLONG;           (* Unit-of-work control *)
    GetWaitInterval : MQLONG;      (* Wait interval for MQGET call issued
                                      by bridge task *)
    LinkType : MQLONG;             (* Link type *)
    OutputDataLength : MQLONG;     (* Output COMMAREA data length *)
    FacilityKeepTime : MQLONG;     (* Bridge facility release time *)
    ADSDescriptor : MQLONG;        (* Send/receive ADS descriptor *)
    ConversationalTask : MQLONG;   (* Whether task can be conversational *)
    TaskEndStatus : MQLONG;        (* Status at end of task *)
    Facility : MQBYTE8;            (* Bridge facility token *)
    Function_ : MQCHAR4;           (* MQ call name or CICS EIBFN
                                      function *)
    AbendCode : MQCHAR4;           (* Abend code *)
    Authenticator : MQCHAR8;       (* Password or passticket *)
    Reserved1 : MQCHAR8;           (* Reserved *)
    ReplyToFormat : MQCHAR8;       (* MQ format name of reply message *)
    RemoteSysId : MQCHAR4;         (* Reserved *)
    RemoteTransId : MQCHAR4;       (* Reserved *)
    TransactionId : MQCHAR4;       (* Transaction to attach *)
    FacilityLike : MQCHAR4;        (* Terminal emulated attributes *)
    AttentionId : MQCHAR4;         (* AID key *)
    StartCode : MQCHAR4;           (* Transaction start code *)
    CancelCode : MQCHAR4;          (* Abend transaction code *)
    NextTransactionId : MQCHAR4;   (* Next transaction to attach *)
    Reserved2 : MQCHAR8;           (* Reserved *)
    Reserved3 : MQCHAR8;           (* Reserved *)
    CursorPosition : MQLONG;       (* Cursor position *)
    ErrorOffset : MQLONG;          (* Offset of error in message *)
    InputItem : MQLONG;            (* Reserved *)
    Reserved4 : MQLONG;            (* Reserved *)
  end;
  PMQCIH = ^TMQCIH;


  (*********************************************************************)
  (*  MQCNO Structure -- Connect Options                               *)
  (*********************************************************************)

  TMQCNO = record
    StrucId : MQCHAR4;           (* Structure identifier *)
    Version : MQLONG;            (* Structure version number *)
    Options : MQLONG;            (* Options that control the action of
                                    MQCONNX *)
    ClientConnOffset : MQLONG;   (* Offset of MQCD structure for
                                    client connection *)
    ClientConnPtr : MQPTR;       (* Address of MQCD structure for
                                    client connection *)
  end;
  PMQCNO = ^TMQCNO;


  (*********************************************************************)
  (*  MQDH Structure -- Distribution Header                            *)
  (*********************************************************************)

  TMQDH = record
    StrucId : MQCHAR4;          (* Structure identifier *)
    Version : MQLONG;           (* Structure version number *)
    StrucLength : MQLONG;       (* Length of MQDH structure plus following
                                   records *)
    Encoding : MQLONG;          (* Numeric encoding of data that follows
                                   array of MQPMR records *)
    CodedCharSetId : MQLONG;    (* Character set identifier of data that
                                   follows array of MQPMR records *)
    Format : MQCHAR8;           (* Format name of data that follows
                                   array of MQPMR records *)
    Flags : MQLONG;             (* General flags *)
    PutMsgRecFields : MQLONG;   (* Flags indicating which MQPMR
                                   fields are present *)
    RecsPresent : MQLONG;       (* Number of object records present *)
    ObjectRecOffset : MQLONG;   (* Offset of first object record from
                                   start of MQDH *)
    PutMsgRecOffset : MQLONG;   (* Offset of first put message record
                                   from start of MQDH *)
  end;
  PMQDH = ^TMQDH;


  (*********************************************************************)
  (*  MQDLH Structure -- Dead Letter Header                            *)
  (*********************************************************************)

  TMQDLH = record
    StrucId : MQCHAR4;          (* Structure identifier *)
    Version : MQLONG;           (* Structure version number *)
    Reason  : MQLONG;           (* Reason message arrived on dead-letter
                                   (undelivered-message) queue *)
    DestQName : MQCHAR48;       (* Name of original destination queue *)
    DestQMgrName : MQCHAR48;    (* Name of original destination queue
                                   manager *)
    Encoding : MQLONG;          (* Numeric encoding of data that follows
                                   MQDLH *)
    CodedCharSetId : MQLONG;    (* Character set identifier of data that
                                   follows MQDLH *)
    Format : MQCHAR8;           (* Format name of data that follows
                                   MQDLH *)
    PutApplType : MQLONG;       (* Type of application that put message on
                                   dead-letter (undelivered-message)
                                   queue *)
    PutApplName : MQCHAR28;     (* Name of application that put message on
                                   dead-letter (undelivered-message)
                                   queue *)
    PutDate : MQCHAR8;          (* Date when message was put on
                                   dead-letter (undelivered-message)
                                   queue *)
    PutTime : MQCHAR8;          (* Time when message was put on the
                                   dead-letter (undelivered-message)
                                   queue *)
  end;
  PMQDLH = ^TMQDLH;


  (*********************************************************************)
  (*  MQGMO Structure -- Get Message Options                           *)
  (*********************************************************************)

  TMQGMO = record
    StrucId : MQCHAR4;          (* Structure identifier *)
    Version : MQLONG;           (* Structure version number *)
    Options : MQLONG;           (* Options that control the action of
                                   MQGET *)
    WaitInterval : MQLONG;      (* Wait interval *)
    Signal1 : MQLONG;           (* Signal *)
    Signal2 : MQLONG;           (* Signal identifier *)
    ResolvedQName : MQCHAR48;   (* Resolved name of destination queue *)
    MatchOptions : MQLONG;      (* Options controlling selection criteria
                                   used for MQGET *)
    GroupStatus : MQCHAR;       (* Flag indicating whether message
                                   retrieved is in a group *)
    SegmentStatus : MQCHAR;     (* Flag indicating whether message
                                   retrieved is a segment of a logical
                                   message *)
    Segmentation : MQCHAR;      (* Flag indicating whether further
                                   segmentation is allowed for the message
                                   retrieved *)
    Reserved1 : MQCHAR;         (* Reserved *)
    MsgToken : MQBYTE16;        (* Message token *)
    ReturnedLength : MQLONG;    (* Length of message data returned
                                  (bytes) *)
  end;
  PMQGMO = ^TMQGMO;

  (*********************************************************************)
  (*  MQIIH Structure -- IMS Information Header                        *)
  (*********************************************************************)

  TMQIIH = record
    StrucId : MQCHAR4;          (* Structure identifier *)
    Version : MQLONG;           (* Structure version number *)
    StrucLength : MQLONG;       (* Length of MQIIH structure *)
    Encoding : MQLONG;          (* Reserved *)
    CodedCharSetId : MQLONG;    (* Reserved *)
    Format : MQCHAR8;           (* MQ format name of data that follows
                                   MQIIH *)
    Flags : MQLONG;             (* Flags *)
    LTermOverride : MQCHAR8;    (* Logical terminal override *)
    MFSMapName : MQCHAR8;       (* Message format services map name *)
    ReplyToFormat : MQCHAR8;    (* MQ format name of reply message *)
    Authenticator : MQCHAR8;    (* RACF password or passticket *)
    TranInstanceId : MQBYTE16;  (* Transaction instance identifier *)
    TranState : MQCHAR;         (* Transaction state *)
    CommitMode : MQCHAR;        (* Commit mode *)
    SecurityScope : MQCHAR;     (* Security scope *)
    Reserved : MQCHAR;          (* Reserved *)
  end;
  PMQIIH = ^TMQIIH;


  (*********************************************************************)
  (*  MQMD Structure -- Message Descriptor                             *)
  (*********************************************************************)

  TMQMD = record
    StrucId : MQCHAR4;           (* Structure identifier *)
    Version : MQLONG;            (* Structure version number *)
    Report : MQLONG;             (* Options for report messages *)
    MsgType : MQLONG;            (* Message type *)
    Expiry : MQLONG;             (* Message lifetime *)
    Feedback : MQLONG;           (* Feedback or reason code *)
    Encoding : MQLONG;           (* Numeric encoding of message data *)
    CodedCharSetId : MQLONG;     (* Character set identifier of message
                                     data *)
    Format : MQCHAR8;            (* Format name of message data *)
    Priority : MQLONG;           (* Message priority *)
    Persistence : MQLONG;        (* Message persistence *)
    MsgId : MQBYTE24;            (* Message identifier *)
    CorrelId : MQBYTE24;         (* Correlation identifier *)
    BackoutCount : MQLONG;       (* Backout counter *)
    ReplyToQ : MQCHAR48;         (* Name of reply queue *)
    ReplyToQMgr : MQCHAR48;      (* Name of reply queue manager *)
    UserIdentifier : MQCHAR12;   (* User identifier *)
    AccountingToken : MQBYTE32;  (* Accounting token *)
    ApplIdentityData : MQCHAR32; (* Application data relating to
                                    identity *)
    PutApplType : MQLONG;        (* Type of application that put the
                                    message *)
    PutApplName : MQCHAR28;      (* Name of application that put the
                                    message *)
    PutDate : MQCHAR8;           (* Date when message was put *)
    PutTime : MQCHAR8;           (* Time when message was put *)
    ApplOriginData : MQCHAR4;    (* Application data relating to
                                    origin *)
    GroupId : MQBYTE24;          (* Group identifier *)
    MsgSeqNumber : MQLONG;       (* Sequence number of logical message
                                   within group *)
    Offset : MQLONG;             (* Offset of data in physical message
                                    from start of logical message *)
    MsgFlags : MQLONG;           (* Message flags *)
    OriginalLength: MQLONG;      (* Length of original message *)
  end;
  PMQMD = ^TMQMD;


  (*********************************************************************)
  (*  MQMDE Structure -- Message Descriptor Extension                  *)
  (*********************************************************************)

  TMQMDE = record
    StrucId : MQCHAR4;         (* Structure identifier *)
    Version : MQLONG;          (* Structure version number *)
    StrucLength : MQLONG;      (* Length of MQMDE structure *)
    Encoding : MQLONG;         (* Numeric encoding of data that follows
                                  MQMDE *)
    CodedCharSetId : MQLONG;   (* Character-set identifier of data that
                                  follows MQMDE *)
    Format : MQCHAR8;          (* Format name of data that follows
                                  MQMDE *)
    Flags : MQLONG;            (* General flags *)
    GroupId : MQBYTE24;        (* Group identifier *)
    MsgSeqNumber : MQLONG;     (* Sequence number of logical message
                                  within group *)
    Offset : MQLONG;           (* Offset of data in physical message from
                                  start of logical message *)
    MsgFlags : MQLONG;         (* Message flags *)
    OriginalLength : MQLONG;   (* Length of original message *)
  end;
  PMQMDE = ^TMQMDE;

  (*********************************************************************)
  (*  MQMD1 Structure -- Version-1 Message Descriptor                  *)
  (*********************************************************************)

  TMQMD1 = record
    StrucId : MQCHAR4;            (* Structure identifier *)
    Version : MQLONG;             (* Structure version number *)
    Report : MQLONG;              (* Report options *)
    MsgType : MQLONG;             (* Message type *)
    Expiry : MQLONG;              (* Expiry time *)
    Feedback : MQLONG;            (* Feedback or reason code *)
    Encoding : MQLONG;            (* Numeric encoding of message data *)
    CodedCharSetId : MQLONG;      (* Character set identifier of message
                                     data *)
    Format : MQCHAR8;             (* Format name of message data *)
    Priority : MQLONG;            (* Message priority *)
    Persistence : MQLONG;         (* Message persistence *)
    MsgId : MQBYTE24;             (* Message identifier *)
    CorrelId : MQBYTE24;          (* Correlation identifier *)
    BackoutCount : MQLONG;        (* Backout counter *)
    ReplyToQ : MQCHAR48;          (* Name of reply-to queue *)
    ReplyToQMgr : MQCHAR48;       (* Name of reply queue manager *)
    UserIdentifier : MQCHAR12;    (* User identifier *)
    AccountingToken : MQBYTE32;   (* Accounting token *)
    ApplIdentityData : MQCHAR32;  (* Application data relating to
                                     identity *)
    PutApplType : MQLONG;         (* Type of application that put the
                                     message *)
    PutApplName : MQCHAR28;       (* Name of application that put the
                                     message *)
    PutDate : MQCHAR8;            (* Date when message was put *)
    PutTime : MQCHAR8;            (* Time when message was put *)
    ApplOriginData : MQCHAR4;     (* Application data relating to
                                    origin *)
  end;
  PMQMD1 = ^TMQMD1;

  (*********************************************************************)
  (*  MQOD Structure -- Object Descriptor                              *)
  (*********************************************************************)

  TMQOD = record
    StrucId : MQCHAR4;               (* Structure identifier *)
    Version : MQLONG;                (* Structure version number *)
    ObjectType : MQLONG;             (* Object type *)
    ObjectName : MQCHAR48;           (* Object name *)
    ObjectQMgrName : MQCHAR48;       (* Object queue manager name *)
    DynamicQName : MQCHAR48;         (* Dynamic queue name *)
    AlternateUserId : MQCHAR12;      (* Alternate user identifier *)
    RecsPresent : MQLONG;            (* Number of object records
                                        present *)
    KnownDestCount : MQLONG;         (* Number of local queues opened
                                        successfully *)
    UnknownDestCount : MQLONG;       (* Number of remote queues opened
                                        successfully *)
    InvalidDestCount : MQLONG;       (* Number of queues that failed to
                                        open *)
    ObjectRecOffset : MQLONG;        (* Offset of first object record from
                                        start of MQOD *)
    ResponseRecOffset : MQLONG;      (* Offset of first response record
                                        from start of MQOD *)
    ObjectRecPtr : MQPTR;            (* Address of first object record *)
    ResponseRecPtr : MQPTR;          (* Address of first response
                                        record *)
    AlternateSecurityId : MQBYTE40;  (* Alternate security identifier *)
    ResolvedQName : MQCHAR48;        (* Resolved queue name *)
    ResolvedQMgrName : MQCHAR48;     (* Resolved queue manager name *)
  end;
  PMQOD = ^TMQOD;


  (*********************************************************************)
  (*  MQOR Structure -- Object Record                                  *)
  (*********************************************************************)

  TMQOR = record
    ObjectName : MQCHAR48;           (* Object name *)
    ObjectQMgrName : MQCHAR48;       (* Object queue manager name *)
  end;
  PMQOR = ^TMQOR;


  (*********************************************************************)
  (*  MQPMO Structure -- Put Message Options                           *)
  (*********************************************************************)

  TMQPMO = record
    StrucId : MQCHAR4;            (* Structure identifier *)
    Version : MQLONG;             (* Structure version number *)
    Options : MQLONG;             (* Options that control the action of
                                     MQPUT and MQPUT1 *)
    Timeout : MQLONG;             (* Reserved *)
    Context : MQHOBJ;             (* Object handle of input queue *)
    KnownDestCount : MQLONG;      (* Number of messages sent successfully
                                     to local queues *)
    UnknownDestCount : MQLONG;    (* Number of messages sent successfully
                                     to remote queues *)
    InvalidDestCount : MQLONG;    (* Number of messages that could not be
                                     sent *)
    ResolvedQName : MQCHAR48;     (* Resolved name of destination
                                     queue *)
    ResolvedQMgrName : MQCHAR48;  (* Resolved name of destination queue
                                     manager *)
    RecsPresent : MQLONG;         (* Number of put message records or
                                     response records present *)
    PutMsgRecFields : MQLONG;     (* Flags indicating which MQPMR fields
                                     are present *)
    PutMsgRecOffset : MQLONG;     (* Offset of first put message record
                                     from start of MQPMO *)
    ResponseRecOffset : MQLONG;   (* Offset of first response record from
                                     start of MQPMO *)
    PutMsgRecPtr : MQPTR;         (* Address of first put message
                                     record *)
    ResponseRecPtr : MQPTR;       (* Address of first response record *)
  end;
  PMQPMO = ^TMQPMO;

  (*********************************************************************)
  (*  MQRFH Structure -- Rules and Formatting Header                   *)
  (*********************************************************************)

  TMQRFH = record
    StrucId : MQCHAR4;          (* Structure identifier *)
    Version : MQLONG;           (* Structure version number *)
    StrucLength : MQLONG;       (* Total length of MQRFH including string
                                   containing name/value pairs *)
    Encoding : MQLONG;          (* Numeric encoding of data that follows
                                   NameValueString *)
    CodedCharSetId : MQLONG;    (* Character set identifier of data that
                                   follows NameValueString *)
    Format : MQCHAR8;           (* Format name of data that follows
                                   NameValueString *)
    Flags : MQLONG;             (* Flags *)
  end;
  PMQRFH = ^TMQRFH;


  (*********************************************************************)
  (*  MQRFH2 Structure -- Rules and Formatting Header 2                *)
  (*********************************************************************)

  TMQRFH2 = record
    StrucId : MQCHAR4;          (* Structure identifier *)
    Version : MQLONG;           (* Structure version number *)
    StrucLength : MQLONG;       (* Total length of MQRFH2 including
                                   NameValueData *)
    Encoding : MQLONG;          (* Numeric encoding of data that follows
                                   NameValueData *)
    CodedCharSetId : MQLONG;    (* Character set identifier of data that
                                   follows NameValueData *)
    Format : MQCHAR8;           (* Format name of data that follows
                                   NameValueData *)
    Flags : MQLONG;             (* Flags *)
    NameValueCCSID : MQLONG;    (* Character set identifier of
                                   NameValueData *)
  end;
  PMQRFH2 = ^TMQRFH2;


  (*********************************************************************)
  (*  MQRMH Structure -- Reference Message Header                      *)
  (*********************************************************************)

  TMQRMH = record
    StrucId : MQCHAR4;             (* Structure identifier *)
    Version : MQLONG;              (* Structure version number *)
    StrucLength : MQLONG;          (* Total length of MQRMH, including
                                      strings at end of fixed fields, but
                                      not the bulk data *)
    Encoding : MQLONG;             (* Numeric encoding of bulk data *)
    CodedCharSetId : MQLONG;       (* Character set identifier of bulk
                                      data *)
    Format : MQCHAR8;              (* Format name of bulk data *)
    Flags : MQLONG;                (* Reference message flags *)
    ObjectType : MQCHAR8;          (* Object type *)
    ObjectInstanceId : MQBYTE24;   (* Object instance identifier *)
    SrcEnvLength : MQLONG;         (* Length of source environment
                                      data *)
    SrcEnvOffset : MQLONG;         (* Offset of source environment
                                      data *)
    SrcNameLength : MQLONG;        (* Length of source object name *)
    SrcNameOffset : MQLONG;        (* Offset of source object name *)
    DestEnvLength : MQLONG;        (* Length of destination environment
                                      data *)
    DestEnvOffset : MQLONG;        (* Offset of destination environment
                                      data *)
    DestNameLength : MQLONG;       (* Length of destination object
                                      name *)
    DestNameOffset : MQLONG;       (* Offset of destination object
                                      name *)
    DataLogicalLength : MQLONG;    (* Length of bulk data *)
    DataLogicalOffset : MQLONG;    (* Low offset of bulk data *)
    DataLogicalOffset2 : MQLONG;   (* High offset of bulk data *)
  end;
  PMQRMH = ^TMQRMH;


  (*********************************************************************)
  (*  MQRR Structure -- Response Record                                *)
  (*********************************************************************)

  TMQRR = record
    CompCode : MQLONG;   (* Completion code for queue *)
    Reason : MQLONG;     (* Reason code for queue *)
  end;
  PMQRR = ^TMQRR;


  (*********************************************************************)
  (*  MQTM Structure -- Trigger Message                                *)
  (*********************************************************************)

  TMQTM = record
    StrucId : MQCHAR4;         (* Structure identifier *)
    Version : MQLONG;          (* Structure version number *)
    QName : MQCHAR48;          (* Name of triggered queue *)
    ProcessName : MQCHAR48;    (* Name of process object *)
    TriggerData : MQCHAR64;    (* Trigger data *)
    ApplType : MQLONG;         (* Application type *)
    ApplId : MQCHAR256;        (* Application identifier *)
    EnvData : MQCHAR128;       (* Environment data *)
    UserData : MQCHAR128;      (* User data *)
  end;
  PMQTM = ^TMQTM;


  (*********************************************************************)
  (*  MQTMC2 Structure -- Trigger Message 2 (Character)                *)
  (*********************************************************************)

  TMQTMC2 = record
    StrucId : MQCHAR4;         (* Structure identifier *)
    Version : MQCHAR4;         (* Structure version number *)
    QName : MQCHAR48;          (* Name of triggered queue *)
    ProcessName : MQCHAR48;    (* Name of process object *)
    TriggerData : MQCHAR64;    (* Trigger data *)
    ApplType : MQCHAR4;        (* Application type *)
    ApplId : MQCHAR256;        (* Application identifier *)
    EnvData : MQCHAR128;       (* Environment data *)
    UserData : MQCHAR128;      (* User data *)
    QMgrName : MQCHAR48;       (* Queue manager name *)
  end;
  PMQTMC2 = ^TMQTMC2;


  (*********************************************************************)
  (*  MQWIH Structure -- Work Information Header                       *)
  (*********************************************************************)

  TMQWIH = record
    StrucId : MQCHAR4;           (* Structure identifier *)
    Version : MQLONG;            (* Structure version number *)
    StrucLength : MQLONG;        (* Length of MQWIH structure *)
    Encoding : MQLONG;           (* Numeric encoding of data that follows
                                    MQWIH *)
    CodedCharSetId : MQLONG;     (* Character-set identifier of data that
                                    follows MQWIH *)
    Format : MQCHAR8;            (* Format name of data that follows
                                    MQWIH *)
    Flags : MQLONG;              (* Flags *)
    ServiceName : MQCHAR32;      (* Service name *)
    ServiceStep : MQCHAR8;       (* Service step name *)
    MsgToken : MQBYTE16;         (* Message token *)
    Reserved : MQCHAR32;         (* Reserved *)
  end;
  PMQWIH = ^TMQWIH;


  (*********************************************************************)
  (*  MQXQH Structure -- Transmission Queue Header                     *)
  (*********************************************************************)

  TMQXQH = record
    StrucId : MQCHAR4;           (* Structure identifier *)
    Version : MQLONG;            (* Structure version number *)
    RemoteQName : MQCHAR48;      (* Name of destination queue *)
    RemoteQMgrName : MQCHAR48;   (* Name of destination queue manager *)
    MsgDesc : TMQMD1;            (* Original message descriptor *)
  end;
  PMQXQH = ^TMQXQH;


  (*********************************************************************)
  (*  MQBACK Function -- Back Out Changes                              *)
  (*********************************************************************)

  procedure MQBACK (
    Hconn: MQHCONN;          (* Connection handle *)
    var CompCode : MQLONG;   (* Completion code *)
    var Reason: MQLONG);     (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQBACK';


  (*********************************************************************)
  (*  MQBEGIN Function -- Begin Unit of Work                           *)
  (*********************************************************************)

  procedure MQBEGIN (
    Hconn: MQHCONN;              (* Connection handle *)
    var BeginOptions: TMQBO;     (* Options that control the action of MQBEGIN *)
    var CompCode: MQLONG;        (* Completion code *)
    var Reason: MQLONG);         (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQBEGIN';


  (*********************************************************************)
  (*  MQCLOSE Function -- Close Object                                 *)
  (*********************************************************************)

  procedure MQCLOSE (
    Hconn: MQHCONN;         (* Connection handle *)
    var Hobj: MQHOBJ;       (* Object handle *)
    Options: MQLONG;        (* Options that control the action of MQCLOSE *)
    var CompCode: MQLONG;   (* Completion code *)
    var Reason: MQLONG);    (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQCLOSE';

  (*********************************************************************)
  (*  MQCMIT Function -- Commit Changes                                *)
  (*********************************************************************)

  procedure MQCMIT (
    Hconn: MQHCONN;            (* Connection handle *)
    var CompCode: PMQLONG;     (* Completion code *)
    var Reason: PMQLONG);      (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQCMIT';


  (*********************************************************************)
  (*  MQCONN Function -- Connect Queue Manager                         *)
  (*********************************************************************)

  procedure MQCONN (
    pQMgrName: PChar;        (* Name of queue manager *)
    var Hconn: MQHCONN;      (* Connection handle *)
    var CompCode: MQLONG;    (* Completion code *)
    var Reason: MQLONG);     (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQCONN';

  (*********************************************************************)
  (*  MQCONNX Function -- Connect Queue Manager (Extended)             *)
  (*********************************************************************)

  procedure MQCONNX (
    pQMgrName: PChar;          (* Name of queue manager *)
    var ConnectOpts: TMQCNO;    (* Options that control the action of
                                MQCONNX *)
    var Hconn: MQHCONN;        (* Connection handle *)
    var CompCode: MQLONG;      (* Completion code *)
    var pReason: MQLONG);      (* Reason code qualifying CompCode *)
 cdecl;
 external 'mqm.dll' name 'MQCONNX';

  (*********************************************************************)
  (*  MQDISC Function -- Disconnect Queue Manager                      *)
  (*********************************************************************)

  procedure MQDISC (
    var Hconn: MQHCONN;      (* Connection handle *)
    var CompCode: MQLONG;    (* Completion code *)
    var Reason: MQLONG);     (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQDISC';

  (*********************************************************************)
  (*  MQGET Function -- Get Message                                    *)
  (*********************************************************************)

  procedure MQGET (
    Hconn: MQHCONN;           (* Connection handle *)
    Hobj: MQHOBJ;             (* Object handle *)
    var MsgDesc: TMQMD;       (* Message descriptor *)
    var GetMsgOpts: TMQGMO;   (* Options that control the action of
                                 MQGET *)
    BufferLength: MQLONG;     (* Length in bytes of the Buffer area *)
    pBuffer: Pointer; //PMQVOID; (* Area to contain the message data *)
    var DataLength: MQLONG;   (* Length of the message *)
    var CompCode: MQLONG;     (* Completion code *)
    var Reason: MQLONG);      (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQGET';

  (*********************************************************************)
  (*  MQINQ Function -- Inquire Object Attributes                      *)
  (*********************************************************************)

  procedure MQINQ (
    Hconn: MQHCONN;            (* Connection handle *)
    Hobj: MQHOBJ;              (* Object handle *)
    SelectorCount: MQLONG;     (* Count of selectors *)
    pSelectors: PMQLONG;       (* Array of attribute selectors *)
    IntAttrCount: MQLONG;      (* Count of integer attributes *)
    pIntAttrs: PMQLONG;        (* Array of integer attributes *)
    CharAttrLength: MQLONG;    (* Length of character attributes buffer *)
    pCharAttrs: PMQCHAR;       (* Character attributes *)
    pCompCode: PMQLONG;        (* Completion code *)
    pReason: PMQLONG);         (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQINQ';


  (*********************************************************************)
  (*  MQOPEN Function -- Open Object                                   *)
  (*********************************************************************)

  procedure MQOPEN (
    Hconn: MQHCONN;         (* Connection handle *)
    var ObjDesc: TMQOD;     (* Object descriptor *)
    Options: MQLONG;        (* Options that control the action of MQOPEN *)
    var Hobj: MQHOBJ;       (* Object handle *)
    var CompCode: MQLONG;   (* Completion code *)
    var Reason: MQLONG);    (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQOPEN';


  (*********************************************************************)
  (*  MQPUT Function -- Put Message                                    *)
  (*********************************************************************)

  procedure MQPUT (
    Hconn : MQHCONN;           (* Connection handle *)
    Hobj : MQHOBJ;             (* Object handle *)
    var MsgDesc : TMQMD;       (* Message descriptor *)
    var PutMsgOpts : TMQPMO;   (* Options that control the action of MQPUT *)
    BufferLength : MQLONG;     (* Length of the message in Buffer *)
    pBuffer : Pointer;         (* Message data *)
    var CompCode : MQLONG;     (* Completion code *)
    var Reason : MQLONG);      (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQPUT';

  (*********************************************************************)
  (*  MQPUT1 Function -- Put One Message                               *)
  (*********************************************************************)

  procedure MQPUT1 (
    Hconn : MQHCONN;           (* Connection handle *)
    var ObjDesc : TMQOD;       (* Object descriptor *)
    var MsgDesc : TMQMD;       (* Message descriptor *)
    var PutMsgOpts : TMQPMO;   (* Options that control the action of MQPUT1 *)
    BufferLength : MQLONG;     (* Length of the message in Buffer *)
    pBuffer : Pointer;         (* Message data *)
    var CompCode : MQLONG;     (* Completion code *)
    var Reason : MQLONG);      (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQPUT1';

  (*********************************************************************)
  (*  MQSET Function -- Set Object Attributes                          *)
  (*********************************************************************)

  procedure MQSET (
    Hconn : MQHCONN;            (* Connection handle *)
    Hobj : MQHOBJ;              (* Object handle *)
    SelectorCount : MQLONG;     (* Count of selectors *)
    var Selectors : MQLONG;     (* Array of attribute selectors *)
    IntAttrCount : MQLONG;      (* Count of integer attributes *)
    var IntAttrs : MQLONG;      (* Array of integer attributes *)
    CharAttrLength : MQLONG;    (* Length of character attributes buffer *)
    var CharAttrs : MQCHAR;     (* Character attributes *)
    var CompCode : MQLONG;      (* Completion code *)
    var Reason : MQLONG);       (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQSET';


function DecodeCompletionCode(CompCode: integer): String;
function DecodeReason(Reason: integer): String;

procedure SetMQBO_DEFAULT (var struct: TMQBO);
procedure SetMQCIH_DEFAULT ( var struct: TMQCIH);
procedure setMQCNO_DEFAULT(var struct: TMQCNO);
procedure setMQDH_DEFAULT(var struct: TMQDH);
procedure SetMQGMO_DEFAULT(var struct: TMQGMO);
procedure SetMQIIH_DEFAULT(var struct: TMQIIH);
procedure SetMQDLH_DEFAULT (var struct: TMQDLH);
procedure SetMQMD_DEFAULT(var struct: TMQMD);
procedure SetMQMDE_DEFAULT(var struct: TMQMDE);
procedure SetMQMD1_DEFAULT(var struct: TMQMD1);
procedure SetMQOD_DEFAULT(var struct: TMQOD);
procedure SetMQOR_DEFAULT(var struct: TMQOR);
procedure SetMQPMO_DEFAULT(var struct: TMQPMO);
procedure SetMQRFH_DEFAULT (var struct: TMQRFH);
procedure SetMQRFH2_DEFAULT(var struct: TMQRFH2);
procedure SetMQRMH_DEFAULT (var struct: TMQRMH);
procedure SetMQRR_DEFAULT(var struct: TMQRR);
procedure SetMQTM_DEFAULT(var struct: TMQTM);
procedure SetMQTMC2_DEFAULT(var struct: TMQTMC2);
procedure SetMQWIH_DEFAULT(var struct: TMQWIH);
procedure SetMQXQH_DEFAULT(var struct: TMQXQH);

implementation

function DecodeCompletionCode(CompCode: integer): String;
var rv: String;
begin
  case CompCode of
    MQCC_OK      : rv := 'MQCC_OK     ';
    MQCC_WARNING : rv := 'MQCC_WARNING';
    MQCC_FAILED  : rv := 'MQCC_FAILED ';
    MQCC_UNKNOWN : rv := 'MQCC_UNKNOWN';
    else           rv := 'UNKNOWN     ';
  end;
  Result := rv;
end;

function DecodeReason(Reason: integer): String;
var rv: String;
begin
  case Reason of
    MQRC_NONE                      : rv := 'MQRC_NONE                     ';
    MQRC_ALIAS_BASE_Q_TYPE_ERROR   : rv := 'MQRC_ALIAS_BASE_Q_TYPE_ERROR  ';
    MQRC_ALREADY_CONNECTED         : rv := 'MQRC_ALREADY_CONNECTED        ';
    MQRC_BACKED_OUT                : rv := 'MQRC_BACKED_OUT               ';
    MQRC_BUFFER_ERROR              : rv := 'MQRC_BUFFER_ERROR             ';
    MQRC_BUFFER_LENGTH_ERROR       : rv := 'MQRC_BUFFER_LENGTH_ERROR      ';
    MQRC_CHAR_ATTR_LENGTH_ERROR    : rv := 'MQRC_CHAR_ATTR_LENGTH_ERROR   ';
    MQRC_CHAR_ATTRS_ERROR          : rv := 'MQRC_CHAR_ATTRS_ERROR         ';
    MQRC_CHAR_ATTRS_TOO_SHORT      : rv := 'MQRC_CHAR_ATTRS_TOO_SHORT     ';
    MQRC_CONNECTION_BROKEN         : rv := 'MQRC_CONNECTION_BROKEN        ';
    MQRC_DATA_LENGTH_ERROR         : rv := 'MQRC_DATA_LENGTH_ERROR        ';
    MQRC_DYNAMIC_Q_NAME_ERROR      : rv := 'MQRC_DYNAMIC_Q_NAME_ERROR     ';
    MQRC_ENVIRONMENT_ERROR         : rv := 'MQRC_ENVIRONMENT_ERROR        ';
    MQRC_EXPIRY_ERROR              : rv := 'MQRC_EXPIRY_ERROR             ';
    MQRC_FEEDBACK_ERROR            : rv := 'MQRC_FEEDBACK_ERROR           ';
    MQRC_GET_INHIBITED             : rv := 'MQRC_GET_INHIBITED            ';
    MQRC_HANDLE_NOT_AVAILABLE      : rv := 'MQRC_HANDLE_NOT_AVAILABLE     ';
    MQRC_HCONN_ERROR               : rv := 'MQRC_HCONN_ERROR              ';
    MQRC_HOBJ_ERROR                : rv := 'MQRC_HOBJ_ERROR               ';
    MQRC_INHIBIT_VALUE_ERROR       : rv := 'MQRC_INHIBIT_VALUE_ERROR      ';
    MQRC_INT_ATTR_COUNT_ERROR      : rv := 'MQRC_INT_ATTR_COUNT_ERROR     ';
    MQRC_INT_ATTR_COUNT_TOO_SMALL  : rv := 'MQRC_INT_ATTR_COUNT_TOO_SMALL ';
    MQRC_INT_ATTRS_ARRAY_ERROR     : rv := 'MQRC_INT_ATTRS_ARRAY_ERROR    ';
    MQRC_SYNCPOINT_LIMIT_REACHED   : rv := 'MQRC_SYNCPOINT_LIMIT_REACHED  ';
    MQRC_MAX_CONNS_LIMIT_REACHED   : rv := 'MQRC_MAX_CONNS_LIMIT_REACHED  ';
    MQRC_MD_ERROR                  : rv := 'MQRC_MD_ERROR                 ';
    MQRC_MISSING_REPLY_TO_Q        : rv := 'MQRC_MISSING_REPLY_TO_Q       ';
    MQRC_MSG_TYPE_ERROR            : rv := 'MQRC_MSG_TYPE_ERROR           ';
    MQRC_MSG_TOO_BIG_FOR_Q         : rv := 'MQRC_MSG_TOO_BIG_FOR_Q        ';
    MQRC_MSG_TOO_BIG_FOR_Q_MGR     : rv := 'MQRC_MSG_TOO_BIG_FOR_Q_MGR    ';
    MQRC_NO_MSG_AVAILABLE          : rv := 'MQRC_NO_MSG_AVAILABLE         ';
    MQRC_NO_MSG_UNDER_CURSOR       : rv := 'MQRC_NO_MSG_UNDER_CURSOR      ';
    MQRC_NOT_AUTHORIZED            : rv := 'MQRC_NOT_AUTHORIZED           ';
    MQRC_NOT_OPEN_FOR_BROWSE       : rv := 'MQRC_NOT_OPEN_FOR_BROWSE      ';
    MQRC_NOT_OPEN_FOR_INPUT        : rv := 'MQRC_NOT_OPEN_FOR_INPUT       ';
    MQRC_NOT_OPEN_FOR_INQUIRE      : rv := 'MQRC_NOT_OPEN_FOR_INQUIRE     ';
    MQRC_NOT_OPEN_FOR_OUTPUT       : rv := 'MQRC_NOT_OPEN_FOR_OUTPUT      ';
    MQRC_NOT_OPEN_FOR_SET          : rv := 'MQRC_NOT_OPEN_FOR_SET         ';
    MQRC_OBJECT_CHANGED            : rv := 'MQRC_OBJECT_CHANGED           ';
    MQRC_OBJECT_IN_USE             : rv := 'MQRC_OBJECT_IN_USE            ';
    MQRC_OBJECT_TYPE_ERROR         : rv := 'MQRC_OBJECT_TYPE_ERROR        ';
    MQRC_OD_ERROR                  : rv := 'MQRC_OD_ERROR                 ';
    MQRC_OPTION_NOT_VALID_FOR_TYPE : rv := 'MQRC_OPTION_NOT_VALID_FOR_TYPE';
    MQRC_OPTIONS_ERROR             : rv := 'MQRC_OPTIONS_ERROR            ';
    MQRC_PERSISTENCE_ERROR         : rv := 'MQRC_PERSISTENCE_ERROR        ';
    MQRC_PERSISTENT_NOT_ALLOWED    : rv := 'MQRC_PERSISTENT_NOT_ALLOWED   ';
    MQRC_PRIORITY_EXCEEDS_MAXIMUM  : rv := 'MQRC_PRIORITY_EXCEEDS_MAXIMUM ';
    MQRC_PRIORITY_ERROR            : rv := 'MQRC_PRIORITY_ERROR           ';
    MQRC_PUT_INHIBITED             : rv := 'MQRC_PUT_INHIBITED            ';
    MQRC_Q_DELETED                 : rv := 'MQRC_Q_DELETED                ';
    MQRC_Q_FULL                    : rv := 'MQRC_Q_FULL                   ';
    MQRC_Q_NOT_EMPTY               : rv := 'MQRC_Q_NOT_EMPTY              ';
    MQRC_Q_SPACE_NOT_AVAILABLE     : rv := 'MQRC_Q_SPACE_NOT_AVAILABLE    ';
    MQRC_Q_TYPE_ERROR              : rv := 'MQRC_Q_TYPE_ERROR             ';
    MQRC_Q_MGR_NAME_ERROR          : rv := 'MQRC_Q_MGR_NAME_ERROR         ';
    MQRC_Q_MGR_NOT_AVAILABLE       : rv := 'MQRC_Q_MGR_NOT_AVAILABLE      ';
    MQRC_REPORT_OPTIONS_ERROR      : rv := 'MQRC_REPORT_OPTIONS_ERROR     ';
    MQRC_SECOND_MARK_NOT_ALLOWED   : rv := 'MQRC_SECOND_MARK_NOT_ALLOWED  ';
    MQRC_SECURITY_ERROR            : rv := 'MQRC_SECURITY_ERROR           ';
    MQRC_SELECTOR_COUNT_ERROR      : rv := 'MQRC_SELECTOR_COUNT_ERROR     ';
    MQRC_SELECTOR_LIMIT_EXCEEDED   : rv := 'MQRC_SELECTOR_LIMIT_EXCEEDED  ';
    MQRC_SELECTOR_ERROR            : rv := 'MQRC_SELECTOR_ERROR           ';
    MQRC_SELECTOR_NOT_FOR_TYPE     : rv := 'MQRC_SELECTOR_NOT_FOR_TYPE    ';
    MQRC_SIGNAL_OUTSTANDING        : rv := 'MQRC_SIGNAL_OUTSTANDING       ';
    MQRC_SIGNAL_REQUEST_ACCEPTED   : rv := 'MQRC_SIGNAL_REQUEST_ACCEPTED  ';
    MQRC_STORAGE_NOT_AVAILABLE     : rv := 'MQRC_STORAGE_NOT_AVAILABLE    ';
    MQRC_SYNCPOINT_NOT_AVAILABLE   : rv := 'MQRC_SYNCPOINT_NOT_AVAILABLE  ';
    MQRC_TRIGGER_CONTROL_ERROR     : rv := 'MQRC_TRIGGER_CONTROL_ERROR    ';
    MQRC_TRIGGER_DEPTH_ERROR       : rv := 'MQRC_TRIGGER_DEPTH_ERROR      ';
    MQRC_TRIGGER_MSG_PRIORITY_ERR  : rv := 'MQRC_TRIGGER_MSG_PRIORITY_ERR ';
    MQRC_TRIGGER_TYPE_ERROR        : rv := 'MQRC_TRIGGER_TYPE_ERROR       ';
    MQRC_TRUNCATED_MSG_ACCEPTED    : rv := 'MQRC_TRUNCATED_MSG_ACCEPTED   ';
    MQRC_TRUNCATED_MSG_FAILED      : rv := 'MQRC_TRUNCATED_MSG_FAILED     ';
    MQRC_UNKNOWN_ALIAS_BASE_Q      : rv := 'MQRC_UNKNOWN_ALIAS_BASE_Q     ';
    MQRC_UNKNOWN_OBJECT_NAME       : rv := 'MQRC_UNKNOWN_OBJECT_NAME      ';
    MQRC_UNKNOWN_OBJECT_Q_MGR      : rv := 'MQRC_UNKNOWN_OBJECT_Q_MGR     ';
    MQRC_UNKNOWN_REMOTE_Q_MGR      : rv := 'MQRC_UNKNOWN_REMOTE_Q_MGR     ';
    MQRC_WAIT_INTERVAL_ERROR       : rv := 'MQRC_WAIT_INTERVAL_ERROR      ';
    MQRC_XMIT_Q_TYPE_ERROR         : rv := 'MQRC_XMIT_Q_TYPE_ERROR        ';
    MQRC_XMIT_Q_USAGE_ERROR        : rv := 'MQRC_XMIT_Q_USAGE_ERROR       ';
    MQRC_NOT_OPEN_FOR_PASS_ALL     : rv := 'MQRC_NOT_OPEN_FOR_PASS_ALL    ';
    MQRC_NOT_OPEN_FOR_PASS_IDENT   : rv := 'MQRC_NOT_OPEN_FOR_PASS_IDENT  ';
    MQRC_NOT_OPEN_FOR_SET_ALL      : rv := 'MQRC_NOT_OPEN_FOR_SET_ALL     ';
    MQRC_NOT_OPEN_FOR_SET_IDENT    : rv := 'MQRC_NOT_OPEN_FOR_SET_IDENT   ';
    MQRC_CONTEXT_HANDLE_ERROR      : rv := 'MQRC_CONTEXT_HANDLE_ERROR     ';
    MQRC_CONTEXT_NOT_AVAILABLE     : rv := 'MQRC_CONTEXT_NOT_AVAILABLE    ';
    MQRC_SIGNAL1_ERROR             : rv := 'MQRC_SIGNAL1_ERROR            ';
    MQRC_OBJECT_ALREADY_EXISTS     : rv := 'MQRC_OBJECT_ALREADY_EXISTS    ';
    MQRC_OBJECT_DAMAGED            : rv := 'MQRC_OBJECT_DAMAGED           ';
    MQRC_RESOURCE_PROBLEM          : rv := 'MQRC_RESOURCE_PROBLEM         ';
    MQRC_ANOTHER_Q_MGR_CONNECTED   : rv := 'MQRC_ANOTHER_Q_MGR_CONNECTED  ';
    MQRC_UNKNOWN_REPORT_OPTION     : rv := 'MQRC_UNKNOWN_REPORT_OPTION    ';
    MQRC_STORAGE_CLASS_ERROR       : rv := 'MQRC_STORAGE_CLASS_ERROR      ';
    MQRC_COD_NOT_VALID_FOR_XCF_Q   : rv := 'MQRC_COD_NOT_VALID_FOR_XCF_Q  ';
    MQRC_XWAIT_CANCELED            : rv := 'MQRC_XWAIT_CANCELED           ';
    MQRC_XWAIT_ERROR               : rv := 'MQRC_XWAIT_ERROR              ';
    MQRC_SUPPRESSED_BY_EXIT        : rv := 'MQRC_SUPPRESSED_BY_EXIT       ';
    MQRC_FORMAT_ERROR              : rv := 'MQRC_FORMAT_ERROR             ';
    MQRC_SOURCE_CCSID_ERROR        : rv := 'MQRC_SOURCE_CCSID_ERROR       ';
    MQRC_SOURCE_INTEGER_ENC_ERROR  : rv := 'MQRC_SOURCE_INTEGER_ENC_ERROR ';
    MQRC_SOURCE_DECIMAL_ENC_ERROR  : rv := 'MQRC_SOURCE_DECIMAL_ENC_ERROR ';
    MQRC_SOURCE_FLOAT_ENC_ERROR    : rv := 'MQRC_SOURCE_FLOAT_ENC_ERROR   ';
    MQRC_TARGET_CCSID_ERROR        : rv := 'MQRC_TARGET_CCSID_ERROR       ';
    MQRC_TARGET_INTEGER_ENC_ERROR  : rv := 'MQRC_TARGET_INTEGER_ENC_ERROR ';
    MQRC_TARGET_DECIMAL_ENC_ERROR  : rv := 'MQRC_TARGET_DECIMAL_ENC_ERROR ';
    MQRC_TARGET_FLOAT_ENC_ERROR    : rv := 'MQRC_TARGET_FLOAT_ENC_ERROR   ';
    MQRC_NOT_CONVERTED             : rv := 'MQRC_NOT_CONVERTED            ';
    MQRC_CONVERTED_MSG_TOO_BIG     : rv := 'MQRC_CONVERTED_MSG_TOO_BIG    ';
//    MQRC_TRUNCATED                 : rv := 'MQRC_TRUNCATED                ';
    MQRC_NO_EXTERNAL_PARTICIPANTS  : rv := 'MQRC_NO_EXTERNAL_PARTICIPANTS ';
    MQRC_PARTICIPANT_NOT_AVAILABLE : rv := 'MQRC_PARTICIPANT_NOT_AVAILABLE';
    MQRC_OUTCOME_MIXED             : rv := 'MQRC_OUTCOME_MIXED            ';
    MQRC_OUTCOME_PENDING           : rv := 'MQRC_OUTCOME_PENDING          ';
    MQRC_BRIDGE_STARTED            : rv := 'MQRC_BRIDGE_STARTED           ';
    MQRC_BRIDGE_STOPPED            : rv := 'MQRC_BRIDGE_STOPPED           ';
    MQRC_ADAPTER_STORAGE_SHORTAGE  : rv := 'MQRC_ADAPTER_STORAGE_SHORTAGE ';
    MQRC_UOW_IN_PROGRESS           : rv := 'MQRC_UOW_IN_PROGRESS          ';
    MQRC_ADAPTER_CONN_LOAD_ERROR   : rv := 'MQRC_ADAPTER_CONN_LOAD_ERROR  ';
    MQRC_ADAPTER_SERV_LOAD_ERROR   : rv := 'MQRC_ADAPTER_SERV_LOAD_ERROR  ';
    MQRC_ADAPTER_DEFS_ERROR        : rv := 'MQRC_ADAPTER_DEFS_ERROR       ';
    MQRC_ADAPTER_DEFS_LOAD_ERROR   : rv := 'MQRC_ADAPTER_DEFS_LOAD_ERROR  ';
    MQRC_ADAPTER_CONV_LOAD_ERROR   : rv := 'MQRC_ADAPTER_CONV_LOAD_ERROR  ';
    MQRC_BO_ERROR                  : rv := 'MQRC_BO_ERROR                 ';
    MQRC_DH_ERROR                  : rv := 'MQRC_DH_ERROR                 ';
    MQRC_MULTIPLE_REASONS          : rv := 'MQRC_MULTIPLE_REASONS         ';
    MQRC_OPEN_FAILED               : rv := 'MQRC_OPEN_FAILED              ';
    MQRC_ADAPTER_DISC_LOAD_ERROR   : rv := 'MQRC_ADAPTER_DISC_LOAD_ERROR  ';
    MQRC_CNO_ERROR                 : rv := 'MQRC_CNO_ERROR                ';
    MQRC_CICS_WAIT_FAILED          : rv := 'MQRC_CICS_WAIT_FAILED         ';
    MQRC_DLH_ERROR                 : rv := 'MQRC_DLH_ERROR                ';
    MQRC_HEADER_ERROR              : rv := 'MQRC_HEADER_ERROR             ';
    MQRC_SOURCE_LENGTH_ERROR       : rv := 'MQRC_SOURCE_LENGTH_ERROR      ';
    MQRC_TARGET_LENGTH_ERROR       : rv := 'MQRC_TARGET_LENGTH_ERROR      ';
    MQRC_SOURCE_BUFFER_ERROR       : rv := 'MQRC_SOURCE_BUFFER_ERROR      ';
    MQRC_TARGET_BUFFER_ERROR       : rv := 'MQRC_TARGET_BUFFER_ERROR      ';
    MQRC_IIH_ERROR                 : rv := 'MQRC_IIH_ERROR                ';
    MQRC_PCF_ERROR                 : rv := 'MQRC_PCF_ERROR                ';
    MQRC_DBCS_ERROR                : rv := 'MQRC_DBCS_ERROR               ';
    MQRC_OBJECT_NAME_ERROR         : rv := 'MQRC_OBJECT_NAME_ERROR        ';
    MQRC_OBJECT_Q_MGR_NAME_ERROR   : rv := 'MQRC_OBJECT_Q_MGR_NAME_ERROR  ';
    MQRC_RECS_PRESENT_ERROR        : rv := 'MQRC_RECS_PRESENT_ERROR       ';
    MQRC_OBJECT_RECORDS_ERROR      : rv := 'MQRC_OBJECT_RECORDS_ERROR     ';
    MQRC_RESPONSE_RECORDS_ERROR    : rv := 'MQRC_RESPONSE_RECORDS_ERROR   ';
    MQRC_ASID_MISMATCH             : rv := 'MQRC_ASID_MISMATCH            ';
    MQRC_PMO_RECORD_FLAGS_ERROR    : rv := 'MQRC_PMO_RECORD_FLAGS_ERROR   ';
    MQRC_PUT_MSG_RECORDS_ERROR     : rv := 'MQRC_PUT_MSG_RECORDS_ERROR    ';
    MQRC_CONN_ID_IN_USE            : rv := 'MQRC_CONN_ID_IN_USE           ';
    MQRC_Q_MGR_QUIESCING           : rv := 'MQRC_Q_MGR_QUIESCING          ';
    MQRC_Q_MGR_STOPPING            : rv := 'MQRC_Q_MGR_STOPPING           ';
    MQRC_DUPLICATE_RECOV_COORD     : rv := 'MQRC_DUPLICATE_RECOV_COORD    ';
    MQRC_PMO_ERROR                 : rv := 'MQRC_PMO_ERROR                ';
    MQRC_API_EXIT_NOT_FOUND        : rv := 'MQRC_API_EXIT_NOT_FOUND       ';
    MQRC_API_EXIT_LOAD_ERROR       : rv := 'MQRC_API_EXIT_LOAD_ERROR      ';
    MQRC_REMOTE_Q_NAME_ERROR       : rv := 'MQRC_REMOTE_Q_NAME_ERROR      ';
    MQRC_INCONSISTENT_PERSISTENCE  : rv := 'MQRC_INCONSISTENT_PERSISTENCE ';
    MQRC_GMO_ERROR                 : rv := 'MQRC_GMO_ERROR                ';
    MQRC_CICS_BRIDGE_RESTRICTION   : rv := 'MQRC_CICS_BRIDGE_RESTRICTION  ';
    MQRC_STOPPED_BY_CLUSTER_EXIT   : rv := 'MQRC_STOPPED_BY_CLUSTER_EXIT  ';
    MQRC_CLUSTER_RESOLUTION_ERROR  : rv := 'MQRC_CLUSTER_RESOLUTION_ERROR ';
    MQRC_CONVERTED_STRING_TOO_BIG  : rv := 'MQRC_CONVERTED_STRING_TOO_BIG ';
    MQRC_TMC_ERROR                 : rv := 'MQRC_TMC_ERROR                ';
    MQRC_PAGESET_FULL              : rv := 'MQRC_PAGESET_FULL             ';
//    MQRC_STORAGE_MEDIUM_FULL       : rv := 'MQRC_STORAGE_MEDIUM_FULL      ';
    MQRC_PAGESET_ERROR             : rv := 'MQRC_PAGESET_ERROR            ';
    MQRC_NAME_NOT_VALID_FOR_TYPE   : rv := 'MQRC_NAME_NOT_VALID_FOR_TYPE  ';
    MQRC_UNEXPECTED_ERROR          : rv := 'MQRC_UNEXPECTED_ERROR         ';
    MQRC_UNKNOWN_XMIT_Q            : rv := 'MQRC_UNKNOWN_XMIT_Q           ';
    MQRC_UNKNOWN_DEF_XMIT_Q        : rv := 'MQRC_UNKNOWN_DEF_XMIT_Q       ';
    MQRC_DEF_XMIT_Q_TYPE_ERROR     : rv := 'MQRC_DEF_XMIT_Q_TYPE_ERROR    ';
    MQRC_DEF_XMIT_Q_USAGE_ERROR    : rv := 'MQRC_DEF_XMIT_Q_USAGE_ERROR   ';
    MQRC_NAME_IN_USE               : rv := 'MQRC_NAME_IN_USE              ';
    MQRC_CONNECTION_QUIESCING      : rv := 'MQRC_CONNECTION_QUIESCING     ';
    MQRC_CONNECTION_STOPPING       : rv := 'MQRC_CONNECTION_STOPPING      ';
    MQRC_ADAPTER_NOT_AVAILABLE     : rv := 'MQRC_ADAPTER_NOT_AVAILABLE    ';
    MQRC_MSG_ID_ERROR              : rv := 'MQRC_MSG_ID_ERROR             ';
    MQRC_CORREL_ID_ERROR           : rv := 'MQRC_CORREL_ID_ERROR          ';
    MQRC_FILE_SYSTEM_ERROR         : rv := 'MQRC_FILE_SYSTEM_ERROR        ';
    MQRC_NO_MSG_LOCKED             : rv := 'MQRC_NO_MSG_LOCKED            ';
    MQRC_FILE_NOT_AUDITED          : rv := 'MQRC_FILE_NOT_AUDITED         ';
    MQRC_CONNECTION_NOT_AUTHORIZED : rv := 'MQRC_CONNECTION_NOT_AUTHORIZED';
    MQRC_MSG_TOO_BIG_FOR_CHANNEL   : rv := 'MQRC_MSG_TOO_BIG_FOR_CHANNEL  ';
    MQRC_CALL_IN_PROGRESS          : rv := 'MQRC_CALL_IN_PROGRESS         ';
    MQRC_RMH_ERROR                 : rv := 'MQRC_RMH_ERROR                ';
    MQRC_Q_MGR_ACTIVE              : rv := 'MQRC_Q_MGR_ACTIVE             ';
    MQRC_Q_MGR_NOT_ACTIVE          : rv := 'MQRC_Q_MGR_NOT_ACTIVE         ';
    MQRC_Q_DEPTH_HIGH              : rv := 'MQRC_Q_DEPTH_HIGH             ';
    MQRC_Q_DEPTH_LOW               : rv := 'MQRC_Q_DEPTH_LOW              ';
    MQRC_Q_SERVICE_INTERVAL_HIGH   : rv := 'MQRC_Q_SERVICE_INTERVAL_HIGH  ';
    MQRC_Q_SERVICE_INTERVAL_OK     : rv := 'MQRC_Q_SERVICE_INTERVAL_OK    ';
    MQRC_UNIT_OF_WORK_NOT_STARTED  : rv := 'MQRC_UNIT_OF_WORK_NOT_STARTED ';
    MQRC_CHANNEL_AUTO_DEF_OK       : rv := 'MQRC_CHANNEL_AUTO_DEF_OK      ';
    MQRC_CHANNEL_AUTO_DEF_ERROR    : rv := 'MQRC_CHANNEL_AUTO_DEF_ERROR   ';
    MQRC_CFH_ERROR                 : rv := 'MQRC_CFH_ERROR                ';
    MQRC_CFIL_ERROR                : rv := 'MQRC_CFIL_ERROR               ';
    MQRC_CFIN_ERROR                : rv := 'MQRC_CFIN_ERROR               ';
    MQRC_CFSL_ERROR                : rv := 'MQRC_CFSL_ERROR               ';
    MQRC_CFST_ERROR                : rv := 'MQRC_CFST_ERROR               ';
    MQRC_INCOMPLETE_GROUP          : rv := 'MQRC_INCOMPLETE_GROUP         ';
    MQRC_INCOMPLETE_MSG            : rv := 'MQRC_INCOMPLETE_MSG           ';
    MQRC_INCONSISTENT_CCSIDS       : rv := 'MQRC_INCONSISTENT_CCSIDS      ';
    MQRC_INCONSISTENT_ENCODINGS    : rv := 'MQRC_INCONSISTENT_ENCODINGS   ';
    MQRC_INCONSISTENT_UOW          : rv := 'MQRC_INCONSISTENT_UOW         ';
    MQRC_INVALID_MSG_UNDER_CURSOR  : rv := 'MQRC_INVALID_MSG_UNDER_CURSOR ';
    MQRC_MATCH_OPTIONS_ERROR       : rv := 'MQRC_MATCH_OPTIONS_ERROR      ';
    MQRC_MDE_ERROR                 : rv := 'MQRC_MDE_ERROR                ';
    MQRC_MSG_FLAGS_ERROR           : rv := 'MQRC_MSG_FLAGS_ERROR          ';
    MQRC_MSG_SEQ_NUMBER_ERROR      : rv := 'MQRC_MSG_SEQ_NUMBER_ERROR     ';
    MQRC_OFFSET_ERROR              : rv := 'MQRC_OFFSET_ERROR             ';
    MQRC_ORIGINAL_LENGTH_ERROR     : rv := 'MQRC_ORIGINAL_LENGTH_ERROR    ';
    MQRC_SEGMENT_LENGTH_ZERO       : rv := 'MQRC_SEGMENT_LENGTH_ZERO      ';
    MQRC_UOW_NOT_AVAILABLE         : rv := 'MQRC_UOW_NOT_AVAILABLE        ';
    MQRC_WRONG_GMO_VERSION         : rv := 'MQRC_WRONG_GMO_VERSION        ';
    MQRC_WRONG_MD_VERSION          : rv := 'MQRC_WRONG_MD_VERSION         ';
    MQRC_GROUP_ID_ERROR            : rv := 'MQRC_GROUP_ID_ERROR           ';
    MQRC_INCONSISTENT_BROWSE       : rv := 'MQRC_INCONSISTENT_BROWSE      ';
    MQRC_XQH_ERROR                 : rv := 'MQRC_XQH_ERROR                ';
    MQRC_SRC_ENV_ERROR             : rv := 'MQRC_SRC_ENV_ERROR            ';
    MQRC_SRC_NAME_ERROR            : rv := 'MQRC_SRC_NAME_ERROR           ';
    MQRC_DEST_ENV_ERROR            : rv := 'MQRC_DEST_ENV_ERROR           ';
    MQRC_DEST_NAME_ERROR           : rv := 'MQRC_DEST_NAME_ERROR          ';
    MQRC_TM_ERROR                  : rv := 'MQRC_TM_ERROR                 ';
    MQRC_CLUSTER_EXIT_ERROR        : rv := 'MQRC_CLUSTER_EXIT_ERROR       ';
    MQRC_CLUSTER_EXIT_LOAD_ERROR   : rv := 'MQRC_CLUSTER_EXIT_LOAD_ERROR  ';
    MQRC_CLUSTER_PUT_INHIBITED     : rv := 'MQRC_CLUSTER_PUT_INHIBITED    ';
    MQRC_CLUSTER_RESOURCE_ERROR    : rv := 'MQRC_CLUSTER_RESOURCE_ERROR   ';
    MQRC_NO_DESTINATIONS_AVAILABLE : rv := 'MQRC_NO_DESTINATIONS_AVAILABLE';
    MQRC_CONN_TAG_IN_USE           : rv := 'MQRC_CONN_TAG_IN_USE          ';
    MQRC_PARTIALLY_CONVERTED       : rv := 'MQRC_PARTIALLY_CONVERTED      ';
    MQRC_CONNECTION_ERROR          : rv := 'MQRC_CONNECTION_ERROR         ';
    MQRC_OPTION_ENVIRONMENT_ERROR  : rv := 'MQRC_OPTION_ENVIRONMENT_ERROR ';
    MQRC_CD_ERROR                  : rv := 'MQRC_CD_ERROR                 ';
    MQRC_CLIENT_CONN_ERROR         : rv := 'MQRC_CLIENT_CONN_ERROR        ';
    MQRC_CHANNEL_STOPPED_BY_USER   : rv := 'MQRC_CHANNEL_STOPPED_BY_USER  ';
    MQRC_HCONFIG_ERROR             : rv := 'MQRC_HCONFIG_ERROR            ';
    MQRC_FUNCTION_ERROR            : rv := 'MQRC_FUNCTION_ERROR           ';
    MQRC_CHANNEL_STARTED           : rv := 'MQRC_CHANNEL_STARTED          ';
    MQRC_CHANNEL_STOPPED           : rv := 'MQRC_CHANNEL_STOPPED          ';
    MQRC_CHANNEL_CONV_ERROR        : rv := 'MQRC_CHANNEL_CONV_ERROR       ';
    MQRC_SERVICE_NOT_AVAILABLE     : rv := 'MQRC_SERVICE_NOT_AVAILABLE    ';
    MQRC_INITIALIZATION_FAILED     : rv := 'MQRC_INITIALIZATION_FAILED    ';
    MQRC_TERMINATION_FAILED        : rv := 'MQRC_TERMINATION_FAILED       ';
    MQRC_UNKNOWN_Q_NAME            : rv := 'MQRC_UNKNOWN_Q_NAME           ';
    MQRC_SERVICE_ERROR             : rv := 'MQRC_SERVICE_ERROR            ';
    MQRC_Q_ALREADY_EXISTS          : rv := 'MQRC_Q_ALREADY_EXISTS         ';
    MQRC_USER_ID_NOT_AVAILABLE     : rv := 'MQRC_USER_ID_NOT_AVAILABLE    ';
    MQRC_UNKNOWN_ENTITY            : rv := 'MQRC_UNKNOWN_ENTITY           ';
    MQRC_UNKNOWN_AUTH_ENTITY       : rv := 'MQRC_UNKNOWN_AUTH_ENTITY      ';
    MQRC_UNKNOWN_REF_OBJECT        : rv := 'MQRC_UNKNOWN_REF_OBJECT       ';
    MQRC_CHANNEL_ACTIVATED         : rv := 'MQRC_CHANNEL_ACTIVATED        ';
    MQRC_CHANNEL_NOT_ACTIVATED     : rv := 'MQRC_CHANNEL_NOT_ACTIVATED    ';
    MQRC_UOW_CANCELED              : rv := 'MQRC_UOW_CANCELED             ';
    MQRC_FUNCTION_NOT_SUPPORTED    : rv := 'MQRC_FUNCTION_NOT_SUPPORTED   ';
    MQRC_SELECTOR_TYPE_ERROR       : rv := 'MQRC_SELECTOR_TYPE_ERROR      ';
    MQRC_COMMAND_TYPE_ERROR        : rv := 'MQRC_COMMAND_TYPE_ERROR       ';
    MQRC_MULTIPLE_INSTANCE_ERROR   : rv := 'MQRC_MULTIPLE_INSTANCE_ERROR  ';
    MQRC_SYSTEM_ITEM_NOT_ALTERABLE : rv := 'MQRC_SYSTEM_ITEM_NOT_ALTERABLE';
    MQRC_BAG_CONVERSION_ERROR      : rv := 'MQRC_BAG_CONVERSION_ERROR     ';
    MQRC_SELECTOR_OUT_OF_RANGE     : rv := 'MQRC_SELECTOR_OUT_OF_RANGE    ';
    MQRC_SELECTOR_NOT_UNIQUE       : rv := 'MQRC_SELECTOR_NOT_UNIQUE      ';
    MQRC_INDEX_NOT_PRESENT         : rv := 'MQRC_INDEX_NOT_PRESENT        ';
    MQRC_STRING_ERROR              : rv := 'MQRC_STRING_ERROR             ';
    MQRC_ENCODING_NOT_SUPPORTED    : rv := 'MQRC_ENCODING_NOT_SUPPORTED   ';
    MQRC_SELECTOR_NOT_PRESENT      : rv := 'MQRC_SELECTOR_NOT_PRESENT     ';
    MQRC_OUT_SELECTOR_ERROR        : rv := 'MQRC_OUT_SELECTOR_ERROR       ';
    MQRC_STRING_TRUNCATED          : rv := 'MQRC_STRING_TRUNCATED         ';
    MQRC_SELECTOR_WRONG_TYPE       : rv := 'MQRC_SELECTOR_WRONG_TYPE      ';
    MQRC_INCONSISTENT_ITEM_TYPE    : rv := 'MQRC_INCONSISTENT_ITEM_TYPE   ';
    MQRC_INDEX_ERROR               : rv := 'MQRC_INDEX_ERROR              ';
    MQRC_SYSTEM_BAG_NOT_ALTERABLE  : rv := 'MQRC_SYSTEM_BAG_NOT_ALTERABLE ';
    MQRC_ITEM_COUNT_ERROR          : rv := 'MQRC_ITEM_COUNT_ERROR         ';
    MQRC_FORMAT_NOT_SUPPORTED      : rv := 'MQRC_FORMAT_NOT_SUPPORTED     ';
    MQRC_SELECTOR_NOT_SUPPORTED    : rv := 'MQRC_SELECTOR_NOT_SUPPORTED   ';
    MQRC_ITEM_VALUE_ERROR          : rv := 'MQRC_ITEM_VALUE_ERROR         ';
    MQRC_HBAG_ERROR                : rv := 'MQRC_HBAG_ERROR               ';
    MQRC_PARAMETER_MISSING         : rv := 'MQRC_PARAMETER_MISSING        ';
    MQRC_CMD_SERVER_NOT_AVAILABLE  : rv := 'MQRC_CMD_SERVER_NOT_AVAILABLE ';
    MQRC_STRING_LENGTH_ERROR       : rv := 'MQRC_STRING_LENGTH_ERROR      ';
    MQRC_INQUIRY_COMMAND_ERROR     : rv := 'MQRC_INQUIRY_COMMAND_ERROR    ';
    MQRC_NESTED_BAG_NOT_SUPPORTED  : rv := 'MQRC_NESTED_BAG_NOT_SUPPORTED ';
    MQRC_BAG_WRONG_TYPE            : rv := 'MQRC_BAG_WRONG_TYPE           ';
    MQRC_ITEM_TYPE_ERROR           : rv := 'MQRC_ITEM_TYPE_ERROR          ';
    MQRC_SYSTEM_BAG_NOT_DELETABLE  : rv := 'MQRC_SYSTEM_BAG_NOT_DELETABLE ';
    MQRC_SYSTEM_ITEM_NOT_DELETABLE : rv := 'MQRC_SYSTEM_ITEM_NOT_DELETABLE';
    MQRC_CODED_CHAR_SET_ID_ERROR   : rv := 'MQRC_CODED_CHAR_SET_ID_ERROR  ';
    MQRC_MSG_TOKEN_ERROR           : rv := 'MQRC_MSG_TOKEN_ERROR          ';
    MQRC_MISSING_WIH               : rv := 'MQRC_MISSING_WIH              ';
    MQRC_WIH_ERROR                 : rv := 'MQRC_WIH_ERROR                ';
    MQRC_RFH_ERROR                 : rv := 'MQRC_RFH_ERROR                ';
    MQRC_RFH_STRING_ERROR          : rv := 'MQRC_RFH_STRING_ERROR         ';
    MQRC_RFH_COMMAND_ERROR         : rv := 'MQRC_RFH_COMMAND_ERROR        ';
    MQRC_RFH_PARM_ERROR            : rv := 'MQRC_RFH_PARM_ERROR           ';
    MQRC_RFH_DUPLICATE_PARM        : rv := 'MQRC_RFH_DUPLICATE_PARM       ';
    MQRC_RFH_PARM_MISSING          : rv := 'MQRC_RFH_PARM_MISSING         ';
    MQRC_CHAR_CONVERSION_ERROR     : rv := 'MQRC_CHAR_CONVERSION_ERROR    ';
    MQRC_UCS2_CONVERSION_ERROR     : rv := 'MQRC_UCS2_CONVERSION_ERROR    ';
    MQRC_DB2_NOT_AVAILABLE         : rv := 'MQRC_DB2_NOT_AVAILABLE        ';
    MQRC_OBJECT_NOT_UNIQUE         : rv := 'MQRC_OBJECT_NOT_UNIQUE        ';
    MQRC_CONN_TAG_NOT_RELEASED     : rv := 'MQRC_CONN_TAG_NOT_RELEASED    ';
    MQRC_CF_NOT_AVAILABLE          : rv := 'MQRC_CF_NOT_AVAILABLE         ';
    MQRC_CF_STRUC_IN_USE           : rv := 'MQRC_CF_STRUC_IN_USE          ';
    MQRC_CF_STRUC_LIST_HDR_IN_USE  : rv := 'MQRC_CF_STRUC_LIST_HDR_IN_USE ';
    MQRC_CF_STRUC_AUTH_FAILED      : rv := 'MQRC_CF_STRUC_AUTH_FAILED     ';
    MQRC_CF_STRUC_ERROR            : rv := 'MQRC_CF_STRUC_ERROR           ';
    MQRC_CONN_TAG_NOT_USABLE       : rv := 'MQRC_CONN_TAG_NOT_USABLE      ';
    MQRC_GLOBAL_UOW_CONFLICT       : rv := 'MQRC_GLOBAL_UOW_CONFLICT      ';
    MQRC_LOCAL_UOW_CONFLICT        : rv := 'MQRC_LOCAL_UOW_CONFLICT       ';
    MQRC_HANDLE_IN_USE_FOR_UOW     : rv := 'MQRC_HANDLE_IN_USE_FOR_UOW    ';
    MQRC_UOW_ENLISTMENT_ERROR      : rv := 'MQRC_UOW_ENLISTMENT_ERROR     ';
    MQRC_UOW_MIX_NOT_SUPPORTED     : rv := 'MQRC_UOW_MIX_NOT_SUPPORTED    ';
    MQRC_WXP_ERROR                 : rv := 'MQRC_WXP_ERROR                ';
    MQRC_CURRENT_RECORD_ERROR      : rv := 'MQRC_CURRENT_RECORD_ERROR     ';
    MQRC_NEXT_OFFSET_ERROR         : rv := 'MQRC_NEXT_OFFSET_ERROR        ';
    MQRC_NO_RECORD_AVAILABLE       : rv := 'MQRC_NO_RECORD_AVAILABLE      ';
    MQRC_OBJECT_LEVEL_INCOMPATIBLE : rv := 'MQRC_OBJECT_LEVEL_INCOMPATIBLE';
    MQRC_NEXT_RECORD_ERROR         : rv := 'MQRC_NEXT_RECORD_ERROR        ';

    MQRC_APPL_FIRST                : rv := 'MQRC_APPL_FIRST               ';
    MQRC_APPL_LAST                 : rv := 'MQRC_APPL_LAST                ';
    else                             rv := 'UNKNOWN REASON                ';
  end;
  result := rv;
end;

procedure SetMQBO_DEFAULT (var struct: TMQBO);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrPLCopy(StrucId, MQBO_STRUC_ID, SizeOf(StrucId));
    Version := MQBO_VERSION_1;
    Options := MQBO_NONE;
  end;
end;

procedure SetMQCIH_DEFAULT ( var struct: TMQCIH);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucId := MQCIH_STRUC_ID;
    Version := MQCIH_VERSION_2;
    StrucLength := MQCIH_LENGTH_2;
    Encoding := 0;
    CodedCharSetId := 0;
    Format := MQFMT_NONE;
    Flags := MQCIH_NONE;
    ReturnCode := MQCRC_OK;
    CompCode := MQCC_OK;
    Reason := MQRC_NONE;
    UOWControl := MQCUOWC_ONLY;
    GetWaitInterval := MQCGWI_DEFAULT;
    LinkType := MQCLT_PROGRAM;
    OutputDataLength := MQCODL_AS_INPUT;
    FacilityKeepTime := 0;
    ADSDescriptor := MQCADSD_NONE;
    ConversationalTask := MQCCT_NO;
    TaskEndStatus := MQCTES_NOSYNC;
    move(MQCFAC_NONE, Facility, SizeOf(Facility));
    Function_ := MQCFUNC_NONE;
    AbendCode :=  '    ';
    Authenticator := '        ';
    Reserved1 := '        ';
    ReplyToFormat := MQFMT_NONE;
    RemoteSysId := '    ';
    RemoteTransId := '    ';
    TransactionId := '    ';
    FacilityLike := '    ';
    AttentionId := '    ';
    StartCode := MQCSC_NONE;
    CancelCode := '    ';
    NextTransactionId := '    ';
    Reserved2 := '        ';
    Reserved3 := '        ';
    CursorPosition := 0;
    ErrorOffset := 0;
    InputItem := 0;
    Reserved4 := 0;
  end;
end;

procedure setMQCNO_DEFAULT(var struct: TMQCNO);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucId := MQCNO_STRUC_ID;
    Version := MQCNO_VERSION_1;
    Options := MQCNO_NONE;
    ClientConnOffset := 0;
    ClientConnPtr := nil;
  end;
end;

procedure setMQDH_DEFAULT(var struct: TMQDH);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucId := MQDH_STRUC_ID;
    Version := MQDH_VERSION_1;
    StrucLength := 0;
    Encoding := 0;
    CodedCharSetId := MQCCSI_UNDEFINED;
    Format := MQFMT_NONE;
    Flags := MQDHF_NONE;
    PutMsgRecFields := MQPMRF_NONE;
    RecsPresent := 0;
    ObjectRecOffset := 0;
    PutMsgRecOffset := 0;
  end;
end;

procedure SetMQGMO_DEFAULT(var struct: TMQGMO);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucID := MQGMO_STRUC_ID;
    Version := MQGMO_VERSION_1;
    Options := MQGMO_NO_WAIT;
    WaitInterval := 0;
    Signal1 := 0;
    Signal2 := 0;
    ResolvedQName := '';
    MatchOptions := MQMO_MATCH_MSG_ID+MQMO_MATCH_CORREL_ID;
    GroupStatus := MQGS_NOT_IN_GROUP;
    SegmentStatus := MQSS_NOT_A_SEGMENT;
    Segmentation := MQSEG_INHIBITED;
    Reserved1 := ' ';
    Move(MQMTOK_NONE, MsgToken, SizeOf(MsgToken));
    ReturnedLength := MQRL_UNDEFINED;
  end;
end;

procedure SetMQIIH_DEFAULT(var struct: TMQIIH);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucID := MQIIH_STRUC_ID;
    Version := MQIIH_VERSION_1;
    StrucLength := MQIIH_LENGTH_1;
    Encoding := 0;
    CodedCharSetId := 0;
    Format := MQFMT_NONE;
    Flags := MQIIH_NONE;
    LTermOverride := '        ';
    MFSMapName := '        ';
    ReplyToFormat := MQFMT_NONE;
    Authenticator := MQIAUT_NONE;
    move(MQITII_NONE, TranInstanceId, SizeOf(TranInstanceId));
    TranState := MQITS_NOT_IN_CONVERSATION;
    CommitMode := MQICM_COMMIT_THEN_SEND;
    SecurityScope := MQISS_CHECK;
    Reserved := ' ';
  end;
end;

procedure SetMQDLH_DEFAULT (var struct: TMQDLH);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucId := MQDLH_STRUC_ID;
    Version := MQDLH_VERSION_1;
    Reason := MQRC_NONE;
    DestQName := '';
    DestQMgrName := '';
    Encoding := 0;
    CodedCharSetId := MQCCSI_UNDEFINED;
    Format := MQFMT_NONE;
    PutApplType := 0;
    PutApplName := '';
    PutDate := '';
    PutTime := '';
  end;
end;

procedure SetMQMD_DEFAULT(var struct: TMQMD);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucId := MQMD_STRUC_ID;
    Version := MQMD_VERSION_1;
    Report := MQRO_NONE;
    MsgType := MQMT_DATAGRAM;
    Expiry := MQEI_UNLIMITED;
    Feedback := MQFB_NONE;
    Encoding := MQENC_NATIVE;
    CodedCharSetId := MQCCSI_Q_MGR;
    StrPLCopy(Format, MQFMT_NONE, SizeOf(Format));
    Priority := MQPRI_PRIORITY_AS_Q_DEF;
    Persistence := MQPER_PERSISTENCE_AS_Q_DEF;
    move(MQMI_NONE, MsgId, SizeOf(MsgId));
    move(MQCI_NONE, CorrelId, SizeOf(COrrelId));
    BackoutCount := 0;
    ReplyToQ := '';
    ReplyToQMgr := '';
    UserIdentifier := '';
    move(MQACT_NONE, AccountingToken, SizeOf(AccountingToken));
    ApplIdentityData := '';
    PutApplType := MQAT_NO_CONTEXT;
    PutApplName := '';
    PutDate := '';
    PutTime := '';
    ApplOriginData := '';
    move(MQGI_NONE, GroupId, SizeOf(GroupID));
    MsgSeqNumber := 1;
    Offset := 0;
    MsgFlags := MQMF_NONE;
    OriginalLength := MQOL_UNDEFINED;
  end;
end;

procedure SetMQMDE_DEFAULT(var struct: TMQMDE);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucId := MQMDE_STRUC_ID;
    Version := MQMDE_VERSION_2;
    StrucLength := MQMDE_LENGTH_2;
    Encoding := MQENC_NATIVE;
    CodedCharSetId := MQCCSI_UNDEFINED;
    Format := MQFMT_NONE;
    Flags := MQMDEF_NONE;
    move(MQGI_NONE, GroupId, SizeOf(GroupId));
    MsgSeqNumber := 1;
    Offset := 0;
    MsgFlags := MQMF_NONE;
    OriginalLength := MQOL_UNDEFINED;
  end;
end;

procedure SetMQMD1_DEFAULT(var struct: TMQMD1);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucId := MQMD_STRUC_ID;
    Version := MQMD_VERSION_1;
    Report := MQRO_NONE;
    MsgType := MQMT_DATAGRAM;
    Expiry := MQEI_UNLIMITED;
    Feedback := MQFB_NONE;
    Encoding := MQENC_NATIVE;
    CodedCharSetId := MQCCSI_Q_MGR;
    Format := MQFMT_NONE;
    Priority := MQPRI_PRIORITY_AS_Q_DEF;
    Persistence := MQPER_PERSISTENCE_AS_Q_DEF;
    move(MQMI_NONE, MsgId, SizeOf(MsgId));
    move(MQCI_NONE, CorrelId, SizeOf(COrrelId));
    BackoutCount := 0;
    ReplyToQ := '';
    ReplyToQMgr := '';
    UserIdentifier := '';
    move(MQACT_NONE, AccountingToken, SizeOf(AccountingToken));
    ApplIdentityData := '';
    PutApplType := MQAT_NO_CONTEXT;
    PutApplName := '';
    PutDate := '';
    PutTime := '';
    ApplOriginData := ''
  end;
end;

procedure SetMQOD_DEFAULT(var struct: TMQOD);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucId := MQOD_STRUC_ID;
    Version := MQOD_VERSION_1;
    ObjectType := MQOT_Q;
    ObjectName := '';
    ObjectQMgrName := '';
    DynamicQName := 'AMQ.*';
    AlternateUserId := '';
    RecsPresent := 0;
    KnownDestCount := 0;
    UnknownDestCount := 0;
    InvalidDestCount := 0;
    ObjectRecOffset := 0;
    ResponseRecOffset := 0;
    ObjectRecPtr := nil;
    ResponseRecPtr := nil;
    Move(MQSID_NONE, AlternateSecurityId, SizeOf(MQSID_NONE));
    ResolvedQName := '';
    ResolvedQMgrName := '';
  end;
end;

procedure SetMQOR_DEFAULT(var struct: TMQOR);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    ObjectName := '';
    ObjectQMgrName := ''
  end;
end;

procedure SetMQPMO_DEFAULT(var struct: TMQPMO);
begin
  FillChar(struct, SizeOf(Struct), 0);
  with struct do begin
    StrucId := MQPMO_STRUC_ID;
    Version := MQPMO_VERSION_1;
    Options := MQPMO_NONE;
    Timeout := -1;
    Context := 0;
    KnownDestCount := 0;
    UnknownDestCount := 0;
    InvalidDestCount := 0;
    ResolvedQName := '';
    ResolvedQMgrName := '';
    RecsPresent := 0;
    PutMsgRecFields := MQPMRF_NONE;
    PutMsgRecOffset := 0;
    ResponseRecOffset := 0;
    PutMsgRecPtr := nil;
    ResponseRecPtr := nil;
  end;
end;

procedure SetMQRFH_DEFAULT (var struct: TMQRFH);
begin
  FillChar(struct, SizeOf(Struct), 0);
  with struct do begin
    StrucId := MQRFH_STRUC_ID;
    Version := MQRFH_VERSION_1;
    StrucLength := MQRFH_STRUC_LENGTH_FIXED;
    Encoding := MQENC_NATIVE;
    CodedCharSetId := MQCCSI_UNDEFINED;
    Format := MQFMT_NONE;
    Flags := MQRFH_NONE;
  end;
end;

procedure SetMQRFH2_DEFAULT(var struct: TMQRFH2);
begin
  FillChar(struct, SizeOf(Struct), 0);
  with struct do begin
    StrucId := MQRFH_STRUC_ID;
    Version := MQRFH_VERSION_2;
    StrucLength := MQRFH_STRUC_LENGTH_FIXED_2;
    Encoding := MQENC_NATIVE;
    CodedCharSetId := MQCCSI_INHERIT;
    Format := MQFMT_NONE;
    Flags := MQRFH_NONE;
    NameValueCCSID := 1208;
  end;
end;

procedure SetMQRMH_DEFAULT (var struct: TMQRMH);
begin
  FillChar(struct, SizeOf(Struct), 0);
  with struct do begin
    StrucId := MQRMH_STRUC_ID;
    Version := MQRMH_VERSION_1;
    StrucLength := 0;
    Encoding := MQENC_NATIVE;
    CodedCharSetId := MQCCSI_UNDEFINED;
    Format := MQFMT_NONE;
    Flags := MQRMHF_NOT_LAST;
    ObjectType := '        ';
    move(MQOII_NONE, ObjectInstanceId, SizeOf(ObjectInstanceId));
    SrcEnvLength := 0;
    SrcEnvOffset := 0;
    SrcNameLength := 0;
    SrcNameOffset := 0;
    DestEnvLength := 0;
    DestEnvOffset := 0;
    DestNameLength := 0;
    DestNameOffset := 0;
    DataLogicalLength := 0;
    DataLogicalOffset := 0;
    DataLogicalOffset2 := 0;
  end;
end;

procedure SetMQRR_DEFAULT(var struct: TMQRR);
begin
  FillChar(struct, SizeOf(Struct), 0);
  with struct do begin
    CompCode := MQCC_OK;
    Reason := MQRC_NONE;
  end;
end;

procedure SetMQTM_DEFAULT(var struct: TMQTM);
begin
  FillChar(struct, SizeOf(Struct), 0);
  with struct do begin
    StrucId := MQTM_STRUC_ID;
    Version := MQTM_VERSION_1;
    QName := '';
    ProcessName := '';
    TriggerData := '';
    ApplType := 0;
    ApplId := '';
    EnvData := '';
    UserData := '';
  end;
end;

procedure SetMQTMC2_DEFAULT(var struct: TMQTMC2);
begin
  FillChar(struct, SizeOf(Struct), 0);
  with struct do begin
    StrucId := MQTMC_STRUC_ID;
    Version := MQTMC_VERSION_2;
    QName := '';
    ProcessName := '';
    TriggerData := '';
    ApplType := '';
    ApplId := '';
    EnvData := '';
    UserData := '';
    QMgrName := '';
  end;
end;

procedure SetMQWIH_DEFAULT(var struct: TMQWIH);
begin
  FillChar(struct, SizeOf(Struct), 0);
  with struct do begin
    StrucId := MQWIH_STRUC_ID;
    Version := MQWIH_VERSION_1;
    StrucLength := MQWIH_LENGTH_1;
    Encoding := 0;
    CodedCharSetId := MQCCSI_UNDEFINED;
    Format := MQFMT_NONE;
    Flags := MQWIH_NONE;
    ServiceName := '                                ';
    ServiceStep := '        ';
    move(MQMTOK_NONE, MsgToken, SizeOf(MsgToken));
    Reserved := '                                ';
  end;
end;

procedure SetMQXQH_DEFAULT(var struct: TMQXQH);
begin
  FillChar(struct, SizeOf(Struct), 0);
  with struct do begin
    StrucId := MQXQH_STRUC_ID;
    Version := MQXQH_VERSION_1;
    RemoteQName := '';
    RemoteQMgrName := '';
    SetMQMD1_DEFAULT(MsgDesc);
  end;
end;

(*********************************************************************)
(*  End of CMQC                                                      *)
(*********************************************************************)


end.
