unit CMQXPas;

// **************************************************************************
// **************************************************************************
// **************************************************************************
// MQSeries IBM library ported for Delphi by Dinko Miljak
// e-mail: dinmil@flashmail.com
// version 0.0.4 2001-05-07
// **************************************************************************
// **************************************************************************
// **************************************************************************

 (*********************************************************************)
 (*                                                                   *)
 (*                  IBM MQSeries for Windows NT and Windows 2000     *)
 (*                                                                   *)
 (*  HEADER NAME:    CMQXC                                            *)
 (*                                                                   *)
 (*  DESCRIPTION:    Declarations for Exits and MQCD                  *)
 (*                                                                   *)
 (*********************************************************************)
 (*  @START_COPYRIGHT@                                                *)
 (*  Licensed Materials - Property of IBM                             *)
 (*                                                                   *)
 (*  0784726, 5639-B43                                                *)
 (*                                                                   *)
 (*  (C) Copyright IBM Corporation 1993, 2000.                        *)
 (*                                                                   *)
 (*  Status: Version 5 Release 2                                      *)
 (*  @END_COPYRIGHT@                                                  *)
 (*********************************************************************)
 (*                                                                   *)
 (*  FUNCTION:       This file declares the functions, structures,    *)
 (*                  and named constants for exits and MQCD.          *)
 (*                                                                   *)
 (*  PROCESSOR:      C                                                *)
 (*                                                                   *)
 (*********************************************************************)

interface

uses SysUtils, CMQPas;

const

 (*********************************************************************)
 (*  Values Related to MQCD Structure                                 *)
 (*********************************************************************)

 (* Structure Version Number *)
  MQCD_VERSION_1       = 1;
  MQCD_VERSION_2       = 2;
  MQCD_VERSION_3       = 3;
  MQCD_VERSION_4       = 4;
  MQCD_VERSION_5       = 5;
  MQCD_VERSION_6       = 6;
  MQCD_CURRENT_VERSION = 6;

 (* Channel Type *)
  MQCHT_SENDER    = 1;
  MQCHT_SERVER    = 2;
  MQCHT_RECEIVER  = 3;
  MQCHT_REQUESTER = 4;
  MQCHT_ALL       = 5;
  MQCHT_CLNTCONN  = 6;
  MQCHT_SVRCONN   = 7;
  MQCHT_CLUSRCVR  = 8;
  MQCHT_CLUSSDR   = 9;

 (* Transport Type *)
  MQXPT_LOCAL   = 0;
  MQXPT_LU62    = 1;
  MQXPT_TCP     = 2;
  MQXPT_NETBIOS = 3;
  MQXPT_SPX     = 4;
  MQXPT_DECNET  = 5;
  MQXPT_UDP     = 6;

 (* Put Authority *)
  MQPA_DEFAULT          = 1;
  MQPA_CONTEXT          = 2;
  MQPA_ONLY_MCA         = 3;
  MQPA_ALTERNATE_OR_MCA = 4;

 (* Channel Data Conversion *)
  MQCDC_SENDER_CONVERSION    = 1;
  MQCDC_NO_SENDER_CONVERSION = 0;

 (* MCA Type *)
  MQMCAT_PROCESS = 1;
  MQMCAT_THREAD  = 2;

 (* NonPersistent-Message Speed *)
  MQNPMS_NORMAL = 1;
  MQNPMS_FAST   = 2;

 (* Structure Length *)
  MQCD_LENGTH_4       = 1540;
  MQCD_LENGTH_5       = 1552;
  MQCD_LENGTH_6       = 1648;
  MQCD_CURRENT_LENGTH = 1648;


 (*********************************************************************)
 (*  Values Related to MQCXP Structure                                *)
 (*********************************************************************)

 (* Structure Identifier *)
  MQCXP_STRUC_ID = 'CXP ';

 (* Structure Identifier (array form) *)
  MQCXP_STRUC_ID_ARRAY: MQCHAR4 = ('C','X','P',' ');

 (* Structure Version Number *)
  MQCXP_VERSION_1       = 1;
  MQCXP_VERSION_2       = 2;
  MQCXP_VERSION_3       = 3;
  MQCXP_VERSION_4       = 4;
  MQCXP_VERSION_5       = 5;
  MQCXP_CURRENT_VERSION = 5;

 (* Exit Response 2 *)
  MQXR2_PUT_WITH_DEF_ACTION  = 0;
  MQXR2_PUT_WITH_DEF_USERID  = 1;
  MQXR2_PUT_WITH_MSG_USERID  = 2;
  MQXR2_USE_AGENT_BUFFER     = 0;
  MQXR2_USE_EXIT_BUFFER      = 4;
  MQXR2_DEFAULT_CONTINUATION = 0;
  MQXR2_CONTINUE_CHAIN       = 8;
  MQXR2_SUPPRESS_CHAIN       = 16;
  MQXR2_STATIC_CACHE         = 0;
  MQXR2_DYNAMIC_CACHE        = 32;

 (* Capability Flags *)
  MQCF_NONE       = $00000000;
  MQCF_DIST_LISTS = $00000001;


 (*********************************************************************)
 (*  Values Related to MQDXP Structure                                *)
 (*********************************************************************)

 (* Structure Identifier *)
  MQDXP_STRUC_ID = 'DXP ';

 (* Structure Identifier (array form) *)
  MQDXP_STRUC_ID_ARRAY : MQCHAR4 = ('D','X','P',' ');

 (* Structure Version Number *)
  MQDXP_VERSION_1       = 1;
  MQDXP_CURRENT_VERSION = 1;

 (* Exit Response *)
  MQXDR_OK                = 0;
  MQXDR_CONVERSION_FAILED = 1;


 (*********************************************************************)
 (*  Values Related to MQPXP Structure                                *)
 (*********************************************************************)

 (* Structure Identifier *)
  MQPXP_STRUC_ID = 'PXP ';

 (* Structure Identifier (array form) *)
  MQPXP_STRUC_ID_ARRAY : MQCHAR4 = ('P','X','P',' ');

 (* Structure Version Number *)
  MQPXP_VERSION_1       = 1;
  MQPXP_CURRENT_VERSION = 1;

 (* Destination Type *)
  MQDT_APPL   = 1;
  MQDT_BROKER = 2;



 (*********************************************************************)
 (*  Values Related to MQWDR Structure                                *)
 (*********************************************************************)

 (* Structure Identifier *)
  MQWDR_STRUC_ID = 'WDR ';

 (* Structure Identifier (array form) *)
  MQWDR_STRUC_ID_ARRAY : MQCHAR4 = ('W','D','R',' ');

 (* Structure Version Number *)
  MQWDR_VERSION_1       = 1;
  MQWDR_CURRENT_VERSION = 1;

 (* Structure Length *)
  MQWDR_LENGTH_1       = 124;
  MQWDR_CURRENT_LENGTH = 124;

 (* Queue Manager Flags *)
  MQQMF_REPOSITORY_Q_MGR     = $00000002;
  MQQMF_CLUSSDR_USER_DEFINED = $00000008;
  MQQMF_CLUSSDR_AUTO_DEFINED = $00000010;
  MQQMF_AVAILABLE            = $00000020;


 (*********************************************************************)
 (*  Values Related to MQWQR Structure                                *)
 (*********************************************************************)

 (* Structure Identifier *)
  MQWQR_STRUC_ID = 'WQR ';

 (* Structure Identifier (array form) *)
  MQWQR_STRUC_ID_ARRAY : MQCHAR4 = ('W','Q','R',' ');

 (* Structure Version Number *)
  MQWQR_VERSION_1       = 1;
  MQWQR_CURRENT_VERSION = 1;

 (* Structure Length *)
  MQWQR_LENGTH_1       = 200;
  MQWQR_CURRENT_LENGTH = 200;

 (* Queue Flags *)
  MQQF_LOCAL_Q = $00000001;


 (*********************************************************************)
 (*  Values Related to MQWXP Structure                                *)
 (*********************************************************************)

 (* Structure Identifier *)
  MQWXP_STRUC_ID = 'WXP ';

 (* Structure Identifier (array form) *)
  MQWXP_STRUC_ID_ARRAY : MQCHAR4 = ('W','X','P',' ');

 (* Structure Version Number *)
  MQWXP_VERSION_1       = 1;
  MQWXP_VERSION_2       = 2;
  MQWXP_CURRENT_VERSION = 2;

  (* Cluster Cache Type *)
  MQCLCT_STATIC     = 0;
  MQCLCT_DYNAMIC    = 1;


 (*********************************************************************)
 (*  General Values Related to Exits                                  *)
 (*********************************************************************)

 (* Exit Identifier *)
  MQXT_CHANNEL_SEC_EXIT       = 11;
  MQXT_CHANNEL_MSG_EXIT       = 12;
  MQXT_CHANNEL_SEND_EXIT      = 13;
  MQXT_CHANNEL_RCV_EXIT       = 14;
  MQXT_CHANNEL_MSG_RETRY_EXIT = 15;
  MQXT_CHANNEL_AUTO_DEF_EXIT  = 16;
  MQXT_CLUSTER_WORKLOAD_EXIT  = 20;
  MQXT_PUBSUB_ROUTING_EXIT    = 21;

 (* Exit Reason *)
  MQXR_INIT            = 11;
  MQXR_TERM            = 12;
  MQXR_MSG             = 13;
  MQXR_XMIT            = 14;
  MQXR_SEC_MSG         = 15;
  MQXR_INIT_SEC        = 16;
  MQXR_RETRY           = 17;
  MQXR_AUTO_CLUSSDR    = 18;
  MQXR_AUTO_RECEIVER   = 19;
  MQXR_CLWL_OPEN       = 20;
  MQXR_CLWL_PUT        = 21;
  MQXR_CLWL_MOVE       = 22;
  MQXR_CLWL_REPOS      = 23;
  MQXR_CLWL_REPOS_MOVE = 24;
  MQXR_AUTO_SVRCONN    = 27;
  MQXR_AUTO_CLUSRCVR   = 28;

 (* Exit Response *)
  MQXCC_OK                       = 0;
  MQXCC_SUPPRESS_FUNCTION        = (-1);
  MQXCC_SKIP_FUNCTION            = (-2);
  MQXCC_SEND_AND_REQUEST_SEC_MSG = (-3);
  MQXCC_SEND_SEC_MSG             = (-4);
  MQXCC_SUPPRESS_EXIT            = (-5);
  MQXCC_CLOSE_CHANNEL            = (-6);

 (* Exit User Area Value *)
  MQXUA_NONE = #0#0#0#0#0#0#0#0#0#0#0#0#0#0#0#0;

 (* Exit User Area Value (array form) *)
  MQXUA_NONE_ARRAY : array[0..15] of char =
    (#0,#0,#0,#0,#0,#0,#0,#0,#0,#0,#0,#0,#0,#0,#0,#0);


 (*********************************************************************)
 (*  Values Related to MQXCNVC Function                               *)
 (*********************************************************************)

 (* Conversion Options *)
  MQDCC_DEFAULT_CONVERSION   = $00000001;
  MQDCC_FILL_TARGET_BUFFER   = $00000002;
  MQDCC_INT_DEFAULT_CONVERSION = $00000004;
  MQDCC_SOURCE_ENC_NATIVE    = $00000020;
  MQDCC_SOURCE_ENC_NORMAL    = $00000010;
  MQDCC_SOURCE_ENC_REVERSED  = $00000020;
  MQDCC_SOURCE_ENC_UNDEFINED = $00000000;
  MQDCC_TARGET_ENC_NATIVE    = $00000200;
  MQDCC_TARGET_ENC_NORMAL    = $00000100;
  MQDCC_TARGET_ENC_REVERSED  = $00000200;
  MQDCC_TARGET_ENC_UNDEFINED = $00000000;
  MQDCC_NONE                 = $00000000;

 (* Conversion Options Masks and Factors *)
  MQDCC_SOURCE_ENC_MASK   = $000000f0;
  MQDCC_TARGET_ENC_MASK   = $00000f00;
  MQDCC_SOURCE_ENC_FACTOR = 16;
  MQDCC_TARGET_ENC_FACTOR = 256;


type

 (*********************************************************************)
 (*  MQCD Structure -- Channel Definition                             *)
 (*********************************************************************)

 TMQCD = record
   ChannelName: array[0..19] of MQCHAR;           (* Channel definition name *)
   Version    : MQLONG;                           (* Structure version number *)
   ChannelType: MQLONG;                           (* Channel type *)
   TransportType: MQLONG;                         (* Transport type *)
   Desc: array[0..63] of MQCHAR;                  (* Channel description *)
   QMgrName: array[0..47] of MQCHAR;              (* Queue-manager name *)
   XmitQName: array[0..47] of MQCHAR;             (* Transmission queue name *)
   ShortConnectionName: array[0..19] of MQCHAR;   (* First 20 bytes of connection
                                                     name *)
   MCAName: array[0..19] of MQCHAR;               (* Reserved *)
   ModeName: array[0..7] of MQCHAR;               (* LU 6.2 Mode name *)
   TpName: array[0..63] of MQCHAR;                (* LU 6.2 transaction program
                                                     name *)
   BatchSize: MQLONG;                             (* Batch size *)
   DiscInterval: MQLONG;                          (* Disconnect interval *)
   ShortRetryCount: MQLONG;                       (* Short retry count *)
   ShortRetryInterval: MQLONG;                    (* Short retry wait interval *)
   LongRetryCount: MQLONG;                        (* Long retry count *)
   LongRetryInterval: MQLONG;                     (* Long retry wait interval *)
   SecurityExit: array[0..127] of MQCHAR;         (* Channel security exit name *)
   MsgExit: array[0..127] of MQCHAR;              (* Channel message exit name *)
   SendExit: array[0..127] of MQCHAR;             (* Channel send exit name *)
   ReceiveExit: array[0..127] of MQCHAR;          (* Channel receive exit name *)
   SeqNumberWrap: MQLONG;                         (* Highest allowable message
                                                     sequence number *)
   MaxMsgLength: MQLONG;                          (* Maximum message length *)
   PutAuthority: MQLONG;                          (* Put authority *)
   DataConversion: MQLONG;                        (* Data conversion *)
   SecurityUserData: array[0..31] of MQCHAR;      (* Channel security exit user
                                                     data *)
   MsgUserData: array[0..31] of MQCHAR;           (* Channel message exit user
                                                     data *)
   SendUserData: array[0..31] of MQCHAR;          (* Channel send exit user
                                                     data *)
   ReceiveUserData: array[0..31] of MQCHAR;       (* Channel receive exit user
                                                     data *)
   UserIdentifier: array[0..11] of MQCHAR;        (* User identifier *)
   Password: array[0..11] of MQCHAR;              (* Password *)
   MCAUserIdentifier: array[0..11] of MQCHAR;     (* First 12 bytes of MCA user
                                                     identifier *)
   MCAType: MQLONG;                               (* Message channel agent type *)
   ConnectionName: array[0..263] of MQCHAR;       (* Connection name *)
   RemoteUserIdentifier: array[0..11] of MQCHAR;  (* First 12 bytes of user
                                                     identifier from partner *)
   RemotePassword: array[0..11] of MQCHAR;        (* Password from partner *)
   MsgRetryExit: array[0..127] of MQCHAR;         (* Channel message retry exit
                                                     name *)
   MsgRetryUserData: array[0..31] of MQCHAR;      (* Channel message retry exit
                                                     user data *)
   MsgRetryCount: MQLONG;                         (* Number of times MCA will try
                                                     to put the message, after the
                                                     first attempt has failed *)
   MsgRetryInterval: MQLONG;                      (* Minimum interval in
                                                     milliseconds after which the
                                                     open or put operation will be
                                                     retried *)
   HeartbeatInterval: MQLONG;                     (* Time in seconds between
                                                     heartbeat flows *)
   BatchInterval: MQLONG;                         (* Batch duration *)
   NonPersistentMsgSpeed: MQLONG;                 (* Speed at which nonpersistent
                                                     messages are sent *)
   StrucLength: MQLONG;                           (* Length of MQCD structure *)
   ExitNameLength: MQLONG;                        (* Length of exit name *)
   ExitDataLength: MQLONG;                        (* Length of exit user data *)
   MsgExitsDefined: MQLONG;                       (* Number of message exits
                                                     defined *)
   SendExitsDefined: MQLONG;                      (* Number of send exits
                                                     defined *)
   ReceiveExitsDefined: MQLONG;                   (* Number of receive exits
                                                     defined *)
   MsgExitPtr: MQPTR;                             (* Address of first MsgExit
                                                     field *)
   MsgUserDataPtr: MQPTR;                         (* Address of first MsgUserData
                                                     field *)
   SendExitPtr: MQPTR;                            (* Address of first SendExit
                                                     field *)
   SendUserDataPtr: MQPTR;                        (* Address of first SendUserData
                                                     field *)
   ReceiveExitPtr: MQPTR;                         (* Address of first ReceiveExit
                                                     field *)
   ReceiveUserDataPtr: MQPTR;                     (* Address of first
                                                     ReceiveUserData field *)
   ClusterPtr: MQPTR;                             (* Address of first cluster
                                                     record *)
   ClustersDefined: MQLONG;                       (* Number of cluster records *)
   NetworkPriority: MQLONG;                       (* Network priority *)
   LongMCAUserIdLength: MQLONG;                   (* Length of long MCA user
                                                    identifier *)
   LongRemoteUserIdLength: MQLONG;                (* Length of long remote user
                                                     identifier *)
   LongMCAUserIdPtr: MQPTR;                       (* Address of long MCA user
                                                     identifier *)
   LongRemoteUserIdPtr: MQPTR;                    (* Address of long remote user
                                                     identifier *)
   MCASecurityId: MQBYTE40;                       (* MCA security identifier *)
   RemoteSecurityId: MQBYTE40;                    (* Remote security identifier *)
 end;
 PMQCD = ^TMQCD;

 (*
  MQCD_DEFAULT {""},\
                      MQCD_CURRENT_VERSION,\
                      MQCHT_SENDER,\
                      MQXPT_LU62,\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      50L,\
                      6000L,\
                      10L,\
                      60L,\
                      999999999L,\
                      1200L,\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      999999999L,\
                      4194304L,\
                      MQPA_DEFAULT,\
                      MQCDC_NO_SENDER_CONVERSION,\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      MQMCAT_PROCESS,\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      {""},\
                      10L,\
                      1000L,\
                      300L,\
                      0L,\
                      MQNPMS_FAST,\
                      MQCD_CURRENT_LENGTH,\
                      MQ_EXIT_NAME_LENGTH,\
                      MQ_EXIT_DATA_LENGTH,\
                      0L,\
                      0L,\
                      0L,\
                      NULL,\
                      NULL,\
                      NULL,\
                      NULL,\
                      NULL,\
                      NULL,\
                      NULL,\
                      0L,\
                      0L,\
                      0L,\
                      0L,\
                      NULL,\
                      NULL,\
                      {MQSID_NONE_ARRAY},\
                      {MQSID_NONE_ARRAY}
 *)


 (* Initial values for MQCD when passed on MQCONNX function *)
 (*
  MQCD_CLIENT_CONN_DEFAULT {""},\
                                  MQCD_VERSION_6,\
                                  MQCHT_CLNTCONN,\
                                  MQXPT_TCP,\
                                  {""},\
                                  {""},\
                                  {""},\
                                  {""},\
                                  {""},\
                                  {""},\
                                  {""},\
                                  50L,\
                                  6000L,\
                                  10L,\
                                  60L,\
                                  999999999L,\
                                  1200L,\
                                  {""},\
                                  {""},\
                                  {""},\
                                  {""},\
                                  999999999L,\
                                  4194304L,\
                                  MQPA_DEFAULT,\
                                  MQCDC_NO_SENDER_CONVERSION,\
                                  {""},\
                                  {""},\
                                  {""},\
                                  {""},\
                                  {""},\
                                  {""},\
                                  {""},\
                                  MQMCAT_PROCESS,\
                                  {""},\
                                  {""},\
                                  {""},\
                                  {""},\
                                  {""},\
                                  10L,\
                                  1000L,\
                                  1L,\
                                  0L,\
                                  MQNPMS_FAST,\
                                  MQCD_LENGTH_6,\
                                  MQ_EXIT_NAME_LENGTH,\
                                  MQ_EXIT_DATA_LENGTH,\
                                  0L,\
                                  0L,\
                                  0L,\
                                  NULL,\
                                  NULL,\
                                  NULL,\
                                  NULL,\
                                  NULL,\
                                  NULL,\
                                  NULL,\
                                  0L,\
                                  0L,\
                                  0L,\
                                  0L,\
                                  NULL,\
                                  NULL,\
                                  {MQSID_NONE_ARRAY},\
                                  {MQSID_NONE_ARRAY}
 *)

 (*********************************************************************)
 (*  MQCXP Structure -- Channel Exit Parameter                        *)
 (*********************************************************************)

 TMQCXP = record
   StrucId         : MQCHAR4;   (* Structure identifier *)
   Version         : MQLONG;    (* Structure version number *)
   ExitId          : MQLONG;    (* Type of exit *)
   ExitReason      : MQLONG;    (* Reason for invoking exit *)
   ExitResponse    : MQLONG;    (* Response from exit *)
   ExitResponse2   : MQLONG;    (* Secondary response from exit *)
   Feedback        : MQLONG;    (* Feedback code *)
   MaxSegmentLength: MQLONG;    (* Maximum segment length *)
   ExitUserArea    : MQBYTE16;  (* Exit user area *)
   ExitData        : MQCHAR32;  (* Exit data *)
   MsgRetryCount   : MQLONG;    (* Number of times the message has been
                                   retried *)
   MsgRetryInterval: MQLONG;    (* Minimum interval in milliseconds
                                   after which the put operation should
                                   be retried *)
   MsgRetryReason  : MQLONG;    (* Reason code from previous attempt to
                                   put the message *)
   HeaderLength    : MQLONG;    (* Length of header information *)
   PartnerName     : MQCHAR48;  (* Partner Name *)
   FAPLevel        : MQLONG;    (* Negotiated Formats and Protocols
                                   level *)
   CapabilityFlags : MQLONG;    (* Capability flags *)
   ExitNumber      : MQLONG;    (* Exit number *)
   ExitSpace       : MQLONG;    (* Bytes reserved for send exit use *)
 end;
 PMQCXP = ^TMQCXP;

 (*
  MQCXP_DEFAULT {MQCXP_STRUC_ID_ARRAY},\
                       MQCXP_CURRENT_VERSION,\
                       0L,\
                       0L,\
                       MQXCC_OK,\
                       MQXR2_PUT_WITH_DEF_ACTION,\
                       0L,\
                       0L,\
                       {MQXUA_NONE_ARRAY},\
                       {""},\
                       0L,\
                       0L,\
                       0L,\
                       0L,\
                       {""},\
                       0L,\
                       MQCF_NONE,\
                       1L,\
                       0L
   *)

 (*********************************************************************)
 (*  MQDXP Structure -- Data Conversion Exit Parameter                *)
 (*********************************************************************)

 TMQDXP = record
   StrucId       : MQCHAR4;    (* Structure identifier *)
   Version       : MQLONG;     (* Structure version number *)
   ExitOptions   : MQLONG;     (* Reserved *)
   AppOptions    : MQLONG;     (* Application options *)
   Encoding      : MQLONG;     (* Numeric encoding required by
                                     application *)
   CodedCharSetId: MQLONG;     (* Character set required by application *)
   DataLength    : MQLONG;     (* Length in bytes of message data *)
   CompCode      : MQLONG;     (* Completion code *)
   Reason        : MQLONG;     (* Reason code qualifying CompCode *)
   ExitResponse  : MQLONG;     (* Response from exit *)
   Hconn         : MQHCONN;    (* Connection handle *)
 end;
 PMQDXP = ^TMQDXP;

 (*
  MQDXP_DEFAULT {MQDXP_STRUC_ID_ARRAY},\
                       MQDXP_CURRENT_VERSION,\
                       0L,\
                       0L,\
                       0L,\
                       0L,\
                       0L,\
                       MQCC_OK,\
                       MQRC_NONE,\
                       MQXDR_CONVERSION_FAILED,\
                       0L
  *)

 (*********************************************************************)
 (*  MQPXP Structure -- Publish/Subscribe Routing Exit Parameter      *)
 (*********************************************************************)

 TMQPXP = record
   StrucId: MQCHAR4;               (* Structure identifier *)
   Version: MQLONG;                (* Structure version number *)
   ExitId: MQLONG;                 (* Type of exit *)
   ExitReason: MQLONG;             (* Reason for invoking exit *)
   ExitResponse: MQLONG;           (* Response from exit *)
   ExitResponse2: MQLONG;          (* Reserved *)
   Feedback: MQLONG;               (* Feedback code *)
   ExitNumber: MQLONG;             (* Exit number *)
   ExitUserArea: MQBYTE16;         (* Exit user area *)
   ExitData: MQCHAR32;             (* Exit data *)
   HeaderLength: MQLONG;           (* Reserved *)
   MsgInLength: MQLONG;            (* Length of input message data *)
   MsgOutLength: MQLONG;           (* Length of output message data *)
   DestinationType: MQLONG;        (* Type of destination for message *)
   MsgDescPtr: PMQMD;              (* Address of message descriptor *)
   MsgInPtr: PMQVOID;              (* Address of input message data *)
   MsgOutPtr: PMQVOID;             (* Address of output message data *)
   StreamName: MQCHAR48;           (* Name of stream *)
   QMgrName: MQCHAR48;             (* Name of local queue manager *)
   DestinationQName: MQCHAR48;     (* Name of destination queue *)
   DestinationQMgrName: MQCHAR48;  (* Name of destination queue
                                      manager *)
  end;
 PMQPXP = ^TMQPXP;

 (*
  MQPXP_DEFAULT {MQPXP_STRUC_ID_ARRAY},\
                       MQPXP_CURRENT_VERSION,\
                       MQXT_PUBSUB_ROUTING_EXIT,\
                       0L,\
                       MQXCC_OK,\
                       0L,\
                       MQFB_NONE,\
                       1L,\
                       {MQXUA_NONE_ARRAY},\
                       {""},\
                       0L,\
                       0L,\
                       0L,\
                       MQDT_APPL,\
                       NULL,\
                       NULL,\
                       NULL,\
                       {""},\
                       {""},\
                       {""},\
                       {""}
 *)

 (*********************************************************************)
 (*  MQWCR Structure -- Cluster Workload Exit Cluster Record          *)
 (*********************************************************************)

 TMQWCR = record
   ClusterName     : MQCHAR48;       (* Cluster name *)
   ClusterRecOffset: MQLONG;         (* Offset of next cluster record *)
   ClusterFlags    : MQLONG;         (* Cluster flags *)
 end;
 PMQWCR = ^TMQWCR;

 (*
  MQWCR_DEFAULT {""},\
                       0L,\
                       0L
 *)

 (*********************************************************************)
 (*  MQWDR Structure -- Cluster Workload Exit Destination Record      *)
 (*********************************************************************)

 TMQWDR = record
   StrucId         : MQCHAR4;  (* Structure identifier *)
   Version         : MQLONG;   (* Structure version number *)
   StrucLength     : MQLONG;   (* Length of MQWDR structure *)
   QMgrFlags       : MQLONG;   (* Queue-manager flags *)
   QMgrIdentifier  : MQCHAR48; (* Queue-manager identifier *)
   QMgrName        : MQCHAR48; (* Queue-manager name *)
   ClusterRecOffset: MQLONG;   (* Offset of first cluster record *)
   ChannelState    : MQLONG;   (* Channel state *)
   ChannelDefOffset: MQLONG;   (* Offset of channel definition
                                   structure *)
 end;
 PMQWDR = ^TMQWDR;
 PPMQWDR = ^PMQWDR;

 (*
  MQWDR_DEFAULT {MQWDR_STRUC_ID_ARRAY},\
                       MQWDR_CURRENT_VERSION,\
                       MQWDR_CURRENT_LENGTH,\
                       0L,\
                       {""},\
                       {""},\
                       0L,\
                       0L,\
                       0L
  *)

 (*********************************************************************)
 (*  MQWQR Structure -- Cluster Workload Exit Queue Record            *)
 (*********************************************************************)

 TMQWQR = record
   StrucId         : MQCHAR4;   (* Structure identifier *)
   Version         : MQLONG;    (* Structure version number *)
   StrucLength     : MQLONG;    (* Length of MQWQR structure *)
   QFlags          : MQLONG;    (* Queue flags *)
   QName           : MQCHAR48;  (* Queue name *)
   QMgrIdentifier  : MQCHAR48;  (* Queue-manager identifier *)
   ClusterRecOffset: MQLONG;    (* Offset of first cluster record *)
   QType           : MQLONG;    (* Queue type *)
   QDesc           : MQCHAR64;  (* Queue description *)
   DefBind         : MQLONG;    (* Default binding *)
   DefPersistence  : MQLONG;    (* Default message persistence *)
   DefPriority     : MQLONG;    (* Default message priority *)
   InhibitPut      : MQLONG;    (* Whether put operations on the queue
                                   are allowed *)
 end;
 PMQWQR = ^TMQWQR;
 PPMQWQR = ^PMQWQR;

 (*
  MQWQR_DEFAULT {MQWQR_STRUC_ID_ARRAY},\
                       MQWQR_CURRENT_VERSION,\
                       MQWQR_CURRENT_LENGTH,\
                       0L,\
                       {""},\
                       {""},\
                       0L,\
                       0L,\
                       {""},\
                       0L,\
                       0L,\
                       0L,\
                       0L
 *)

 (*********************************************************************)
 (*  MQWXP Structure -- Cluster Workload Exit Parameter               *)
 (*********************************************************************)

 TMQWXP = record
   StrucId            : MQCHAR4;           (* Structure identifier *)
   Version            : MQLONG;            (* Structure version number *)
   ExitId             : MQLONG;            (* Type of exit *)
   ExitReason         : MQLONG;            (* Reason for invoking exit *)
   ExitResponse       : MQLONG;            (* Response from exit *)
   ExitResponse2      : MQLONG;            (* Secondary response from exit *)
   Feedback           : MQLONG;            (* Reserved *)
   Reserved           : MQLONG;            (* Reserved *)
   ExitUserArea       : MQBYTE16;          (* Exit user area *)
   ExitData           : MQCHAR32;          (* Exit data *)
   MsgDescPtr         : PMQMD;             (* Address of message descriptor *)
   MsgBufferPtr       : PMQVOID;           (* Address of buffer containing some
                                              or all of the message data *)
   MsgBufferLength    : MQLONG;            (* Length of buffer containing
                                              message data *)
   MsgLength          : MQLONG;            (* Length of complete message *)
   QName              : MQCHAR48;          (* Queue name *)
   QMgrName           : MQCHAR48;          (* Name of local queue manager *)
   DestinationCount   : MQLONG;            (* Number of possible destinations *)
   DestinationChosen  : MQLONG;            (* Destination chosen *)
   DestinationArrayPtr: PPMQWDR;           (* Address of an array of pointers to
                                              destination records *)
   QArrayPtr          : PPMQWQR;           (* Address of an array of pointers to
                                              queue records *)
   CacheContext       : MQPTR;             (* Context information *)
   CacheType          : MQLONG;            (* Type of cluster cache *)
 end;
 PMQWXP = ^TMQWXP;

 (*
  MQWXP_DEFAULT {MQWXP_STRUC_ID_ARRAY},\
                       MQWXP_CURRENT_VERSION,\
                       0L,\
                       0L,\
                       MQXCC_OK,\
                       0L,\
                       0L,\
                       0L,\
                       {MQXUA_NONE_ARRAY},\
                       {""},\
                       NULL,\
                       NULL,\
                       0L,\
                       0L,\
                       {""},\
                       {""},\
                       0L,\
                       0L,\
                       NULL,\
                       NULL,\
                       NULL,\
                       MQCLCT_DYNAMIC
 *)

 (*********************************************************************)
 (*  MQ_CHANNEL_EXIT -- Channel Exit Datatype                         *)
 (*********************************************************************)

  // MQCHANNELEXIT MQ_CHANNEL_EXIT

  procedure MQ_CHANNEL_EXIT (
     pChannelExitParms    : Pointer;  (* Channel exit parameter block *)
     pChannelDefinition   : Pointer;  (* Channel definition *)
     var DataLength       : MQLONG;   (* Length of data *)
     var AgentBufferLength: MQLONG;   (* Length of agent buffer *)
     pAgentBuffer         : Pointer;  (* Agent buffer *)
     var ExitBufferLength : MQLONG;   (* Length of exit buffer *)
     pExitBufferAddr      : Pointer); (* Address of exit buffer *)
  cdecl;
  external 'mqm.dll' name 'MQ_CHANNEL_EXIT';



 (*********************************************************************)
 (*  MQ_CHANNEL_AUTO_DEF_EXIT -- Channel Auto Def Exit Datatype       *)
 (*********************************************************************)

  // MQCHANNELAUTODEFEXIT MQ_CHANNEL_AUTO_DEF_EXIT

  procedure MQ_CHANNEL_AUTO_DEF_EXIT (
     pChannelExitParms: Pointer;   (* Channel exit parameter block *)
     pChannelDefinition: Pointer); (* Channel definition *)
  cdecl;
  external 'mqm.dll' name 'MQ_CHANNEL_AUTO_DEF_EXIT';


 (*********************************************************************)
 (*  MQ_CLUSTER_WORKLOAD_EXIT -- Cluster Workload Exit Datatype       *)
 (*********************************************************************)

  procedure MQ_CLUSTER_WORKLOAD_EXIT (
     var ExitParms: TMQWXP); (* Exit parameter block *)
  cdecl;
  external 'mqm.dll' name 'MQ_CLUSTER_WORKLOAD_EXIT';


 (*********************************************************************)
 (*  MQ_DATA_CONV_EXIT -- Data Conversion Exit Datatype               *)
 (*********************************************************************)

  // MQDATACONVEXIT MQ_DATA_CONV_EXIT

  procedure MQ_DATA_CONV_EXIT (
     var DataConvExitParms: TMQDXP;  (* Data-conversion exit parameter
                                        block *)
     var MsgDesc: TMQMD;             (* Message descriptor *)
     InBufferLength: MQLONG;         (* Length in bytes of InBuffer *)
     pInBuffer: Pointer;             (* Buffer containing the unconverted
                                        message *)
     OutBufferLength: MQLONG;        (* Length in bytes of OutBuffer *)
     pOutBuffer: Pointer);           (* Buffer containing the converted
                                        message *)
  cdecl;
  external 'mqm.dll' name 'MQ_DATA_CONV_EXIT';


 (*********************************************************************)
 (*  MQ_PUBSUB_ROUTING_EXIT -- Pub/Sub Routing Exit Datatype          *)
 (*********************************************************************)

  procedure MQ_PUBSUB_ROUTING_EXIT (
     var ExitParms: TMQPXP  ); (* Exit parameter block *)
  cdecl;
  external 'mqm.dll' name 'MQ_PUBSUB_ROUTING_EXIT';


 (*********************************************************************)
 (*  MQ_TRANSPORT_EXIT -- Transport Retry Exit Datatype               *)
 (*********************************************************************)

//  MQTRANSPORTEXIT MQ_TRANSPORT_EXIT

  procedure MQ_TRANSPORT_EXIT (
     pExitParms: Pointer;          (* Exit parameter block *)
     DestAddressLength: MQLONG;    (* Length in bytes of destination IP
                                      address *)
     pDestAddress: PMQCHAR);       (* Destination IP address *)
  cdecl;
  external 'mqm.dll' name 'MQ_TRANSPORT_EXIT';



 (*********************************************************************)
 (*  MQXCLWLN Function -- Cluster Workload Navigate Records           *)
 (*********************************************************************)

  procedure MQXCLWLN (
    var ExitParms : TMQWXP;     (* Exit parameter structure *)
    pCurrentRecord: Pointer;    (* Address of current record *)
    NextOffset    : MQLONG;     (* Offset of next record *)
    pNextRecord   : Pointer;    (* Address of next record or structure *)
    var CompCode  : MQLONG;     (* Completion code *)
    var Reason    : MQLONG);    (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQXCLWLN';


 (*********************************************************************)
 (*  MQXCNVC Function -- Convert Characters                           *)
 (*********************************************************************)

  procedure MQXCNVC (
    Hconn         : MQHCONN;   (* Connection handle *)
    Options       : MQLONG;    (* Options that control the action of
                                  MQXCNVC *)
    SourceCCSID   : MQLONG;    (* Coded character set identifier of string
                                  before conversion *)
    SourceLength  : MQLONG;    (* Length of string before conversion *)
    pSourceBuffer : PMQCHAR;   (* String to be converted *)
    TargetCCSID   : MQLONG;    (* Coded character set identifier of string
                                  after conversion *)
    TargetLength  : MQLONG;    (* Length of output buffer *)
    pTargetBuffer : PMQCHAR;   (* String after conversion *)
    var DataLength: MQLONG;    (* Length of output string *)
    var CompCode  : MQLONG;    (* Completion code *)
    var Reason    : MQLONG);   (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQXCNVC';

procedure SetMQCD_DEFAULT(var struct: TMQCD);
procedure SetMQDXP_DEFAULT(var struct: TMQDXP);
procedure SetMQCD_CLIENT_CONN_DEFAULT(var struct: TMQCD);
procedure SetMQCXP_DEFAULT(var struct: TMQCXP);
procedure SetMQPXP_DEFAULT(var struct: TMQPXP);
procedure SetMQWDR_DEFAULT(var struct: TMQWDR);
procedure SetMQWQR_DEFAULT(var struct: TMQWQR);
procedure SetMQWXP_DEFAULT(var struct: TMQWXP);

implementation

procedure SetMQCD_DEFAULT(var struct: TMQCD);
begin
  FillChar(struct, SizeOf(Struct), 0);
  with struct do begin
    ChannelName := '';
    Version := MQCD_CURRENT_VERSION;
    ChannelType :=  MQCHT_SENDER;
    TransportType := MQXPT_LU62;
    Desc := '';
    QMgrName := '';
    XmitQName := '';
    ShortConnectionName := '';
    MCAName := '';
    ModeName := '';
    TpName := '';
    BatchSize := 50;
    DiscInterval := 6000;
    ShortRetryCount := 10;
    ShortRetryInterval := 60;
    LongRetryCount := 999999999;
    LongRetryInterval := 1200;
    SecurityExit := '';
    MsgExit := '';
    SendExit := '';
    ReceiveExit := '';
    SeqNumberWrap := 999999999;
    MaxMsgLength := 4194304;
    PutAuthority := MQPA_DEFAULT;
    DataConversion := MQCDC_NO_SENDER_CONVERSION;
    SecurityUserData := '';
    MsgUserData := '';
    SendUserData := '';
    ReceiveUserData := '';
    UserIdentifier := '';
    Password := '';
    MCAUserIdentifier := '';
    MCAType := MQMCAT_PROCESS;
    ConnectionName := '';
    RemoteUserIdentifier := '';
    RemotePassword := '';
    MsgRetryExit := '';
    MsgRetryUserData := '';
    MsgRetryCount := 10;
    MsgRetryInterval := 1000;
    HeartbeatInterval := 300;
    BatchInterval := 0;
    NonPersistentMsgSpeed := MQNPMS_FAST;
    StrucLength := MQCD_CURRENT_LENGTH;
    ExitNameLength := MQ_EXIT_NAME_LENGTH;
    ExitDataLength := MQ_EXIT_DATA_LENGTH;
    MsgExitsDefined := 0;
    SendExitsDefined := 0;
    ReceiveExitsDefined := 0;
    MsgExitPtr := nil;
    MsgUserDataPtr := nil;
    SendExitPtr := nil;
    SendUserDataPtr := nil;
    ReceiveExitPtr := nil;
    ReceiveUserDataPtr := nil;
    ClusterPtr := nil;
    ClustersDefined := 0;
    NetworkPriority := 0;
    LongMCAUserIdLength := 0;
    LongRemoteUserIdLength := 0;
    LongMCAUserIdPtr := nil;
    LongRemoteUserIdPtr := nil;
//    MCASecurityId := MQSID_NONE;
//    RemoteSecurityId := MQSID_NONE;
  end;
end;

procedure SetMQCD_CLIENT_CONN_DEFAULT(var struct: TMQCD);
begin
  FillChar(struct, SizeOf(Struct), 0);
  with struct do begin
    ChannelName := '';
    Version := MQCD_VERSION_6;
    ChannelType := MQCHT_CLNTCONN;
    TransportType := MQXPT_TCP;
    Desc := '';
    QMgrName := '';
    XmitQName := '';
    ShortConnectionName := '';
    MCAName := '';
    ModeName := '';
    TpName := '';
    BatchSize := 50;
    DiscInterval := 6000;
    ShortRetryCount := 10;
    ShortRetryInterval := 60;
    LongRetryCount := 999999999;
    LongRetryInterval := 1200;
    SecurityExit := '';
    MsgExit := '';
    SendExit := '';
    ReceiveExit := '';
    SeqNumberWrap := 999999999;
    MaxMsgLength := 4194304;
    PutAuthority := MQPA_DEFAULT;
    DataConversion := MQCDC_NO_SENDER_CONVERSION;
    SecurityUserData := '';
    MsgUserData := '';
    SendUserData := '';
    ReceiveUserData := '';
    UserIdentifier := '';
    Password := '';
    MCAUserIdentifier := '';
    MCAType := MQMCAT_PROCESS;
    ConnectionName := '';
    RemoteUserIdentifier := '';
    RemotePassword := '';
    MsgRetryExit := '';
    MsgRetryUserData := '';
    MsgRetryCount := 10;
    MsgRetryInterval := 1000;
    HeartbeatInterval := 1;
    BatchInterval := 0;
    NonPersistentMsgSpeed := MQNPMS_FAST;
    StrucLength := MQCD_LENGTH_6;
    ExitNameLength := MQ_EXIT_NAME_LENGTH;
    ExitDataLength := MQ_EXIT_DATA_LENGTH;
    MsgExitsDefined := 0;
    SendExitsDefined := 0;
    ReceiveExitsDefined := 0;
    MsgExitPtr := nil;
    MsgUserDataPtr := nil;
    SendExitPtr := nil;
    SendUserDataPtr := nil;
    ReceiveExitPtr := nil;
    ReceiveUserDataPtr := nil;
    ClusterPtr := nil;
    ClustersDefined := 0;
    NetworkPriority := 0;
    LongMCAUserIdLength := 0;
    LongRemoteUserIdLength := 0;
    LongMCAUserIdPtr := nil;
    LongRemoteUserIdPtr := nil;
//    MCASecurityId := MQSID_NONE_ARRAY;
//    RemoteSecurityId := MQSID_NONE_ARRAY;
  end;
end;

procedure SetMQCXP_DEFAULT(var struct: TMQCXP);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucId := MQCXP_STRUC_ID;
    Version := MQCXP_CURRENT_VERSION;
    ExitId := 0;
    ExitReason := 0;
    ExitResponse := MQXCC_OK;
    ExitResponse2 := MQXR2_PUT_WITH_DEF_ACTION;
    Feedback := 0;
    MaxSegmentLength := 0;
//    ExitUserArea := MQXUA_NONE_ARRAY;
    ExitData := '';
    MsgRetryCount := 0;
    MsgRetryInterval := 0;
    MsgRetryReason := 0;
    HeaderLength := 0;
    PartnerName := '';
    FAPLevel := 0;
    CapabilityFlags := MQCF_NONE;
    ExitNumber := 1;
    ExitSpace := 0;
  end;
end;

procedure SetMQDXP_DEFAULT(var struct: TMQDXP);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucId := MQDXP_STRUC_ID_ARRAY;
    Version := MQDXP_CURRENT_VERSION;
    ExitOptions := 0;
    AppOptions := 0;
    Encoding := 0;
    CodedCharSetId := 0;
    DataLength := 0;
    CompCode := MQCC_OK;
    Reason := MQRC_NONE;
    ExitResponse := MQXDR_CONVERSION_FAILED;
    Hconn := 0;
  end;
end;

procedure SetMQPXP_DEFAULT(var struct: TMQPXP);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucId := MQPXP_STRUC_ID;
    Version := MQPXP_CURRENT_VERSION;
    ExitId := MQXT_PUBSUB_ROUTING_EXIT;
    ExitReason := 0;
    ExitResponse := MQXCC_OK;
    ExitResponse2 := 0;
    Feedback := MQFB_NONE;
    ExitNumber := 1;
//    ExitUserArea := MQXUA_NONE_ARRAY;
    ExitData := '';
    HeaderLength := 0;
    MsgInLength := 0;
    MsgOutLength := 0;
    DestinationType := MQDT_APPL;
    MsgDescPtr := nil;
    MsgInPtr := nil;
    MsgOutPtr := nil;
    StreamName := '';
    QMgrName := '';
    DestinationQName := '';
    DestinationQMgrName := '';
  end;
end;

procedure SetMQWDR_DEFAULT(var struct: TMQWDR);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucId := MQWDR_STRUC_ID;
    Version := MQWDR_CURRENT_VERSION;
    StrucLength := MQWDR_CURRENT_LENGTH;
    QMgrFlags := 0;
    QMgrIdentifier := '';
    QMgrName := '';
    ClusterRecOffset := 0;
    ChannelState := 0;
    ChannelDefOffset := 0;
  end;
end;

procedure SetMQWQR_DEFAULT(var struct: TMQWQR);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucId := MQWQR_STRUC_ID;
    Version := MQWQR_CURRENT_VERSION;
    StrucLength := MQWQR_CURRENT_LENGTH;
    QFlags := 0;
    QName := '';
    QMgrIdentifier := '';
    ClusterRecOffset := 0;
    QType := 0;
    QDesc := '';
    DefBind := 0;
    DefPersistence := 0;
    DefPriority := 0;
    InhibitPut := 0;
  end;
end;

procedure SetMQWXP_DEFAULT(var struct: TMQWXP);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucId := MQWXP_STRUC_ID;
    Version := MQWXP_CURRENT_VERSION;
    ExitId := 0;
    ExitReason := 0;
    ExitResponse := MQXCC_OK;
    ExitResponse2 := 0;
    Feedback := 0;
    Reserved := 0;
//    ExitUserArea := MQXUA_NONE_ARRAY;
    ExitData := '';
    MsgDescPtr := nil;
    MsgBufferPtr := nil;
    MsgBufferLength := 0;
    MsgLength := 0;
    QName := '';
    QMgrName := '';
    DestinationCount := 0;
    DestinationChosen := 0;
    DestinationArrayPtr := nil;
    QArrayPtr := nil;
    CacheContext := nil;
    CacheType := MQCLCT_DYNAMIC;
  end;
end;



end.
