unit CMQZPas;

// **************************************************************************
// **************************************************************************
// **************************************************************************
// MQSeries IBM library ported for Delphi by Dinko Miljak
// e-mail: dinmil@flashmail.com
// version 0.0.4 2001-05-07
// **************************************************************************
// **************************************************************************
// **************************************************************************

 (*********************************************************************)
 (*                                                                   *)
 (*                  IBM MQSeries for Windows NT  and Windows 2000    *)
 (*                                                                   *)
 (*  HEADER NAME:    CMQZC                                            *)
 (*                                                                   *)
 (*  DESCRIPTION:    Declarations for Installable Services            *)
 (*                                                                   *)
 (*********************************************************************)
 (*  @START_COPYRIGHT@                                                *)
 (*  Licensed Materials - Property of IBM                             *)
 (*                                                                   *)
 (*  0784726, 5639-B43                                                *)
 (*                                                                   *)
 (*  (C) Copyright IBM Corporation 1995, 2000.                        *)
 (*                                                                   *)
 (*  Status: Version 5 Release 2                                      *)
 (*  @END_COPYRIGHT@                                                  *)
 (*********************************************************************)
 (*                                                                   *)
 (*  FUNCTION:       This file declares the functions, structures,    *)
 (*                  and named constants for installable services.    *)
 (*                                                                   *)
 (*  PROCESSOR:      C                                                *)
 (*                                                                   *)
 (*********************************************************************)

interface

uses SysUtils, CMQPas;

const

 (*********************************************************************)
 (*  Values Related to MQZED Structure                                *)
 (*********************************************************************)

 (* Structure Identifier *)
  MQZED_STRUC_ID = 'ZED ';

 (* Structure Identifier (array form) *)
  MQZED_STRUC_ID_ARRAY : MQCHAR4 = ('Z','E','D',' ');

 (* Structure Version Number *)
  MQZED_VERSION_1       = 1;
  MQZED_CURRENT_VERSION = 1;


 (*********************************************************************)
 (*  Values related to MQZEP function                                 *)
 (*********************************************************************)

 (* Function ids common to all services *)
  MQZID_INIT = 0;
  MQZID_TERM = 1;

 (* Function ids for Authority service *)
  MQZID_INIT_AUTHORITY         = 0;
  MQZID_TERM_AUTHORITY         = 1;
  MQZID_CHECK_AUTHORITY        = 2;
  MQZID_COPY_ALL_AUTHORITY     = 3;
  MQZID_DELETE_AUTHORITY       = 4;
  MQZID_SET_AUTHORITY          = 5;
  MQZID_GET_AUTHORITY          = 6;
  MQZID_GET_EXPLICIT_AUTHORITY = 7;
  MQZID_REFRESH_CACHE          = 8;

 (* Function ids for Name service *)
  MQZID_INIT_NAME   = 0;
  MQZID_TERM_NAME   = 1;
  MQZID_LOOKUP_NAME = 2;
  MQZID_INSERT_NAME = 3;
  MQZID_DELETE_NAME = 4;

 (* Function ids for Userid service *)
  MQZID_INIT_USERID = 0;
  MQZID_TERM_USERID = 1;
  MQZID_FIND_USERID = 2;


 (*********************************************************************)
 (*  Values related to all services                                   *)
 (*********************************************************************)

 (* Initialization Options *)
  MQZIO_PRIMARY   = 0;
  MQZIO_SECONDARY = 1;

 (* Termination Options *)
  MQZTO_PRIMARY   = 0;
  MQZTO_SECONDARY = 1;

 (* Continuation Indicator *)
  MQZCI_DEFAULT  = 0;
  MQZCI_CONTINUE = 0;
  MQZCI_STOP     = 1;


 (*********************************************************************)
 (*  Values related to Authority service                              *)
 (*********************************************************************)

 (* Service Interface Version *)
  MQZAS_VERSION_1 = 1;
  MQZAS_VERSION_2 = 2;
  MQZAS_VERSION_3 = 3;

 (* Authorizations *)
  MQZAO_CONNECT                  = $00000001;
  MQZAO_BROWSE                   = $00000002;
  MQZAO_INPUT                    = $00000004;
  MQZAO_OUTPUT                   = $00000008;
  MQZAO_INQUIRE                  = $00000010;
  MQZAO_SET                      = $00000020;
  MQZAO_PASS_IDENTITY_CONTEXT    = $00000040;
  MQZAO_PASS_ALL_CONTEXT         = $00000080;
  MQZAO_SET_IDENTITY_CONTEXT     = $00000100;
  MQZAO_SET_ALL_CONTEXT          = $00000200;
  MQZAO_ALTERNATE_USER_AUTHORITY = $00000400;
  MQZAO_ALL_MQI                  = $000007ff;
  MQZAO_CREATE                   = $00010000;
  MQZAO_DELETE                   = $00020000;
  MQZAO_DISPLAY                  = $00040000;
  MQZAO_CHANGE                   = $00080000;
  MQZAO_CLEAR                    = $00100000;
  MQZAO_AUTHORIZE                = $00800000;
  MQZAO_ALL_ADMIN                = $009e0000;
  MQZAO_ALL                      = $009e07ff;
  MQZAO_NONE                     = $00000000;

 (* Entity Types *)
  MQZAET_PRINCIPAL = $00000001;
  MQZAET_GROUP     = $00000002;


 (*********************************************************************)
 (*  Values related to Name service                                   *)
 (*********************************************************************)

 (* Service Interface Version *)
  MQZNS_VERSION_1 = 1;


 (*********************************************************************)
 (*  Values related to Userid service                                 *)
 (*********************************************************************)

 (* Service Interface Version *)
  MQZUS_VERSION_1 = 1;


 (*********************************************************************)
 (*  Simple Data Types                                                *)
 (*********************************************************************)

 type
   MQHCONFIG = MQLONG;
   PMQHCONFIG = ^MQHCONFIG;
   PMQFUNC = MQPOINTER;


 (*********************************************************************)
 (*  MQZED Structure -- Entity Data                                   *)
 (*********************************************************************)

 TMQZED = record
   StrucId        : MQCHAR4;        (* Structure identifier *)
   Version        : MQLONG;         (* Structure version number *)
   EntityNamePtr  : PMQCHAR;        (* Address of entity name *)
   EntityDomainPtr: PMQCHAR;        (* Address of entity domain name *)
   SecurityId     : MQBYTE40;       (* Security identifier *)
 end;
 PMQZED = ^TMQZED;

 (*
  MQZED_DEFAULT {MQZED_STRUC_ID_ARRAY},\
                       MQZED_VERSION_1,\
                       NULL,\
                       NULL,\
                       {MQSID_NONE_ARRAY}
 *)

 (*********************************************************************)
 (*  MQZEP -- Add Component Entry Point                               *)
 (*********************************************************************)

  procedure MQZEP (
    Hconfig     : MQHCONFIG;     (* Configuration handle *)
    _Function   : MQLONG;        (* Function identifier *)
    EntryPoint  : PMQFUNC;       (* Function entry point *)
    var CompCode: MQLONG;        (* Completion code *)
    var Reason  : MQLONG);       (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZEP';


 (*********************************************************************)
 (*  Function datatypes for Authority services                        *)
 (*********************************************************************)

 (*********************************************************************)
 (*  MQZ_INIT_AUTHORITY -- Initialize Authority-Services              *)
 (*********************************************************************)

  procedure MQZ_INIT_AUTHORITY (
    Hconfig            : MQHCONFIG;    (* Configuration handle *)
    Options            : MQLONG;       (* Initialization options *)
    pQMgrName          : PChar;        (* Queue manager name *)
    ComponentDataLength: MQLONG;       (* Length of component data *)
    var ComponentData  : MQBYTE;       (* Component data *)
    var Version        : MQLONG;       (* Version number *)
    var CompCode       : MQLONG;       (* Completion code *)
    var Reason         : MQLONG);      (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_INIT_AUTHORITY';

 (*********************************************************************)
 (*  MQZ_TERM_AUTHORITY -- Terminate Authority-Services               *)
 (*********************************************************************)

  procedure MQZ_TERM_AUTHORITY (
    Hconfig            : MQHCONFIG;    (* Configuration handle *)
    Options            : MQLONG;       (* Termination options *)
    var QMgrName       : PChar;        (* Queue manager name *)
    var ComponentData  : MQBYTE;       (* Component data *)
    var CompCode       : MQLONG;       (* Completion code *)
    var Reason         : MQLONG);      (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_TERM_AUTHORITY';


 (*********************************************************************)
 (*  MQZ_DELETE_AUTHORITY -- Delete Authority                         *)
 (*********************************************************************)

  procedure MQZ_DELETE_AUTHORITY (
    QMgrName           : PChar;    (* Queue manager name *)
    ObjectName         : PChar;    (* Object name *)
    ObjectType         : MQLONG;   (* Object type *)
    var ComponentData  : MQBYTE;   (* Component data *)
    var Continuation   : MQLONG;   (* Continuation indicator set by component *)
    var CompCode       : MQLONG;   (* Completion code *)
    var Reason         : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_DELETE_AUTHORITY';


 (*********************************************************************)
 (*  MQZ_GET_AUTHORITY -- Get Authority                               *)
 (*********************************************************************)

  procedure MQZ_GET_AUTHORITY (
    QMgrName           : PChar;    (* Queue manager name *)
    EntityName         : PChar;    (* Entity name *)
    EntityType         : MQLONG;   (* Entity type *)
    ObjectName         : PChar;    (* Object name *)
    ObjectType         : MQLONG;   (* Object type *)
    var Authority      : MQLONG;   (* Authority of entity *)
    var ComponentData  : MQBYTE;   (* Component data *)
    var Continuation   : MQLONG;   (* Continuation indicator set by component *)
    var CompCode       : MQLONG;   (* Completion code *)
    var Reason         : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_GET_AUTHORITY';


 (*********************************************************************)
 (*  MQZ_GET_AUTHORITY_2 -- Get Authority Version 2                   *)
 (*********************************************************************)

  procedure MQZ_GET_AUTHORITY_2 (
    QMgrName           : PChar;    (* Queue manager name *)
    var EntityData     : TMQZED;   (* Entity data *)
    EntityType         : MQLONG;   (* Entity type *)
    ObjectName         : PChar;    (* Object name *)
    ObjectType         : MQLONG;   (* Object type *)
    var Authority      : MQLONG;   (* Authority of entity *)
    var ComponentData  : MQBYTE;   (* Component data *)
    var Continuation   : MQLONG;   (* Continuation indicator set by component *)
    var CompCode       : MQLONG;   (* Completion code *)
    var Reason         : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_GET_AUTHORITY_2';


 (*********************************************************************)
 (*  MQZ_GET_EXPLICIT_AUTHORITY -- Get Explicit Authority             *)
 (*********************************************************************)

  procedure MQZ_GET_EXPLICIT_AUTHORITY (
    QMgrName           : PChar;    (* Queue manager name *)
    EntityName         : PChar;    (* Entity name *)
    EntityType         : MQLONG;   (* Entity type *)
    ObjectName         : PChar;    (* Object name *)
    ObjectType         : MQLONG;   (* Object type *)
    var Authority      : MQLONG;   (* Authority of entity *)
    AuthorityMask      : MQLONG;   (* Mask for relevant authorities *)
    var ComponentData  : MQBYTE;   (* Component data *)
    var Continuation   : MQLONG;   (* Continuation indicator set by component *)
    var CompCode       : MQLONG;   (* Completion code *)
    var Reason         : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_GET_EXPLICIT_AUTHORITY';


 (*********************************************************************)
 (*  MQZ_GET_EXPLICIT_AUTHORITY_2 -- Get Explicit Authority Version 2 *)
 (*********************************************************************)

  procedure MQZ_GET_EXPLICIT_AUTHORITY_2 (
    QMgrName           : PChar;    (* Queue manager name *)
    var EntityData     : TMQZED;   (* Entity data *)
    EntityType         : MQLONG;   (* Entity type *)
    ObjectName         : PChar;    (* Object name *)
    ObjectType         : MQLONG;   (* Object type *)
    var Authority      : MQLONG;   (* Authority of entity *)
    AuthorityMask      : MQLONG;   (* Mask for relevant authorities *)
    var ComponentData  : MQBYTE;   (* Component data *)
    var Continuation   : MQLONG;   (* Continuation indicator set by component *)
    var CompCode       : MQLONG;   (* Completion code *)
    var Reason         : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_GET_EXPLICIT_AUTHORITY_2';


 (*********************************************************************)
 (*  MQZ_SET_AUTHORITY -- Set Authority                               *)
 (*********************************************************************)

  procedure MQZ_SET_AUTHORITY (
    QMgrName           : PChar;    (* Queue manager name *)
    EntityName         : PChar;    (* Entity name *)
    EntityType         : MQLONG;   (* Entity type *)
    ObjectName         : PChar;    (* Object name *)
    ObjectType         : MQLONG;   (* Object type *)
    Authority          : MQLONG;   (* Authority of entity *)
    var ComponentData  : MQBYTE;   (* Component data *)
    var Continuation   : MQLONG;   (* Continuation indicator set by component *)
    var CompCode       : MQLONG;   (* Completion code *)
    var Reason         : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_SET_AUTHORITY';


 (*********************************************************************)
 (*  MQZ_SET_AUTHORITY_2 -- Set Authority Version 2                   *)
 (*********************************************************************)

  procedure MQZ_SET_AUTHORITY_2 (
    QMgrName           : PChar;    (* Queue manager name *)
    var EntityData     : TMQZED;   (* Entity data *)
    EntityType         : MQLONG;   (* Entity type *)
    pObjectName        : PChar;    (* Object name *)
    ObjectType         : MQLONG;   (* Object type *)
    Authority          : MQLONG;   (* Authority of entity *)
    var ComponentData  : MQBYTE;   (* Component data *)
    var Continuation   : MQLONG;   (* Continuation indicator set by component *)
    var CompCode       : MQLONG;   (* Completion code *)
    var Reason         : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_SET_AUTHORITY_2';


 (*********************************************************************)
 (*  MQZ_COPY_ALL_AUTHORITY -- Copy All Authority                     *)
 (*********************************************************************)

  procedure MQZ_COPY_ALL_AUTHORITY (
    QMgrName           : PChar;    (* Queue manager name *)
    RefObjectName      : PChar;    (* Reference object name *)
    ObjectName         : PChar;    (* Object name *)
    ObjectType         : MQLONG;   (* Object type *)
    var ComponentData  : MQBYTE;   (* Component data *)
    var Continuation   : MQLONG;   (* Continuation indicator set by component *)
    var CompCode       : MQLONG;   (* Completion code *)
    var Reason         : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_COPY_ALL_AUTHORITY';


 (*********************************************************************)
 (*  MQZ_CHECK_AUTHORITY -- Check Authority                           *)
 (*********************************************************************)

  procedure MQZ_CHECK_AUTHORITY (
    QMgrName           : PChar;    (* Queue manager name *)
    EntityName         : PChar;    (* Entity name *)
    EntityType         : MQLONG;   (* Entity type *)
    ObjectName         : PChar;    (* Object name *)
    ObjectType         : MQLONG;   (* Object type *)
    Authority          : MQLONG;   (* Authority to be checked *)
    var ComponentData  : MQBYTE;   (* Component data *)
    var Continuation   : MQLONG;   (* Continuation indicator set by component *)
    var CompCode       : MQLONG;   (* Completion code *)
    var Reason         : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_CHECK_AUTHORITY';


 (*********************************************************************)
 (*  MQZ_CHECK_AUTHORITY_2 -- Check Authority Version 2               *)
 (*********************************************************************)

  procedure MQZ_CHECK_AUTHORITY_2 (
    QMgrName           : PChar;    (* Queue manager name *)
    var EntityData     : TMQZED;   (* Entity data *)
    EntityType         : MQLONG;   (* Entity type *)
    ObjectName         : PChar;    (* Object name *)
    ObjectType         : MQLONG;   (* Object type *)
    Authority          : MQLONG;   (* Authority to be checked *)
    var ComponentData  : MQBYTE;   (* Component data *)
    var Continuation   : MQLONG;   (* Continuation indicator set by component *)
    var CompCode       : MQLONG;   (* Completion code *)
    var Reason         : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_CHECK_AUTHORITY_2';


 (*********************************************************************)
 (*  MQZ_REFRESH_CACHE -- Refresh Cache                               *)
 (*********************************************************************)

  procedure MQZ_REFRESH_CACHE (
    QMgrName           : PChar;    (* Queue manager name *)
    var ComponentData  : MQBYTE;   (* Component data *)
    var Continuation   : MQLONG;   (* Continuation indicator set by component *)
    var CompCode       : MQLONG;   (* Completion code *)
    var Reason         : MQLONG);  (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_REFRESH_CACHE';


 (*********************************************************************)
 (*  Function datatypes for Name services                             *)
 (*********************************************************************)

 (*********************************************************************)
 (*  MQZ_INIT_NAME -- Initialize Name-Services                        *)
 (*********************************************************************)

  procedure MQZ_INIT_NAME (
    Hconfig            : MQHCONFIG; (* Configuration handle *)
    Options            : MQLONG;    (* Initialization options *)
    QMgrName           : PChar;     (* Queue manager name *)
    ComponentDataLength: MQLONG;    (* Length of component data *)
    var ComponentData  : MQBYTE;    (* Component data *)
    var Continuation   : MQLONG;    (* Continuation indicator set by component *)
    var CompCode       : MQLONG;    (* Completion code *)
    var Reason         : MQLONG);   (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_INIT_NAME';


 (*********************************************************************)
 (*  MQZ_TERM_NAME -- Terminate Name-Services                         *)
 (*********************************************************************)

  procedure MQZ_TERM_NAME (
    Hconfig            : MQHCONFIG; (* Configuration handle *)
    Options            : MQLONG;    (* Termination options *)
    var ComponentData  : MQBYTE;    (* Component data *)
    var Continuation   : MQLONG;    (* Continuation indicator set by component *)
    var CompCode       : MQLONG;    (* Completion code *)
    var Reason         : MQLONG);   (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_TERM_NAME';


 (*********************************************************************)
 (*  MQZ_LOOKUP_NAME -- Look-Up Name                                  *)
 (*********************************************************************)

  procedure MQZ_LOOKUP_NAME (
    QMgrName           : PChar;     (* Queue manager name *)
    QName              : PChar;     (* Queue name *)
    ResolvedQMgrName   : PChar;     (* Resolved queue manager name *)
    var ComponentData  : MQBYTE;    (* Component data *)
    var Continuation   : MQLONG;    (* Continuation indicator set by component *)
    var CompCode       : MQLONG;    (* Completion code *)
    var Reason         : MQLONG);   (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_LOOKUP_NAME';


 (*********************************************************************)
 (*  MQZ_INSERT_NAME -- Insert Name                                   *)
 (*********************************************************************)

  procedure MQZ_INSERT_NAME (
    QMgrName           : PChar;     (* Queue manager name *)
    QName              : PChar;     (* Queue name *)
    ResolvedQMgrName   : PChar;     (* Resolved queue manager name *)
    var ComponentData  : MQBYTE;    (* Component data *)
    var Continuation   : MQLONG;    (* Continuation indicator set by component *)
    var CompCode       : MQLONG;    (* Completion code *)
    var Reason         : MQLONG);   (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_INSERT_NAME';


 (*********************************************************************)
 (*  MQZ_DELETE_NAME -- Delete Name                                   *)
 (*********************************************************************)

 procedure MQZ_DELETE_NAME (
    QMgrName           : PChar;     (* Queue manager name *)
    QName              : PChar;     (* Queue name *)
    var ComponentData  : MQBYTE;    (* Component data *)
    var Continuation   : MQLONG;    (* Continuation indicator set by component *)
    var CompCode       : MQLONG;    (* Completion code *)
    var Reason         : MQLONG);   (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_DELETE_NAME';


 (*********************************************************************)
 (*  Function datatypes for Userid services                           *)
 (*********************************************************************)

 (*********************************************************************)
 (*  MQZ_INIT_USERID -- Initialize Userid-Services                    *)
 (*********************************************************************)

  procedure MQZ_INIT_USERID (
    Hconfig            : MQHCONFIG; (* Configuration handle *)
    Options            : MQLONG;    (* Initialization options *)
    QMgrName           : PChar;     (* Queue manager name *)
    ComponentDataLength: MQLONG;    (* Length of component data *)
    var ComponentData  : MQBYTE;    (* Component data *)
    var Continuation   : MQLONG;    (* Continuation indicator set by component *)
    var CompCode       : MQLONG;    (* Completion code *)
    var Reason         : MQLONG);   (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_INIT_USERID';


 (*********************************************************************)
 (*  MQZ_TERM_USERID -- Terminate Userid-Services                     *)
 (*********************************************************************)

  procedure MQZ_TERM_USERID (
    Hconfig            : MQHCONFIG;  (* Configuration handle *)
    Options            : MQLONG;    (* Termination options *)
    QMgrName           : PChar;     (* Queue manager name *)
    var ComponentData  : MQBYTE;    (* Component data *)
    var CompCode       : MQLONG;    (* Completion code *)
    var Reason         : MQLONG);   (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_TERM_USERID';


 (*********************************************************************)
 (*  MQZ_FIND_USERID -- Find Userid                                   *)
 (*********************************************************************)

  procedure MQZ_FIND_USERID (
    QMgrName           : PChar;     (* Queue manager name *)
    Userid             : PChar;     (* User identifier *)
    Password           : PChar;     (* Password *)
    var ComponentData  : MQBYTE;    (* Component data *)
    var Continuation   : MQLONG;    (* Continuation indicator set by component *)
    var CompCode       : MQLONG;    (* Completion code *)
    var Reason         : MQLONG);   (* Reason code qualifying CompCode *)
  cdecl;
  external 'mqm.dll' name 'MQZ_FIND_USERID';

procedure SetMQZED_DEFAULT(var struct: TMQZED);

implementation

procedure SetMQZED_DEFAULT(var struct: TMQZED);
begin
  FillChar(struct, SizeOf(struct), 0);
  with struct do begin
    StrucId := MQZED_STRUC_ID;
    Version := MQZED_VERSION_1;
    EntityNamePtr := nil;
    EntityDomainPtr := nil;
//    SecurityId := MQSID_NONE_ARRAY;
  end;
end;

end.
