program MQAIDemo;

// **************************************************************************
// **************************************************************************
// **************************************************************************
// MQSeries IBM library test program for Delphi
// Author: Dinko Miljak
// e-mail: dinmil@flashmail.com
// version 0.0.3
// **************************************************************************
// **************************************************************************
// **************************************************************************

{$APPTYPE CONSOLE}
{$A-}  // alignment settings - aviod problems between different languages

uses
  SysUtils,
  CMQBPas in '..\lib\CMQBPas.pas',
  CMQCFPas in '..\lib\CMQCFPas.pas',
  CMQPas in '..\lib\CMQPas.pas',
  CMQPSPas in '..\lib\CMQPSPas.pas',
  CMQXPas in '..\lib\CMQXPas.pas',
  CMQZPas in '..\lib\CMQZPas.pas';

procedure CheckCallResult(Const callText: String; cc: MQLONG; rc: MQLONG);
begin
  if (cc <> MQCC_OK) then begin
    Writeln(Format('%s failed: Completion Code = %d : Reason = %d"', [callText, cc, rc]));
  end;
end;

function PrintBagContents(dataBag: MQHBAG; indent: Integer): Integer;
const LENGTH = 500; // Max length of string to be read
      INDENT_ = 4;   // Number of spaces to indent
                    // embedded bag display
var itemCount: MQLONG;                  // Number of items in the bag
    itemType : MQLONG;                  // Type of the item
    i: Integer;                         // Index of item in the bag
    stringVal: array[0..LENGTH+1] of Char; // Value if item is a string
    stringLength: MQLONG;               // Length of string value
    ccsid: MQLONG;                      // CCSID of string value
    iValue: MQLONG;                     // Value if item is an integer
    selector: MQLONG;                   // Selector of item
    bagHandle: MQHBAG;                  // Value if item is a bag handle
    reason: MQLONG;                     // reason code
    compCode: MQLONG;                   // completion code
    trimLength: MQLONG;                 // Length of string to be trimmed
    errors: Integer;                    // Count of errors found
    blanks: String;                     // Blank string used to indent display
begin
  errors := 0;
  blanks := '                       ';

  (***************************************************************************)
  (* Count the number of items in the bag                                    *)
  (***************************************************************************)
  mqCountItems(dataBag, MQSEL_ALL_SELECTORS, itemCount, compCode, reason);

  if (compCode <> MQCC_OK) then begin
    Inc(errors);
  end
  else begin
    Writeln(Format('%.*sHandle:%d ', [indent, blanks, dataBag]));
    Writeln(Format('%.*sSize:%d', [indent, blanks, itemCount]));
    Writeln(Format('%.*sIndex: Selector: Value:', [indent, blanks]));
  end;

  (***************************************************************************)
  (* If no errors found, display each item in the bag                        *)
  (***************************************************************************)
  if (errors = 0) then begin
    for i := 0 to itemCount-1 do begin
      (********************************************************************)
      (* First inquire the type of the item for each item in the bag      *)
      (********************************************************************)
      mqInquireItemInfo(dataBag,             (* Bag handle                *)
                        MQSEL_ANY_SELECTOR,  (* Item can have any selector*)
                        i,                   (* Index position in the bag *)
                        selector,            (* Actual value of selector  *)
                                             (* returned by call          *)
                        itemType,            (* Actual type of item       *)
                                             (* returned by call          *)
                        compCode,            (* Completion code           *)
                        reason);             (* Reason Code               *)

      if (compCode <> MQCC_OK) then begin
        Inc(errors);
      end;

      case itemType of
        MQIT_INTEGER: begin
          (***************************************************************)
          (* Item is an integer. Find its value and display its index,   *)
          (* selector and value.                                         *)
          (***************************************************************)
          mqInquireInteger(dataBag,         (* Bag handle                *)
                           MQSEL_ANY_SELECTOR, (* Allow any selector     *)
                           i,               (* Index position in the bag *)
                           iValue,          (* Returned integer value    *)
                           compCode,        (* Completion code           *)
                           reason);         (* Reason Code               *)

          if (compCode <> MQCC_OK) then begin
            Inc(errors);
          end
          else begin
             Writeln(Format('%.*s  %-2d     %-4d     (%d)',
                           [indent, blanks, i, selector, iValue]));
          end;
        end;
        MQIT_STRING: begin
          (***************************************************************)
          (* Item is a string. Obtain the string in a buffer, prepare    *)
          (* the string for displaying and display the index, selector,  *)
          (* string and Character Set ID.                                *)
          (***************************************************************)
          mqInquireString(dataBag,          (* Bag handle                *)
                          MQSEL_ANY_SELECTOR, (* Allow any selector      *)
                          i,                (* Index position in the bag *)
                          LENGTH,          (* Maximum length of buffer  *)
                          @stringVal,      (* Buffer to receive string  *)
                          stringLength,    (* Actual length of string   *)
                          ccsid,           (* Coded character set id    *)
                          compCode,        (* Completion code           *)
                          reason);         (* Reason Code               *)

          (***************************************************************)
          (* The call can return a warning if the string is too long for *)
          (* the output buffer and has been truncated, so only check     *)
          (* explicitly for call failure.                                *)
          (***************************************************************)
          if (compCode = MQCC_FAILED) then begin
            Inc(errors);
          end
          else begin
            (************************************************************)
            (* Remove trailing blanks from the string and terminate with*)
            (* a null. First check that the string should not have been *)
            (* longer than the maximum buffer size allowed.             *)
            (************************************************************)
            if (stringLength > LENGTH) then begin
               trimLength := LENGTH;
            end
            else begin
               trimLength := stringLength;
            end;
            mqTrim(trimLength, stringVal, stringVal, compCode, reason);
            Writeln(Format('%.*s  %-2d     %-4d     "%s" %d',
                           [indent, blanks, i, selector, stringVal, ccsid]));
          end;
        end;
        MQIT_BAG: begin
          (***************************************************************)
          (* Item is an embedded bag handle, so call the PrintBagContents*)
          (* function again to display the contents.                     *)
          (***************************************************************)
          mqInquireBag(dataBag,             (* Bag handle                *)
                       MQSEL_ANY_SELECTOR,  (* Allow any selector        *)
                       i,                   (* Index position in the bag *)
                       bagHandle,           (* Returned embedded bag hdle*)
                       compCode,            (* Completion code           *)
                       reason);             (* Reason Code               *)

          if (compCode <> MQCC_OK) then begin
            Inc(errors);
          end
          else begin
            Writeln(Format('%.*s  %-2d     %-4d     (%d)',
                           [indent, blanks, i, selector, bagHandle]));
            Writeln(Format('%.*sSystem Bag:"', [indent+INDENT_, blanks]));
            PrintBagContents(bagHandle, indent+INDENT_);
          end;
        end
        else begin
          Writeln(Format('%.*sUnknown item type', [indent, blanks]));
        end;
      end;
    end;
  end;
  Result := errors;
end;



function PrintBag(dataBag: MQHBAG): Integer;
var errors: Integer;
begin
  Writeln;
  errors := PrintBagContents(dataBag, 0);
  Writeln;
  Result := errors;
end;


procedure GetQEvents(hConn: MQHCONN; qName: String);
var openReason: MQLONG;    // MQOPEN reason code
    reason: MQLONG;        // reason code
    compCode: MQLONG;      // completion code
    eventQueue: MQHOBJ;    // handle to event queue
    eventBag: MQHBAG;      // event bag to receive event msg
    od: TMQOD;             // Object Descriptor
    md: TMQMD;             // Message Descriptor
    gmo: TMQGMO;           // get message options
    bQueueOK: MQLONG;      // keep reading msgs while true
begin
  (***************************************************************************)
  (* Set defaults                                                            *)
  (***************************************************************************)
  eventBag := MQHB_UNUSABLE_HBAG;
  SetMQOD_DEFAULT(od);
  SetMQMD_DEFAULT(md);
  SetMQGMO_DEFAULT(gmo);
  bQueueOK := 1;

  (***************************************************************************)
  (* Create an Event Bag in which to receive the event.                      *)
  (* Exit the function if the create fails.                                  *)
  (***************************************************************************)
  mqCreateBag(MQCBO_USER_BAG, eventBag, compCode, reason);
  CheckCallResult('Create event bag', compCode, reason);
  if (compCode <> MQCC_OK) then Exit;

  (***************************************************************************)
  (* Open the event queue chosen by the user                                 *)
  (***************************************************************************)
  StrPLCopy(od.ObjectName, qName, SizeOf(od.ObjectName));
  MQOPEN(hConn, od, MQOO_INPUT_AS_Q_DEF +
                    MQOO_FAIL_IF_QUIESCING,
         eventQueue, compCode, openReason);
  CheckCallResult('Open event queue', compCode, openReason);

  (***************************************************************************)
  (* Set the GMO options to control the action of the get message from the   *)
  (* queue.                                                                  *)
  (***************************************************************************)
  gmo.WaitInterval := 30000;               // 30 second wait for message
  gmo.Options := MQGMO_WAIT + MQGMO_FAIL_IF_QUIESCING + MQGMO_CONVERT;
  gmo.Version := MQGMO_VERSION_2;          // Avoid need to reset Message ID
  gmo.MatchOptions := MQMO_NONE;           // and Correlation ID after every
	                                          // mqGetBag

  (***************************************************************************)
  (* If open fails, we cannot access the queue and must stop the monitor.    *)
  (***************************************************************************)
  if (compCode = MQCC_OK) then bQueueOK := 0;

  (***************************************************************************)
  (* Main loop to get an event message when it arrives                       *)
  (***************************************************************************)
  while (bQueueOK = 0) do begin
    Writeln('Waiting for an event...');

    (*************************************************************************)
    (* Get the message from the event queue and convert it into the event    *)
    (* bag.                                                                  *)
    (*************************************************************************)
    mqGetBag(hConn, eventQueue, md, gmo, eventBag, compCode, reason);

    (*************************************************************************)
    (* If get fails, we cannot access the queue and must stop the monitor.   *)
    (*************************************************************************)
    if (compCode <> MQCC_OK) then begin
      bQueueOK := 0;
      (*********************************************************************)
      (* If get fails because no message available then we have timed out, *)
      (* so report this, otherwise report an error.                        *)
      (*********************************************************************)
      if (reason = MQRC_NO_MSG_AVAILABLE) then begin
        Writeln('No more messages');
      end
      else begin
        CheckCallResult('Get bag', compCode, reason);
      end;
    end

    (*************************************************************************)
    (* Event message read - Print the contents of the event bag              *)
    (*************************************************************************)
    else begin
      if ( PrintBag(eventBag) <> 0 ) then begin
        Writeln('Error found while printing bag contents');
      end;
    end;  (* end of msg found *)
  end; (* end of main loop *)

  (***************************************************************************)
  (* Close the event queue if successfully opened                            *)
  (***************************************************************************)
  if (openReason = MQRC_NONE) then begin
    MQCLOSE(hConn, eventQueue, MQCO_NONE, compCode, reason);
    CheckCallResult('Close event queue', compCode, reason);
  end;

  (***************************************************************************)
  (* Delete the event bag if successfully created.                           *)
  (***************************************************************************)
  if (eventBag <> MQHB_UNUSABLE_HBAG) then begin
    mqDeleteBag(eventBag, compCode, reason);
    CheckCallResult('Delete the event bag', compCode, reason);
  end;
end; (* end of GetQEvents *)

var hConn     : MQHCONN ;   // handle to connection
    QMName    : String;     // default QM name
    reason    : MQLONG;     // reason code
    connReason: MQLONG;     // MQCONN reason code
    compCode  : MQLONG;     // completion code
begin
  (***************************************************************************)
  (* First check the required parameters                                     *)
  (***************************************************************************)
  Writeln('Sample Event Monitor. ParamCount: ', ParamCount);
  if (ParamCount < 1) then begin
    Writeln('Required parameter missing - event queue to be monitored');
    Halt(99);
  end;

  (**************************************************************************)
  (* Connect to the queue manager                                           *)
  (**************************************************************************)
  QMName := ''; // assume default queue manager
  if (ParamCount > 1) then begin
    QMName := ParamStr(2);
  end;
  MQCONN(PChar(QMName), hConn, compCode, connReason);

  (***************************************************************************)
  (* Report the reason and stop if the connection failed                     *)
  (***************************************************************************)
  if (compCode = MQCC_FAILED) then begin
    CheckCallResult('MQCONN', compCode, connReason);
    Halt(connReason);
  end;

  (***************************************************************************)
  (* Call the routine to open the event queue and format any event messages  *)
  (* read from the queue.                                                    *)
  (***************************************************************************)
  GetQEvents(hConn, ParamStr(1));

  (***************************************************************************)
  (* Disconnect from the queue manager if not already connected              *)
  (***************************************************************************)
  if (connReason <> MQRC_ALREADY_CONNECTED) then begin
    MQDISC(hConn, compCode, reason);
    CheckCallResult('MQDISC', compCode, reason);
  end;

  Halt(0);
end.
